@@ -472,9 +472,13 @@ with open(CONFIGURE_AC, 'r') as f:
     match = re.compile(r'm4_define\(\[TS_VERSION_S],\[(.*?)]\)').search(contents)
     autoconf_version = '.'.join(match.group(1).split('.', 2)[:2] + ['x'])
 
-# get the current branch the local repository is on
-REPO_GIT_DIR = os.path.join(REPO_ROOT, ".git")
-git_branch = subprocess.check_output(['git', '--git-dir', REPO_GIT_DIR, 'rev-parse', '--abbrev-ref', 'HEAD'])
+# Get the current branch the local repository is on.
+# Run git from the repository root to work with both normal repos and worktrees.
+try:
+    git_branch = subprocess.check_output(
+        ['git', '-C', REPO_ROOT, 'rev-parse', '--abbrev-ref', 'HEAD'], stderr=subprocess.DEVNULL, text=True).strip()
+except (subprocess.CalledProcessError, FileNotFoundError):
+    git_branch = 'master'
 
 
 def make_github_link(name, rawtext, text, lineno, inliner, options=None, content=None):
