@@ -64,7 +64,23 @@ public:
     : version(pp_ver), ip_family(family), src_addr(src), dst_addr(dst)
   {
   }
-  ~ProxyProtocol() { ats_free(additional_data); }
+  ProxyProtocol(const ProxyProtocol &other)
+    : version(other.version), ip_family(other.ip_family), src_addr(other.src_addr), dst_addr(other.dst_addr)
+  {
+    if (!other.additional_data.empty()) {
+      set_additional_data(other.additional_data);
+    }
+  }
+  ProxyProtocol(ProxyProtocol &&other)
+    : version(other.version), ip_family(other.ip_family), src_addr(other.src_addr), dst_addr(other.dst_addr)
+  {
+    if (!other.additional_data.empty()) {
+      set_additional_data(other.additional_data);
+    }
+    other.additional_data.clear();
+    other.tlv.clear();
+  }
+  ~ProxyProtocol() = default;
   int  set_additional_data(std::string_view data);
   void set_ipv4_addrs(in_addr_t src_addr, uint16_t src_port, in_addr_t dst_addr, uint16_t dst_port);
   void set_ipv6_addrs(const in6_addr &src_addr, uint16_t src_port, const in6_addr &dst_addr, uint16_t dst_port);
@@ -78,8 +94,46 @@ public:
   IpEndpoint                                    dst_addr  = {};
   std::unordered_map<uint8_t, std::string_view> tlv;
 
+  ProxyProtocol &
+  operator=(const ProxyProtocol &other)
+  {
+    if (&other == this) {
+      return *this;
+    }
+    version   = other.version;
+    ip_family = other.ip_family;
+    src_addr  = other.src_addr;
+    dst_addr  = other.dst_addr;
+    if (!other.additional_data.empty()) {
+      set_additional_data(other.additional_data);
+    } else {
+      additional_data.clear();
+      tlv.clear();
+    }
+    return *this;
+  }
+
+  ProxyProtocol &
+  operator=(ProxyProtocol &&other)
+  {
+    version   = other.version;
+    ip_family = other.ip_family;
+    src_addr  = other.src_addr;
+    dst_addr  = other.dst_addr;
+
+    additional_data.clear();
+    tlv.clear();
+
+    if (!other.additional_data.empty()) {
+      set_additional_data(other.additional_data);
+    }
+    other.additional_data.clear();
+    other.tlv.clear();
+    return *this;
+  }
+
 private:
-  char *additional_data = nullptr;
+  std::string additional_data;
 };
 
 const size_t PPv1_CONNECTION_HEADER_LEN_MAX = 108;
