@@ -143,7 +143,6 @@ struct MIMEField {
 
   /// @return The name of @a this field.
   std::string_view name_get() const;
-  const char      *name_get(int *length) const;
 
   /** Find the index of the value in the multi-value field.
 
@@ -161,7 +160,6 @@ struct MIMEField {
 
   /// @return The value of @a this field.
   std::string_view value_get() const;
-  const char      *value_get(int *length) const;
 
   int32_t  value_get_int() const;
   uint32_t value_get_uint() const;
@@ -940,17 +938,6 @@ bool     mime_parse_integer(const char *&buf, const char *end, int *integer);
  *                                                                     *
  ***********************************************************************/
 
-/*-------------------------------------------------------------------------
-  -------------------------------------------------------------------------*/
-
-inline const char *
-MIMEField::name_get(int *length) const
-{
-  auto name{this->name_get()};
-  *length = int(name.size());
-  return name.data();
-}
-
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
@@ -974,11 +961,9 @@ MIMEField::name_set(HdrHeap *heap, MIMEHdrImpl *mh, const char *name, int length
 inline bool
 MIMEField::name_is_valid(uint32_t invalid_char_bits) const
 {
-  const char *name;
-  int         length;
-
-  for (name = name_get(&length); length > 0; length--) {
-    if (ParseRules::is_type(name[length - 1], invalid_char_bits)) {
+  auto name{name_get()};
+  for (auto c : name) {
+    if (ParseRules::is_type(c, invalid_char_bits)) {
       return false;
     }
   }
@@ -988,14 +973,6 @@ MIMEField::name_is_valid(uint32_t invalid_char_bits) const
 /*-------------------------------------------------------------------------
   -------------------------------------------------------------------------*/
 
-inline const char *
-MIMEField::value_get(int *length) const
-{
-  auto value{this->value_get()};
-  *length = int(value.size());
-  return value.data();
-}
-
 inline int32_t
 MIMEField::value_get_int() const
 {
@@ -1083,11 +1060,9 @@ MIMEField::value_append(HdrHeap *heap, MIMEHdrImpl *mh, const char *value, int l
 inline bool
 MIMEField::value_is_valid(uint32_t invalid_char_bits) const
 {
-  const char *value;
-  int         length;
-
-  for (value = value_get(&length); length > 0; length--) {
-    if (ParseRules::is_type(value[length - 1], invalid_char_bits)) {
+  auto value{value_get()};
+  for (auto c : value) {
+    if (ParseRules::is_type(c, invalid_char_bits)) {
       return false;
     }
   }
@@ -1449,7 +1424,9 @@ MIMEHdr::value_get(const char *name, int name_length, int *value_length_return)
   const MIMEField *field = field_find(name, name_length);
 
   if (field) {
-    return field->value_get(value_length_return);
+    auto value{field->value_get()};
+    *value_length_return = static_cast<int>(value.length());
+    return value.data();
   }
   return nullptr;
 }
@@ -1581,12 +1558,10 @@ MIMEHdr::field_combine_dups(MIMEField *field, bool prepend_comma, const char sep
   MIMEField *current = field->m_next_dup;
 
   while (current) {
-    int         value_len = 0;
-    const char *value_str = current->value_get(&value_len);
-
-    if (value_len > 0) {
-      HdrHeap::HeapGuard guard(m_heap, value_str); // reference count the source string so it doesn't get moved
-      field->value_append(m_heap, m_mime, value_str, value_len, prepend_comma, separator);
+    auto value{current->value_get()};
+    if (value.length() > 0) {
+      HdrHeap::HeapGuard guard(m_heap, value.data()); // reference count the source string so it doesn't get moved
+      field->value_append(m_heap, m_mime, value.data(), value.length(), prepend_comma, separator);
     }
     field_delete(current, false); // don't delete duplicates
     current = field->m_next_dup;
