@@ -41,6 +41,7 @@
 #include <string_view>
 #include <chrono>
 
+#include "iocore/eventsystem/IOBuffer.h"
 #include "swoc/swoc_ip.h"
 #include "swoc/BufferWriter.h"
 
@@ -85,6 +86,7 @@ struct HttpStatsBlock {
   Metrics::Counter::AtomicType *cache_open_write_adjust_thread;
   Metrics::Counter::AtomicType *cache_open_write_begin_time;
   Metrics::Counter::AtomicType *cache_open_write_end_time;
+  Metrics::Counter::AtomicType *cache_open_write_fail_count;
   Metrics::Counter::AtomicType *cache_read_error;
   Metrics::Counter::AtomicType *cache_read_errors;
   Metrics::Counter::AtomicType *cache_updates;
@@ -256,8 +258,10 @@ struct HttpStatsBlock {
   Metrics::Counter::AtomicType *total_client_connections;
   Metrics::Counter::AtomicType *total_client_connections_ipv4;
   Metrics::Counter::AtomicType *total_client_connections_ipv6;
+  Metrics::Counter::AtomicType *total_client_connections_uds;
   Metrics::Counter::AtomicType *total_incoming_connections;
   Metrics::Counter::AtomicType *total_parent_marked_down_count;
+  Metrics::Counter::AtomicType *total_parent_marked_down_timeout;
   Metrics::Counter::AtomicType *total_parent_proxy_connections;
   Metrics::Counter::AtomicType *total_parent_retries;
   Metrics::Counter::AtomicType *total_parent_retries_exhausted;
@@ -326,6 +330,7 @@ struct HttpStatsBlock {
   Metrics::Counter::AtomicType *origin_server_speed_bytes_per_sec_400M;
   Metrics::Counter::AtomicType *origin_server_speed_bytes_per_sec_800M;
   Metrics::Counter::AtomicType *origin_server_speed_bytes_per_sec_1G;
+  Metrics::Counter::AtomicType *cache_compat_key_reads;
 };
 
 enum CacheOpenWriteFailAction_t {
@@ -547,6 +552,8 @@ struct OverridableHttpConfigParams {
   ////////////////////////
   MgmtByte post_check_content_length_enabled = 1;
 
+  MgmtByte cache_post_method = 0;
+
   ////////////////////////////////////////////////
   // Buffer post body before connecting servers //
   ////////////////////////////////////////////////
@@ -774,8 +781,6 @@ public:
 
   MgmtByte enable_http_stats = 1; // Can be "slow"
 
-  MgmtByte cache_post_method = 0;
-
   MgmtByte push_method_enabled = 0;
 
   MgmtByte referer_filter_enabled  = 0;
@@ -799,6 +804,9 @@ public:
   // bitset to hold the status codes that will BE cached with negative caching enabled
   HttpStatusBitset negative_caching_list;
 
+  // bitset to hold the status codes that will used by nagative revalidating enabled
+  HttpStatusBitset negative_revalidating_list;
+
   // All the overridable configurations goes into this class member, but they
   // are not copied over until needed ("lazy").
   OverridableHttpConfigParams oride;
@@ -811,6 +819,8 @@ public:
   MgmtByte http_host_sni_policy         = 0;
   MgmtByte scheme_proto_mismatch_policy = 2;
 
+  MgmtByte cache_try_compat_key_read = 0;
+
   // noncopyable
   /////////////////////////////////////
   // operator = and copy constructor //
