@@ -24,56 +24,54 @@
 #pragma once
 
 #include <cstring>
-// I had to move this here, because I really needed to avoid including ink_platform.h in here,
-// because of a conflict on linux/tcp.h vs netinet/tcp.h.
-#include <limits.h> // NOLINT(modernize-deprecated-headers)
 
+#include "tscore/ink_platform.h"
 #include "tscore/ink_defs.h"
 #include "tscore/ink_apidefs.h"
 
-typedef unsigned int CTypeResult;
+using CTypeResult = unsigned int;
 
 // Set this to 0 to disable SI
 // decimal multipliers
 #define USE_SI_MULTIPLIERS 1
 
-#define is_char_BIT (1 << 0)
-#define is_upalpha_BIT (1 << 1)
-#define is_loalpha_BIT (1 << 2)
-#define is_alpha_BIT (1 << 3)
-#define is_digit_BIT (1 << 4)
-#define is_ctl_BIT (1 << 5)
-#define is_ws_BIT (1 << 6)
-#define is_hex_BIT (1 << 7)
-#define is_pchar_BIT (1 << 8)
-#define is_extra_BIT (1 << 9)
-#define is_safe_BIT (1 << 10)
-#define is_unsafe_BIT (1 << 11)
-#define is_national_BIT (1 << 12)
-#define is_reserved_BIT (1 << 13)
-#define is_unreserved_BIT (1 << 14)
-#define is_punct_BIT (1 << 15)
-#define is_end_of_url_BIT (1 << 16)
-#define is_tspecials_BIT (1 << 17)
-#define is_spcr_BIT (1 << 18)
-#define is_splf_BIT (1 << 19)
-#define is_wslfcr_BIT (1 << 20)
-#define is_eow_BIT (1 << 21)
-#define is_token_BIT (1 << 22)
-#define is_uri_BIT (1 << 23)
-#define is_sep_BIT (1 << 24)
-#define is_empty_BIT (1 << 25)
-#define is_alnum_BIT (1 << 26)
-#define is_space_BIT (1 << 27)
-#define is_control_BIT (1 << 28)
-#define is_mime_sep_BIT (1 << 29)
+#define is_char_BIT            (1 << 0)
+#define is_upalpha_BIT         (1 << 1)
+#define is_loalpha_BIT         (1 << 2)
+#define is_alpha_BIT           (1 << 3)
+#define is_digit_BIT           (1 << 4)
+#define is_ctl_BIT             (1 << 5)
+#define is_ws_BIT              (1 << 6)
+#define is_hex_BIT             (1 << 7)
+#define is_pchar_BIT           (1 << 8)
+#define is_extra_BIT           (1 << 9)
+#define is_safe_BIT            (1 << 10)
+#define is_unsafe_BIT          (1 << 11)
+#define is_national_BIT        (1 << 12)
+#define is_reserved_BIT        (1 << 13)
+#define is_unreserved_BIT      (1 << 14)
+#define is_punct_BIT           (1 << 15)
+#define is_end_of_url_BIT      (1 << 16)
+#define is_tspecials_BIT       (1 << 17)
+#define is_spcr_BIT            (1 << 18)
+#define is_splf_BIT            (1 << 19)
+#define is_wslfcr_BIT          (1 << 20)
+#define is_eow_BIT             (1 << 21)
+#define is_token_BIT           (1 << 22)
+#define is_uri_BIT             (1 << 23)
+#define is_sep_BIT             (1 << 24)
+#define is_empty_BIT           (1 << 25)
+#define is_alnum_BIT           (1 << 26)
+#define is_space_BIT           (1 << 27)
+#define is_control_BIT         (1 << 28)
+#define is_mime_sep_BIT        (1 << 29)
 #define is_http_field_name_BIT (1 << 30)
 /* shut up the DEC compiler */
 #define is_http_field_value_BIT (((CTypeResult)1) << 31)
 
 extern const CTypeResult parseRulesCType[];
-extern const char parseRulesCTypeToUpper[];
-extern const char parseRulesCTypeToLower[];
+extern const char        parseRulesCTypeToUpper[];
+extern const char        parseRulesCTypeToLower[];
 
 class ParseRules
 {
@@ -128,9 +126,9 @@ public:
   static CTypeResult is_empty(char c);            // wslfcr,#
   static CTypeResult is_alnum(char c);            // 0-9,A-Z,a-z
   static CTypeResult is_space(char c);            // ' ' HT,VT,NP,CR,LF
-  static CTypeResult is_control(char c);          // 0-31 127
-  static CTypeResult is_mime_sep(char c);         // ()<>,;\"/[]?{} \t
-  static CTypeResult is_http_field_name(char c);  // not : or mime_sep except for @
+  static CTypeResult is_control(char c);          // 0x00-0x08, 0x0a-0x1f, 0x7f
+  static CTypeResult is_mime_sep(char c);         // @()<>,;\"/[]?{} \t
+  static CTypeResult is_http_field_name(char c);  // not :, =, 0x80+, control, or mime_sep except for @
   static CTypeResult is_http_field_value(char c); // not CR, LF, comma, or "
 
   //////////////////
@@ -154,16 +152,16 @@ public:
 
   static CTypeResult strncasecmp_eow(const char *s1, const char *s2, int n);
   static const char *strcasestr(const char *s1, const char *s2);
-  static int strlen_eow(const char *s);
+  static int         strlen_eow(const char *s);
   static const char *strstr_eow(const char *s1, const char *s2);
 
-  static char ink_toupper(char c);
-  static char ink_tolower(char c);
+  static char        ink_toupper(char c);
+  static char        ink_tolower(char c);
   static const char *memchr(const char *s, char c, int max_length);
   static const char *strchr(const char *s, char c);
 
   // noncopyable
-  ParseRules(const ParseRules &) = delete;
+  ParseRules(const ParseRules &)            = delete;
   ParseRules &operator=(const ParseRules &) = delete;
 };
 
@@ -174,14 +172,14 @@ public:
 inline CTypeResult
 ParseRules::is_type(char c, uint32_t bitmask)
 {
-  return (parseRulesCType[(unsigned char)c] & bitmask);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & bitmask);
 }
 
 inline CTypeResult
 ParseRules::is_char(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_char_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_char_BIT);
 #else
   return ((c & 0x80) == 0);
 #endif
@@ -191,7 +189,7 @@ inline CTypeResult
 ParseRules::is_upalpha(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_upalpha_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_upalpha_BIT);
 #else
   return (c >= 'A' && c <= 'Z');
 #endif
@@ -201,7 +199,7 @@ inline CTypeResult
 ParseRules::is_loalpha(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_loalpha_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_loalpha_BIT);
 #else
   return (c >= 'a' && c <= 'z');
 #endif
@@ -211,7 +209,7 @@ inline CTypeResult
 ParseRules::is_alpha(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_alpha_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_alpha_BIT);
 #else
   return (is_upalpha(c) || is_loalpha(c));
 #endif
@@ -221,7 +219,7 @@ inline CTypeResult
 ParseRules::is_digit(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_digit_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_digit_BIT);
 #else
   return (c >= '0' && c <= '9');
 #endif
@@ -231,7 +229,7 @@ inline CTypeResult
 ParseRules::is_alnum(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_alnum_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_alnum_BIT);
 #else
   return (is_alpha(c) || is_digit(c));
 #endif
@@ -241,7 +239,7 @@ inline CTypeResult
 ParseRules::is_ctl(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_ctl_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_ctl_BIT);
 #else
   return ((!(c & 0x80) && c <= 31) || c == 127);
 #endif
@@ -251,7 +249,7 @@ inline CTypeResult
 ParseRules::is_ws(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_ws_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_ws_BIT);
 #else
   return (c == CHAR_SP || c == CHAR_HT);
 #endif
@@ -261,7 +259,7 @@ inline CTypeResult
 ParseRules::is_hex(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_hex_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_hex_BIT);
 #else
   return ((c >= 'A' && c <= 'F') || (c >= 'a' && c <= 'f') || (c >= '0' && c <= '9'));
 #endif
@@ -283,7 +281,7 @@ inline CTypeResult
 ParseRules::is_splf(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_splf_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_splf_BIT);
 #else
   return (c == CHAR_SP || c == CHAR_LF);
 #endif
@@ -293,7 +291,7 @@ inline CTypeResult
 ParseRules::is_spcr(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_spcr_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_spcr_BIT);
 #else
   return (c == CHAR_SP || c == CHAR_CR);
 #endif
@@ -303,7 +301,7 @@ inline CTypeResult
 ParseRules::is_wslfcr(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_wslfcr_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_wslfcr_BIT);
 #else
   return ParseRules::is_ws(c) || ParseRules::is_splf(c) || ParseRules::is_spcr(c);
 #endif
@@ -313,7 +311,7 @@ inline CTypeResult
 ParseRules::is_extra(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_extra_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_extra_BIT);
 #else
   switch (c) {
   case '!':
@@ -332,7 +330,7 @@ inline CTypeResult
 ParseRules::is_safe(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_safe_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_safe_BIT);
 #else
   return (c == '$' || c == '-' || c == '_' || c == '.' || c == '+');
 #endif
@@ -342,10 +340,11 @@ inline CTypeResult
 ParseRules::is_unsafe(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_unsafe_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_unsafe_BIT);
 #else
-  if (is_ctl(c))
+  if (is_ctl(c)) {
     return (true);
+  }
 
   switch (c) {
   case ' ':
@@ -364,7 +363,7 @@ inline CTypeResult
 ParseRules::is_reserved(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_reserved_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_reserved_BIT);
 #else
   switch (c) {
   case ';':
@@ -384,7 +383,7 @@ inline CTypeResult
 ParseRules::is_national(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_national_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_national_BIT);
 #else
   switch (c) {
   case '{':
@@ -406,7 +405,7 @@ inline CTypeResult
 ParseRules::is_unreserved(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_unreserved_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_unreserved_BIT);
 #else
   return (is_alpha(c) || is_digit(c) || is_safe(c) || is_extra(c) || is_national(c));
 #endif
@@ -416,7 +415,7 @@ inline CTypeResult
 ParseRules::is_punct(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_punct_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_punct_BIT);
 #else
   switch (c) {
   case '!':
@@ -460,7 +459,7 @@ inline CTypeResult
 ParseRules::is_end_of_url(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_end_of_url_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_end_of_url_BIT);
 #else
   return (c == '\0' || c == '\n' || c == ' ' || ParseRules::is_ctl(c));
 #endif
@@ -485,13 +484,15 @@ inline CTypeResult
 ParseRules::is_pchar(const char *seq)
 {
 #ifndef COMPILE_PARSE_RULES
-  if (*seq != '%')
-    return (parseRulesCType[(uint8_t)*seq] & is_pchar_BIT);
-  else
+  if (*seq != '%') {
+    return (parseRulesCType[static_cast<uint8_t>(*seq)] & is_pchar_BIT);
+  } else {
     return is_hex(seq[1]) && is_hex(seq[2]);
+  }
 #else
-  if (is_unreserved(*seq))
+  if (is_unreserved(*seq)) {
     return (true);
+  }
 
   switch (seq[0]) {
   case ':':
@@ -509,7 +510,7 @@ inline CTypeResult
 ParseRules::is_tspecials(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_tspecials_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_tspecials_BIT);
 #else
   switch (c) {
   case '(':
@@ -541,7 +542,7 @@ inline CTypeResult
 ParseRules::is_token(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_token_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_token_BIT);
 #else
   return (is_char(c) && !(is_ctl(c) || is_tspecials(c)));
 #endif
@@ -551,9 +552,9 @@ inline char
 ParseRules::ink_toupper(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return parseRulesCTypeToUpper[(unsigned char)c];
+  return parseRulesCTypeToUpper[static_cast<unsigned char>(c)];
 #else
-  int up_case            = c;
+  int       up_case      = c;
   const int up_case_diff = 'a' - 'A';
 
   if (c >= 'a' && c <= 'z') {
@@ -567,9 +568,9 @@ inline char
 ParseRules::ink_tolower(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return parseRulesCTypeToLower[(unsigned char)c];
+  return parseRulesCTypeToLower[static_cast<unsigned char>(c)];
 #else
-  int lo_case            = c;
+  int       lo_case      = c;
   const int lo_case_diff = 'a' - 'A';
 
   if (c >= 'A' && c <= 'Z') {
@@ -583,7 +584,7 @@ inline CTypeResult
 ParseRules::is_eow(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_eow_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_eow_BIT);
 #else
   return (c == '\0' || c == '\r' || c == '\n');
 #endif
@@ -593,10 +594,11 @@ inline CTypeResult
 ParseRules::is_uri(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_uri_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_uri_BIT);
 #else
-  if (is_alnum(c))
+  if (is_alnum(c)) {
     return (true);
+  }
 
   switch (c) {
   case ':':
@@ -632,7 +634,7 @@ inline CTypeResult
 ParseRules::is_sep(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_sep_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_sep_BIT);
 #else
   return (!c || c == ',' || c == ':' || c == '!' || is_wslfcr(c));
 #endif
@@ -642,7 +644,7 @@ inline CTypeResult
 ParseRules::is_empty(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_empty_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_empty_BIT);
 #else
   return (c == '#' || is_wslfcr(c));
 #endif
@@ -652,7 +654,7 @@ inline CTypeResult
 ParseRules::is_space(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_space_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_space_BIT);
 #else
   switch (c) {
   case CHAR_SP:
@@ -667,14 +669,24 @@ ParseRules::is_space(char c)
 #endif
 }
 
+/**
+   Return true if @c is a control char except HTAB(0x09) and SP(0x20).
+   If you need to check @c is HTAB or SP, use `ParseRules::is_ws`.
+ */
 inline CTypeResult
 ParseRules::is_control(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_control_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_control_BIT);
 #else
-  if (((unsigned char)c) < 32 || ((unsigned char)c) == 127)
+  if (c == CHAR_HT || c == CHAR_SP) {
+    return false;
+  }
+
+  if ((static_cast<unsigned char>(c)) < 0x20 || c == 0x7f) {
     return true;
+  }
+
   return false;
 #endif
 }
@@ -683,11 +695,13 @@ inline CTypeResult
 ParseRules::is_mime_sep(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_mime_sep_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_mime_sep_BIT);
 #else
   if ((c == '(') || (c == ')') || (c == '<') || (c == '>') || (c == '@') || (c == ',') || (c == ';') || (c == '\\') ||
-      (c == '\"') || (c == '/') || (c == '[') || (c == ']') || (c == '?') || (c == '{') || (c == '}') || (c == ' ') || (c == '\t'))
+      (c == '\"') || (c == '/') || (c == '[') || (c == ']') || (c == '?') || (c == '{') || (c == '}') || (c == ' ') ||
+      (c == '\t')) {
     return true;
+  }
   return false;
 #endif
 }
@@ -696,10 +710,11 @@ inline CTypeResult
 ParseRules::is_http_field_name(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (parseRulesCType[(unsigned char)c] & is_http_field_name_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_http_field_name_BIT);
 #else
-  if ((c == ':') || (is_mime_sep(c) && (c != '@')))
+  if (!is_char(c) || is_control(c) || (is_mime_sep(c) && c != '@') || c == '=' || c == ':') {
     return false;
+  }
   return true;
 #endif
 }
@@ -708,7 +723,7 @@ inline CTypeResult
 ParseRules::is_http_field_value(char c)
 {
 #ifndef COMPILE_PARSE_RULES
-  return (CTypeResult)(parseRulesCType[(unsigned char)c] & is_http_field_value_BIT);
+  return (parseRulesCType[static_cast<unsigned char>(c)] & is_http_field_value_BIT);
 #else
   switch (c) {
   case CHAR_CR:
@@ -741,8 +756,9 @@ ParseRules::strncasecmp_eow(const char *s1, const char *s2, int count)
     ///////////////////////////////////////////////////////////////
     // if they are different; only match if both are terminators //
     ///////////////////////////////////////////////////////////////
-    if (ink_tolower(a) != ink_tolower(b))
+    if (ink_tolower(a) != ink_tolower(b)) {
       return (is_eow(a) && is_eow(b));
+    }
   }
   return (true);
 }
@@ -757,8 +773,9 @@ inline int
 ParseRules::strlen_eow(const char *s)
 {
   for (int i = 0; true; i++) {
-    if (is_eow(s[i]))
+    if (is_eow(s[i])) {
       return (i);
+    }
   }
 }
 
@@ -777,10 +794,13 @@ ParseRules::strstr_eow(const char *s1, const char *s2)
 
   int s2_len = strlen_eow(s2);
 
-  for (i1 = 0; !is_eow(s1[i1]); i1++)
-    if (ink_tolower(s1[i1]) == ink_tolower(s2[0]))
-      if (strncasecmp_eow(&s1[i1], &s2[0], s2_len))
+  for (i1 = 0; !is_eow(s1[i1]); i1++) {
+    if (ink_tolower(s1[i1]) == ink_tolower(s2[0])) {
+      if (strncasecmp_eow(&s1[i1], &s2[0], s2_len)) {
         return (&s1[i1]);
+      }
+    }
+  }
 
   return (nullptr);
 }
@@ -792,10 +812,13 @@ ParseRules::strcasestr(const char *s1, const char *s2)
 
   size_t s2_len = strlen(s2);
 
-  for (i1 = 0; s1[i1] != '\0'; i1++)
-    if (ink_tolower(s1[i1]) == ink_tolower(s2[0]))
-      if (strncasecmp_eow(&s1[i1], &s2[0], (int)s2_len))
+  for (i1 = 0; s1[i1] != '\0'; i1++) {
+    if (ink_tolower(s1[i1]) == ink_tolower(s2[0])) {
+      if (strncasecmp_eow(&s1[i1], &s2[0], static_cast<int>(s2_len))) {
         return (&s1[i1]);
+      }
+    }
+  }
 
   return (nullptr);
 }
@@ -803,45 +826,51 @@ ParseRules::strcasestr(const char *s1, const char *s2)
 inline const char *
 ParseRules::memchr(const char *s, char c, int max_length)
 {
-  for (int i = 0; i < max_length; i++)
-    if (s[i] == c)
+  for (int i = 0; i < max_length; i++) {
+    if (s[i] == c) {
       return (&s[i]);
+    }
+  }
   return (nullptr);
 }
 
 inline const char *
 ParseRules::strchr(const char *s, char c)
 {
-  for (int i = 0; s[i] != '\0'; i++)
-    if (s[i] == c)
+  for (int i = 0; s[i] != '\0'; i++) {
+    if (s[i] == c) {
       return (&s[i]);
+    }
+  }
   return (nullptr);
 }
 
 static inline int
 ink_get_hex(char c)
 {
-  if (ParseRules::is_digit(c))
-    return (int)(c - '0');
+  if (ParseRules::is_digit(c)) {
+    return (c - '0');
+  }
   c = ParseRules::ink_tolower(c);
-  return (int)((c - 'a') + 10);
+  return ((c - 'a') + 10);
 }
 
-int64_t ink_atoi64(const char *, const char **end = nullptr);
+int64_t  ink_atoi64(const char *, const char **end = nullptr);
 uint64_t ink_atoui64(const char *);
-int64_t ink_atoi64(const char *, int);
+int64_t  ink_atoi64(const char *, int);
 
 static inline int
 ink_atoi(const char *str)
 {
   int64_t val = ink_atoi64(str);
 
-  if (val > INT_MAX)
+  if (val > INT_MAX) {
     return INT_MAX;
-  else if (val < INT_MIN)
+  } else if (val < INT_MIN) {
     return INT_MIN;
-  else
+  } else {
     return static_cast<int>(val);
+  }
 }
 
 static inline int
@@ -849,12 +878,13 @@ ink_atoi(const char *str, int len)
 {
   int64_t val = ink_atoi64(str, len);
 
-  if (val > INT_MAX)
+  if (val > INT_MAX) {
     return INT_MAX;
-  else if (val < INT_MIN)
+  } else if (val < INT_MIN) {
     return INT_MIN;
-  else
+  } else {
     return static_cast<int>(val);
+  }
 }
 
 static inline unsigned int
@@ -862,8 +892,9 @@ ink_atoui(const char *str)
 {
   uint64_t val = ink_atoui64(str);
 
-  if (val > INT_MAX)
-    return INT_MAX;
-  else
-    return static_cast<int>(val);
+  if (val > UINT_MAX) {
+    return UINT_MAX;
+  } else {
+    return static_cast<unsigned int>(val);
+  }
 }
