@@ -27,6 +27,7 @@
 static const struct option longopt[] = {
   {const_cast<char *>("policy"),               required_argument, nullptr, 'p' },
   {const_cast<char *>("stats-enable-with-id"), required_argument, nullptr, 'e' },
+  {const_cast<char *>("disable-on-redirect"),  no_argument,       nullptr, 'd' },
   // This is for both Chance and LRU (optional) policy
   {const_cast<char *>("sample"),               required_argument, nullptr, 's' },
   // For the LRU policy
@@ -78,6 +79,8 @@ PromotionConfig::factory(int argc, char *argv[])
           DBG("stats collection is enabled");
         }
       }
+    } else if (opt == 'd') {
+      _disable_on_redirect = true;
     } else {
       if (_policy) {
         // The --sample (-s) option is allowed for all configs, but only after --policy is specified.
