@@ -45,8 +45,13 @@
 
 #include "ts/ts.h"
 
+namespace
+{
 const char *PLUGIN_NAME = "certifier";
 
+DbgCtl dbg_ctl{PLUGIN_NAME};
+} // namespace
+
 /// Override default delete for unique ptrs to openSSL objects
 namespace std
 {
@@ -90,19 +95,19 @@ class SslLRUList
 {
 private:
   struct SslData {
-    std::queue<void *> vconnQ;    ///< Current queue of connections waiting for cert
-    std::unique_ptr<SSL_CTX> ctx; ///< Context generated
-    std::unique_ptr<X509> cert;   ///< Cert generated
-    std::string commonName;       ///< SNI
-    bool scheduled = false;       ///< If a TASK thread has been scheduled to generate cert
-                                  ///< The first thread might fail to do so, this flag will help reschedule
-    bool wontdo = false;          ///< if certs not on disk and dynamic gen is disabled
+    std::queue<void *>       vconnQ;            ///< Current queue of connections waiting for cert
+    std::unique_ptr<SSL_CTX> ctx;               ///< Context generated
+    std::unique_ptr<X509>    cert;              ///< Cert generated
+    std::string              commonName;        ///< SNI
+    bool                     scheduled = false; ///< If a TASK thread has been scheduled to generate cert
+                                                ///< The first thread might fail to do so, this flag will help reschedule
+    bool wontdo = false;                        ///< if certs not on disk and dynamic gen is disabled
     /// Doubly Linked List pointers for LRU
     SslData *prev = nullptr;
     SslData *next = nullptr;
 
     SslData() = default;
-    ~SslData() { TSDebug(PLUGIN_NAME, "Deleting ssl data for [%s]", commonName.c_str()); }
+    ~SslData() { /* Dbg(dbg_ctl, "Deleting ssl data for [%s]", commonName.c_str()); */ }
   };
 
   using scoped_SslData = std::unique_ptr<SslLRUList::SslData>;
@@ -110,10 +115,10 @@ private:
   // unordered_map is much faster in terms of insertion/lookup/removal
   // Although it uses more space than map, the time efficiency should be more important
   std::unordered_map<std::string, scoped_SslData> cnDataMap; ///< Map from CN to sslData
-  TSMutex list_mutex;
+  TSMutex                                         list_mutex;
 
-  int size = 0;
-  int limit;
+  int      size = 0;
+  int      limit;
   SslData *head = nullptr;
   SslData *tail = nullptr;
 
@@ -127,10 +132,10 @@ public:
   SSL_CTX *
   lookup_and_create(const char *servername, void *edata, bool &wontdo)
   {
-    SslData *ssl_data              = nullptr;
+    SslData       *ssl_data        = nullptr;
     scoped_SslData scoped_ssl_data = nullptr;
-    SSL_CTX *ref_ctx               = nullptr;
-    std::string commonName(servername);
+    SSL_CTX       *ref_ctx         = nullptr;
+    std::string    commonName(servername);
     TSMutexLock(list_mutex);
     auto dataItr = cnDataMap.find(commonName);
     /// If such a context exists in dict
@@ -209,7 +214,7 @@ public:
 
         // Remove oldest node if size exceeds limit
         if (++size > limit) {
-          TSDebug(PLUGIN_NAME, "Removing %s", tail->commonName.c_str());
+          Dbg(dbg_ctl, "%s: removing '%s'", __func__, tail->commonName.c_str());
           auto iter = cnDataMap.find(tail->commonName);
           if (iter != cnDataMap.end()) {
             local = std::move(iter->second); // copy ownership
@@ -222,8 +227,8 @@ public:
         }
       }
     }
-    TSDebug(PLUGIN_NAME, "%s Prepend to LRU list...List Size:%d Map Size: %d", data->commonName.c_str(), size,
-            static_cast<int>(cnDataMap.size()));
+    Dbg(dbg_ctl, "%s: prepending '%s' to LRU ... list size: %d, map size: %d", __func__, data->commonName.c_str(), size,
+        static_cast<int>(cnDataMap.size()));
 
     TSMutexUnlock(list_mutex);
   }
@@ -249,9 +254,9 @@ public:
         if (tail == data) {
           tail = data->prev;
         }
-        data->prev = nullptr;
-        data->next = nullptr;
-        size -= 1;
+        data->prev  = nullptr;
+        data->next  = nullptr;
+        size       -= 1;
       }
     }
     TSMutexUnlock(list_mutex);
@@ -304,139 +309,121 @@ public:
 static bool sign_enabled = false;
 
 // Trusted CA private key and cert
-static scoped_X509 ca_cert_scoped;
+static scoped_X509     ca_cert_scoped;
 static scoped_EVP_PKEY ca_pkey_scoped;
 // static scoped_EVP_PKEY  ts_pkey_scoped;
 
-static int ca_serial;            ///< serial number
-static std::fstream serial_file; ///< serial number file
-static TSMutex serial_mutex;     ///< serial number mutex
+static int          ca_serial;    ///< serial number
+static std::fstream serial_file;  ///< serial number file
+static TSMutex      serial_mutex; ///< serial number mutex
 
 // Management Object
 static std::unique_ptr<SslLRUList> ssl_list = nullptr;
-static std::string store_path;
+static std::string                 store_path;
 
-/// Local helper function that generates a CSR based on common name
-static scoped_X509_REQ
-mkcsr(const char *cn)
+/**
+ * Local helper function that adds a Subject Alternative Name field into a
+ * certificate.
+ *
+ * @param[out] cert
+ * @param[in] dnsName
+ */
+static void
+addSANExtToCert(X509 *cert, std::string_view dnsName)
 {
-  TSDebug(PLUGIN_NAME, "Entering mkcsr()...");
-  X509_NAME *n;
-  scoped_X509_REQ req;
-  req.reset(X509_REQ_new());
-
-  /// Set X509 version
-  X509_REQ_set_version(req.get(), 1);
-
-  /// Get handle to subject name
-  n = X509_REQ_get_subject_name(req.get());
-
-  /// Set common name field
-  if (X509_NAME_add_entry_by_txt(n, "CN", MBSTRING_ASC, (unsigned char *)cn, -1, -1, 0) != 1) {
-    TSError("[%s] mkcsr(): Failed to add entry.", PLUGIN_NAME);
-    return nullptr;
-  }
-  /// Set Traffic Server public key
-  if (X509_REQ_set_pubkey(req.get(), ca_pkey_scoped.get()) != 1) {
-    TSError("[%s] mkcsr(): Failed to set pubkey.", PLUGIN_NAME);
-    return nullptr;
-  }
-  /// Sign with Traffic Server private key
-  if (X509_REQ_sign(req.get(), ca_pkey_scoped.get(), EVP_sha256()) <= 0) {
-    TSError("[%s] mkcsr(): Failed to Sign.", PLUGIN_NAME);
-    return nullptr;
-  }
-  return req;
+  Dbg(dbg_ctl, "Adding SAN extension to the cert");
+  GENERAL_NAMES  *generalNames = sk_GENERAL_NAME_new_null();
+  GENERAL_NAME   *generalName  = GENERAL_NAME_new();
+  ASN1_IA5STRING *ia5          = ASN1_IA5STRING_new();
+  ASN1_STRING_set(ia5, dnsName.data(), dnsName.length());
+  // generalName owns ia5 after this call
+  GENERAL_NAME_set0_value(generalName, GEN_DNS, ia5);
+  sk_GENERAL_NAME_push(generalNames, generalName);
+  X509_add1_ext_i2d(cert, NID_subject_alt_name, generalNames, 0, X509V3_ADD_DEFAULT);
+  sk_GENERAL_NAME_pop_free(generalNames, GENERAL_NAME_free);
 }
 
-/// Local helper function that generates a X509 certificate based on CSR
+/// Local helper function that generates a X509 certificate based on SNI
 static scoped_X509
-mkcrt(X509_REQ *req, int serial)
+mkcrt(const std::string &commonName, int serial)
 {
-  TSDebug(PLUGIN_NAME, "Entering mkcrt()...");
-  X509_NAME *subj, *tmpsubj;
   scoped_EVP_PKEY pktmp;
-  scoped_X509 cert;
+  scoped_X509     cert;
 
   cert.reset(X509_new());
 
-  /// Set X509V3
+  // Set X509V3
   if (X509_set_version(cert.get(), 2) == 0) {
-    TSError("[%s] mkcrt(): Failed to set X509V3.", PLUGIN_NAME);
+    TSError("[%s] %s: failed to set X509V3", PLUGIN_NAME, __func__);
     return nullptr;
   }
 
-  /// Set serial number
-  // TSDebug("txn_monitor", "serial: %d", serial);
+  // Set serial number
   ASN1_INTEGER_set(X509_get_serialNumber(cert.get()), serial);
 
-  /// Set issuer from CA cert
+  // Set issuer from CA cert
   if (X509_set_issuer_name(cert.get(), X509_get_subject_name(ca_cert_scoped.get())) == 0) {
-    TSError("[%s] mkcrt(): Failed to set issuer.", PLUGIN_NAME);
+    TSError("[%s] %s: failed to set certificate issuer", PLUGIN_NAME, __func__);
     return nullptr;
   }
-  /// Set certificate time
+
+  // Set certificate time
   X509_gmtime_adj(X509_get_notBefore(cert.get()), 0);
   X509_gmtime_adj(X509_get_notAfter(cert.get()), static_cast<long>(3650) * 24 * 3600);
 
-  /// Get a handle to csr subject name
-  subj = X509_REQ_get_subject_name(req);
-  if ((tmpsubj = X509_NAME_dup(subj)) == nullptr) {
-    TSDebug(PLUGIN_NAME, "mkcrt(): Failed to duplicate subject name.");
-    return nullptr;
-  }
-  if ((X509_set_subject_name(cert.get(), tmpsubj)) == 0) {
-    TSDebug(PLUGIN_NAME, "mkcrt(): Failed to set X509 subject name");
-    X509_NAME_free(tmpsubj); ///< explicit call to free X509_NAME object
-    return nullptr;
-  }
-  pktmp.reset(X509_REQ_get_pubkey(req));
-  if (pktmp == nullptr) {
-    TSDebug(PLUGIN_NAME, "mkcrt(): Failed to get CSR public key.");
-    X509_NAME_free(tmpsubj);
-    return nullptr;
-  }
-  if (X509_set_pubkey(cert.get(), pktmp.get()) == 0) {
-    TSDebug(PLUGIN_NAME, "mkcrt(): Failed to set X509 public key.");
-    X509_NAME_free(tmpsubj);
+  // Get handle to subject name
+  X509_NAME *n = X509_get_subject_name(cert.get());
+  // Set common name field
+  if (X509_NAME_add_entry_by_txt(n, "CN", MBSTRING_ASC, (unsigned char *)commonName.c_str(), -1, -1, 0) != 1) {
+    TSError("[%s] %s: failed to add certificate subject CN", PLUGIN_NAME, __func__);
     return nullptr;
   }
 
+  // Set Traffic Server public key
+  if (X509_set_pubkey(cert.get(), ca_pkey_scoped.get()) == 0) {
+    TSError("[%s] %s: failed to set certificate public key", PLUGIN_NAME, __func__);
+    return nullptr;
+  }
+
+  // Add the Subject Alternative Name (SAN) extension
+  addSANExtToCert(cert.get(), commonName);
+
+  // Sign the certificate
   X509_sign(cert.get(), ca_pkey_scoped.get(), EVP_sha256());
 
   return cert;
 }
 
 static int
-shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
+shadow_cert_generator(TSCont contp, TSEvent /* event ATS_UNUSED */, void * /* edata ATS_UNUSED */)
 {
   const char *servername = reinterpret_cast<const char *>(TSContDataGet(contp));
   std::string commonName(servername);
 
   std::queue<void *> localQ;
-  SSL_CTX *ref_ctx;
-  scoped_SSL_CTX ctx;
-  scoped_X509_REQ req;
-  scoped_X509 cert;
+  SSL_CTX           *ref_ctx;
+  scoped_SSL_CTX     ctx;
+  scoped_X509_REQ    req;
+  scoped_X509        cert;
 
   /// Calculate hash and path, try certs on disk first
   unsigned char digest[MD5_DIGEST_LENGTH];
   MD5(reinterpret_cast<unsigned char const *>(commonName.data()), commonName.length(), digest);
   char md5String[5];
-  sprintf(md5String, "%02hhx%02hhx", digest[0], digest[1]);
+  snprintf(md5String, sizeof(md5String), "%02hhx%02hhx", digest[0], digest[1]);
   std::string path          = store_path + "/" + std::string(md5String, 3);
   std::string cert_filename = path + '/' + commonName + ".crt";
 
   struct stat st;
-  FILE *fp = nullptr;
-  /// If directory doesn't exist, creat one
+  FILE       *fp = nullptr;
+  /// If directory doesn't exist, create one
   if (stat(path.c_str(), &st) == -1) {
     mkdir(path.c_str(), 0755);
   } else {
     /// Try open the file if directory exists
     fp = fopen(cert_filename.c_str(), "rt");
   }
-  TSDebug(PLUGIN_NAME, "shadow_cert_generator(): Cert file is expected at %s", cert_filename.c_str());
+  Dbg(dbg_ctl, "%s: cert file is expected at %s", __func__, cert_filename.c_str());
   /// If cert file exists and is readable
   if (fp != nullptr) {
     cert.reset(PEM_read_X509(fp, nullptr, nullptr, nullptr));
@@ -444,22 +431,21 @@ shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
 
     if (cert == nullptr) {
       /// Problem with cert file / openssl read
-      TSError("[%s] [shadow_cert_generator] Problem with loading certs", PLUGIN_NAME);
-      std::remove(cert_filename.c_str());
+      TSError("[%s] %s: failed o load certificate from '%s'", PLUGIN_NAME, __func__, cert_filename.c_str());
     } else {
-      TSDebug(PLUGIN_NAME, "shadow_cert_generator(): Loaded cert from file");
+      Dbg(dbg_ctl, "%s: loaded certificate from '%s'", __func__, cert_filename.c_str());
     }
   }
 
   /// No valid certs available from disk, create one and write to file
   if (cert == nullptr) {
     if (!sign_enabled) {
-      TSDebug(PLUGIN_NAME, "shadow_cert_generator(): No certs found and dynamic generation disabled. Marked as wontdo.");
+      Dbg(dbg_ctl, "%s: no certs found and dynamic generation disabled; marked as wontdo", __func__);
       // There won't be certs available. Mark this servername as wontdo
       // Pass on as if plugin doesn't exist
       ssl_list->setup_data_ctx(commonName, localQ, nullptr, nullptr, true);
       while (!localQ.empty()) {
-        // TSDebug(PLUGIN_NAME, "\tClearing the queue size %lu", localQ.size());
+        // Dbg(dbg_ctl, "\tClearing the queue size %lu", localQ.size());
         TSVConn ssl_vc = reinterpret_cast<TSVConn>(localQ.front());
         localQ.pop();
         TSVConnReenable(ssl_vc);
@@ -467,7 +453,7 @@ shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
       TSContDestroy(contp);
       return TS_SUCCESS;
     }
-    TSDebug(PLUGIN_NAME, "shadow_cert_generator(): Creating shadow certs");
+    Dbg(dbg_ctl, "%s: creating shadow certs", __func__);
 
     /// Get serial number
     TSMutexLock(serial_mutex);
@@ -481,19 +467,10 @@ shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
 
     TSMutexUnlock(serial_mutex);
 
-    /// Create CSR and cert
-    req = mkcsr(commonName.c_str());
-    if (req == nullptr) {
-      TSDebug(PLUGIN_NAME, "[shadow_cert_generator] CSR generation failed");
-      TSContDestroy(contp);
-      ssl_list->set_schedule(commonName, false);
-      return TS_ERROR;
-    }
-
-    cert = mkcrt(req.get(), serial);
-
+    /// Create cert
+    cert = mkcrt(commonName, serial);
     if (cert == nullptr) {
-      TSDebug(PLUGIN_NAME, "[shadow_cert_generator] Cert generation failed");
+      Dbg(dbg_ctl, "%s: cert generation failed", __func__);
       TSContDestroy(contp);
       ssl_list->set_schedule(commonName, false);
       return TS_ERROR;
@@ -501,10 +478,10 @@ shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
 
     /// Write certs to file
     if ((fp = fopen(cert_filename.c_str(), "w+")) == nullptr) {
-      TSDebug(PLUGIN_NAME, "shadow_cert_generator(): Error opening file: %s\n", strerror(errno));
+      Dbg(dbg_ctl, "%s: error opening file: %s", __func__, strerror(errno));
     } else {
       if (!PEM_write_X509(fp, cert.get())) {
-        TSDebug(PLUGIN_NAME, "shadow_cert_generator(): Error writing cert to disk");
+        Dbg(dbg_ctl, "%s: error writing cert to disk", __func__);
       }
       fclose(fp);
     }
@@ -515,27 +492,27 @@ shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
   ctx.reset(ref_ctx);
 
   if (SSL_CTX_use_certificate(ref_ctx, cert.get()) < 1) {
-    TSError("[%s] shadow_cert_handler(): Failed to use certificate in SSL_CTX.", PLUGIN_NAME);
+    TSError("[%s] %s: failed to use certificate in SSL_CTX", PLUGIN_NAME, __func__);
     TSContDestroy(contp);
     ssl_list->set_schedule(commonName, false);
     return TS_ERROR;
   }
   if (SSL_CTX_use_PrivateKey(ref_ctx, ca_pkey_scoped.get()) < 1) {
-    TSError("[%s] shadow_cert_handler(): Failed to use private key in SSL_CTX.", PLUGIN_NAME);
+    TSError("[%s] %s: failed to use private key in SSL_CTX", PLUGIN_NAME, __func__);
     TSContDestroy(contp);
     ssl_list->set_schedule(commonName, false);
     return TS_ERROR;
   }
-  TSDebug(PLUGIN_NAME, "shadow_cert_generator(): cert and context ready, clearing the queue");
+  Dbg(dbg_ctl, "%s: cert and context ready, clearing the queue", __func__);
   ssl_list->setup_data_ctx(commonName, localQ, std::move(ctx), std::move(cert), false);
 
   /// Clear the queue by setting context for each and reenable them
   while (!localQ.empty()) {
-    TSDebug(PLUGIN_NAME, "\tClearing the queue size %lu", localQ.size());
+    Dbg(dbg_ctl, "%s: clearing the queue size %lu", __func__, localQ.size());
     TSVConn ssl_vc = reinterpret_cast<TSVConn>(localQ.front());
     localQ.pop();
     TSSslConnection sslobj = TSVConnSslConnectionGet(ssl_vc);
-    SSL *ssl               = reinterpret_cast<SSL *>(sslobj);
+    SSL            *ssl    = reinterpret_cast<SSL *>(sslobj);
     SSL_set_SSL_CTX(ssl, ref_ctx);
     TSVConnReenable(ssl_vc);
   }
@@ -546,50 +523,55 @@ shadow_cert_generator(TSCont contp, TSEvent event, void *edata)
 
 /// Callback at TS_SSL_CERT_HOOK, generate/look up shadow certificates based on SNI/FQDN
 static int
-cert_retriever(TSCont contp, TSEvent event, void *edata)
+cert_retriever(TSCont /* contp ATS_UNUSED */, TSEvent /* event ATS_UNUSED */, void *edata)
 {
-  TSVConn ssl_vc         = reinterpret_cast<TSVConn>(edata);
-  TSSslConnection sslobj = TSVConnSslConnectionGet(ssl_vc);
-  SSL *ssl               = reinterpret_cast<SSL *>(sslobj);
-  const char *servername = SSL_get_servername(ssl, TLSEXT_NAMETYPE_host_name);
-  SSL_CTX *ref_ctx       = nullptr;
+  TSVConn         ssl_vc     = reinterpret_cast<TSVConn>(edata);
+  TSSslConnection sslobj     = TSVConnSslConnectionGet(ssl_vc);
+  SSL            *ssl        = reinterpret_cast<SSL *>(sslobj);
+  const char     *servername = SSL_get_servername(ssl, TLSEXT_NAMETYPE_host_name);
+  SSL_CTX        *ref_ctx    = nullptr;
 
   if (servername == nullptr) {
-    TSError("[%s] cert_retriever(): No SNI available.", PLUGIN_NAME);
+    TSError("[%s] %s: no SNI available", __func__, PLUGIN_NAME);
     return TS_ERROR;
   }
+
   bool wontdo = false;
   ref_ctx     = ssl_list->lookup_and_create(servername, edata, wontdo);
+
   if (wontdo) {
-    TSDebug(PLUGIN_NAME, "cert_retriever(): Won't generate cert for %s", servername);
-    TSVConnReenable(ssl_vc);
-  } else if (nullptr == ref_ctx) {
-    // If no existing context, schedule TASK thread to generate
-    TSDebug(PLUGIN_NAME, "cert_retriever(): schedule thread to generate/retrieve cert for %s", servername);
-    TSCont schedule_cont = TSContCreate(shadow_cert_generator, TSMutexCreate());
-    TSContDataSet(schedule_cont, (void *)servername);
-    TSContScheduleOnPool(schedule_cont, 0, TS_THREAD_POOL_TASK);
-  } else {
-    // Use existing context
-    TSDebug(PLUGIN_NAME, "cert_retriever(): Reuse existing cert and context for %s", servername);
-    SSL_set_SSL_CTX(ssl, ref_ctx);
+    Dbg(dbg_ctl, "%s: won't generate cert for %s", __func__, servername);
     TSVConnReenable(ssl_vc);
+    return TS_SUCCESS;
   }
 
-  /// For scheduled connections, the scheduled continuation will handle the reenabling
+  if (ref_ctx) {
+    // Use existing context.
+    Dbg(dbg_ctl, "%s: reusing existing cert and context for %s", __func__, servername);
+    SSL_set_SSL_CTX(ssl, ref_ctx);
+    TSVConnReenable(ssl_vc);
+    return TS_SUCCESS;
+  }
+
+  // If no existing context, schedule TASK thread to generate.
+  Dbg(dbg_ctl, "%s: scheduling thread to generate/retrieve cert for %s", __func__, servername);
+  TSCont schedule_cont = TSContCreate(shadow_cert_generator, TSMutexCreate());
+  TSContDataSet(schedule_cont, const_cast<char *>(servername));
+  TSContScheduleOnPool(schedule_cont, 0, TS_THREAD_POOL_TASK);
+
   return TS_SUCCESS;
 }
 
 void
 TSPluginInit(int argc, const char *argv[])
 {
-  TSDebug(PLUGIN_NAME, "initializing plugin");
+  Dbg(dbg_ctl, "initializing plugin");
   // Initialization data and callback
   TSPluginRegistrationInfo info;
-  TSCont cb_shadow   = nullptr;
-  info.plugin_name   = "certifier";
-  info.vendor_name   = "Apache Software Foundation";
-  info.support_email = "dev@trafficserver.apache.org";
+  TSCont                   cb_shadow = nullptr;
+  info.plugin_name                   = "certifier";
+  info.vendor_name                   = "Apache Software Foundation";
+  info.support_email                 = "dev@trafficserver.apache.org";
 
   const char *key    = nullptr;
   const char *cert   = nullptr;
@@ -597,12 +579,15 @@ TSPluginInit(int argc, const char *argv[])
 
   // Read options from plugin.config
   static const struct option longopts[] = {
-    {"sign-cert", required_argument, nullptr, 'c'},   {"sign-key", required_argument, nullptr, 'k'},
-    {"sign-serial", required_argument, nullptr, 'r'}, {"max", required_argument, nullptr, 'm'},
-    {"store", required_argument, nullptr, 's'},       {nullptr, no_argument, nullptr, 0}};
+    {"sign-cert",   required_argument, nullptr, 'c'},
+    {"sign-key",    required_argument, nullptr, 'k'},
+    {"sign-serial", required_argument, nullptr, 'r'},
+    {"max",         required_argument, nullptr, 'm'},
+    {"store",       required_argument, nullptr, 's'},
+    {nullptr,       no_argument,       nullptr, 0  }
+  };
 
   int opt = 0;
-
   while (opt >= 0) {
     opt = getopt_long(argc, const_cast<char *const *>(argv), "c:k:r:m:s:", longopts, nullptr);
     switch (opt) {
@@ -630,66 +615,73 @@ TSPluginInit(int argc, const char *argv[])
     case '?':
       break;
     default:
-      TSDebug(PLUGIN_NAME, "Unexpected options.");
-      TSError("[%s] Unexpected options error.", PLUGIN_NAME);
+      Dbg(dbg_ctl, "unexpected options");
+      TSError("[%s] unexpected options error", PLUGIN_NAME);
       return;
     }
   }
 
   // Register plugin and create callback
   if (TSPluginRegister(&info) != TS_SUCCESS) {
-    TSError("[%s] Unable to initialize plugin (disabled). Failed to register plugin.", PLUGIN_NAME);
-  } else if ((cb_shadow = TSContCreate(cert_retriever, nullptr)) == nullptr) {
-    TSError("[%s] Unable to initialize plugin (disabled). Failed to create shadow cert cb.", PLUGIN_NAME);
-  } else {
-    if ((sign_enabled = cert && key && serial)) {
-      // Dynamic cert generation enabled. Initialize CA key, cert and serial
-      // To comply to openssl, key and cert file are opened as FILE*
-      FILE *fp = nullptr;
-      if ((fp = fopen(cert, "rt")) == nullptr) {
-        TSDebug(PLUGIN_NAME, "fopen() error is %d: %s for %s", errno, strerror(errno), cert);
-        TSError("[%s] Unable to initialize plugin. Failed to open ca cert.", PLUGIN_NAME);
-        return;
-      }
-      ca_cert_scoped.reset(PEM_read_X509(fp, nullptr, nullptr, nullptr));
-      fclose(fp);
-
-      if ((fp = fopen(key, "rt")) == nullptr) {
-        TSDebug(PLUGIN_NAME, "fopen() error is %d: %s for %s", errno, strerror(errno), key);
-        TSError("[%s] Unable to initialize plugin. Failed to open ca key.", PLUGIN_NAME);
-        return;
-      }
-      ca_pkey_scoped.reset(PEM_read_PrivateKey(fp, nullptr, nullptr, nullptr));
-      fclose(fp);
-
-      if (ca_pkey_scoped == nullptr || ca_cert_scoped == nullptr) {
-        TSDebug(PLUGIN_NAME, "PEM_read failed to read %s %s", ca_pkey_scoped ? "" : "pkey", ca_cert_scoped ? "" : "cert");
-        TSError("[%s] Unable to initialize plugin. Failed to read ca key/cert.", PLUGIN_NAME);
-        return;
-      }
-
-      // Read serial file
-      serial_file.open(serial, std::fstream::in | std::fstream::out);
-      if (!serial_file.is_open()) {
-        TSDebug(PLUGIN_NAME, "Failed to open serial file.");
-        TSError("[%s] Unable to initialize plugin. Failed to open serial.", PLUGIN_NAME);
-        return;
-      }
-      /// Initialize mutex and serial number
-      serial_mutex = TSMutexCreate();
-      ca_serial    = 0;
-
-      serial_file.seekg(0, serial_file.beg);
-      serial_file >> ca_serial;
-      if (serial_file.bad() || serial_file.fail()) {
-        ca_serial = 0;
-      }
-    }
-    TSDebug(PLUGIN_NAME, "Dynamic cert generation %s", sign_enabled ? "enabled" : "disabled");
-
-    /// Add global hooks
-    TSHttpHookAdd(TS_SSL_CERT_HOOK, cb_shadow);
+    TSError("[%s] unable to initialize plugin (disabled): failed to register plugin", PLUGIN_NAME);
+    return;
   }
 
+  if ((cb_shadow = TSContCreate(cert_retriever, nullptr)) == nullptr) {
+    TSError("[%s] unable to initialize plugin (disabled): failed to create shadow cert cb", PLUGIN_NAME);
+    return;
+  }
+
+  if (cert && key && serial) {
+    sign_enabled = true;
+
+    // Dynamic cert generation enabled. Initialize CA key, cert and serial
+    // To comply to openssl, key and cert file are opened as FILE*
+    FILE *fp = nullptr;
+    if ((fp = fopen(cert, "r")) == nullptr) {
+      Dbg(dbg_ctl, "fopen() error is %d: %s for %s", errno, strerror(errno), cert);
+      TSError("[%s] unable to initialize plugin: failed to open CA certificate '%s'", PLUGIN_NAME, cert);
+      return;
+    }
+    ca_cert_scoped.reset(PEM_read_X509(fp, nullptr, nullptr, nullptr));
+    fclose(fp);
+
+    if ((fp = fopen(key, "r")) == nullptr) {
+      Dbg(dbg_ctl, "fopen() error is %d: %s for %s", errno, strerror(errno), key);
+      TSError("[%s] unable to initialize plugin: failed to open CA key '%s'", PLUGIN_NAME, key);
+      return;
+    }
+    ca_pkey_scoped.reset(PEM_read_PrivateKey(fp, nullptr, nullptr, nullptr));
+    fclose(fp);
+
+    if (ca_pkey_scoped == nullptr || ca_cert_scoped == nullptr) {
+      Dbg(dbg_ctl, "PEM_read failed to read %s %s", ca_pkey_scoped ? "" : "pkey", ca_cert_scoped ? "" : "cert");
+      TSError("[%s] unable to initialize plugin: failed to parse ca key or certificate", PLUGIN_NAME);
+      return;
+    }
+
+    // Read serial file
+    serial_file.open(serial, std::fstream::in | std::fstream::out);
+    if (!serial_file.is_open()) {
+      Dbg(dbg_ctl, "failed to open serial file '%s'", serial);
+      TSError("[%s] unable to initialize plugin: failed to open serial file '%s'", PLUGIN_NAME, serial);
+      return;
+    }
+    /// Initialize mutex and serial number
+    serial_mutex = TSMutexCreate();
+    ca_serial    = 0;
+
+    serial_file.seekg(0, serial_file.beg);
+    serial_file >> ca_serial;
+    if (serial_file.bad() || serial_file.fail()) {
+      ca_serial = 0;
+    }
+  }
+
+  Dbg(dbg_ctl, "dynamic certificate generation %s", sign_enabled ? "enabled" : "disabled");
+
+  /// Add global hooks
+  TSHttpHookAdd(TS_SSL_CERT_HOOK, cb_shadow);
+
   return;
 }
