@@ -26,18 +26,20 @@
 namespace
 {
 struct _f {
-  const char *name;
+  const char    *name;
   ExpansionField field;
 };
-const std::array<_f, SSL_HEADERS_FIELD_MAX - 1> fields = {{
-  {"certificate", SSL_HEADERS_FIELD_CERTIFICATE},
-  {"subject", SSL_HEADERS_FIELD_SUBJECT},
-  {"issuer", SSL_HEADERS_FIELD_ISSUER},
-  {"serial", SSL_HEADERS_FIELD_SERIAL},
-  {"signature", SSL_HEADERS_FIELD_SIGNATURE},
-  {"notbefore", SSL_HEADERS_FIELD_NOTBEFORE},
-  {"notafter", SSL_HEADERS_FIELD_NOTAFTER},
-}};
+const std::array<_f, SSL_HEADERS_FIELD_MAX - 1> fields = {
+  {
+   {"certificate", SSL_HEADERS_FIELD_CERTIFICATE},
+   {"subject", SSL_HEADERS_FIELD_SUBJECT},
+   {"issuer", SSL_HEADERS_FIELD_ISSUER},
+   {"serial", SSL_HEADERS_FIELD_SERIAL},
+   {"signature", SSL_HEADERS_FIELD_SIGNATURE},
+   {"notbefore", SSL_HEADERS_FIELD_NOTBEFORE},
+   {"notafter", SSL_HEADERS_FIELD_NOTAFTER},
+   }
+};
 } // namespace
 
 bool
