@@ -52,6 +52,7 @@ handleFetchEvents(TSCont cont, TSEvent event, void *edata)
       TSHttpParser parser   = TSHttpParserCreate();
       TSMBuffer    hdr_buf  = TSMBufferCreate();
       TSMLoc       hdr_loc  = TSHttpHdrCreate(hdr_buf);
+
       TSHttpHdrTypeSet(hdr_buf, hdr_loc, TS_HTTP_TYPE_RESPONSE);
       if (TSHttpHdrParseResp(parser, hdr_buf, hdr_loc, &data_start, data_end) == TS_PARSE_DONE) {
         TSHttpTxnErrorBodySet(http_txn, TSstrdup(data_start), (data_end - data_start), nullptr);
@@ -120,7 +121,7 @@ OperatorSetConfig::initialize(Parser &p)
   _config = p.get_arg();
 
   if (TS_SUCCESS == TSHttpTxnConfigFind(_config.c_str(), _config.size(), &_key, &_type)) {
-    _value.set_value(p.get_value());
+    _value.set_value(p.get_value(), this);
   } else {
     _key = TS_CONFIG_NULL;
     TSError("[%s] no such records config: %s", PLUGIN_NAME, _config.c_str());
@@ -133,21 +134,21 @@ OperatorSetConfig::exec(const Resources &res) const
   if (TS_CONFIG_NULL != _key) {
     switch (_type) {
     case TS_RECORDDATATYPE_INT:
-      if (TS_SUCCESS == TSHttpTxnConfigIntSet(res.txnp, _key, _value.get_int_value())) {
+      if (TS_SUCCESS == TSHttpTxnConfigIntSet(res.state.txnp, _key, _value.get_int_value())) {
         Dbg(pi_dbg_ctl, "OperatorSetConfig::exec() invoked on %s=%d", _config.c_str(), _value.get_int_value());
       } else {
         Dbg(pi_dbg_ctl, "OperatorSetConfig::exec() invocation failed on %s=%d", _config.c_str(), _value.get_int_value());
       }
       break;
     case TS_RECORDDATATYPE_FLOAT:
-      if (TS_SUCCESS == TSHttpTxnConfigFloatSet(res.txnp, _key, _value.get_float_value())) {
+      if (TS_SUCCESS == TSHttpTxnConfigFloatSet(res.state.txnp, _key, _value.get_float_value())) {
         Dbg(pi_dbg_ctl, "OperatorSetConfig::exec() invoked on %s=%f", _config.c_str(), _value.get_float_value());
       } else {
         Dbg(pi_dbg_ctl, "OperatorSetConfig::exec() invocation failed on %s=%f", _config.c_str(), _value.get_float_value());
       }
       break;
     case TS_RECORDDATATYPE_STRING:
-      if (TS_SUCCESS == TSHttpTxnConfigStringSet(res.txnp, _key, _value.get_value().c_str(), _value.size())) {
+      if (TS_SUCCESS == TSHttpTxnConfigStringSet(res.state.txnp, _key, _value.get_value().c_str(), _value.size())) {
         Dbg(pi_dbg_ctl, "OperatorSetConfig::exec() invoked on %s=%s", _config.c_str(), _value.get_value().c_str());
       } else {
         Dbg(pi_dbg_ctl, "OperatorSetConfig::exec() invocation failed on %s=%s", _config.c_str(), _value.get_value().c_str());
@@ -167,7 +168,7 @@ OperatorSetStatus::initialize(Parser &p)
 {
   Operator::initialize(p);
 
-  _status.set_value(p.get_arg());
+  _status.set_value(p.get_arg(), this);
 
   if (nullptr == (_reason = TSHttpHdrReasonLookup(static_cast<TSHttpStatus>(_status.get_int_value())))) {
     TSError("[%s] unknown status %d", PLUGIN_NAME, _status.get_int_value());
@@ -205,7 +206,7 @@ OperatorSetStatus::exec(const Resources &res) const
     }
     break;
   default:
-    TSHttpTxnStatusSet(res.txnp, static_cast<TSHttpStatus>(_status.get_int_value()));
+    TSHttpTxnStatusSet(res.state.txnp, static_cast<TSHttpStatus>(_status.get_int_value()));
     break;
   }
 
@@ -220,7 +221,7 @@ OperatorSetStatusReason::initialize(Parser &p)
 {
   Operator::initialize(p);
 
-  _reason.set_value(p.get_arg());
+  _reason.set_value(p.get_arg(), this);
   require_resources(RSRC_CLIENT_RESPONSE_HEADERS);
   require_resources(RSRC_SERVER_RESPONSE_HEADERS);
 }
@@ -254,7 +255,7 @@ OperatorSetDestination::initialize(Parser &p)
   Operator::initialize(p);
 
   _url_qual = parse_url_qualifier(p.get_arg());
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
   require_resources(RSRC_CLIENT_REQUEST_HEADERS);
   require_resources(RSRC_SERVER_REQUEST_HEADERS);
 }
@@ -264,10 +265,10 @@ OperatorSetDestination::exec(const Resources &res) const
 {
   if (res._rri || (res.bufp && res.hdr_loc)) {
     std::string value;
+    TSMBuffer   bufp;
+    TSMLoc      url_m_loc;
 
     // Determine which TSMBuffer and TSMLoc to use
-    TSMBuffer bufp;
-    TSMLoc    url_m_loc;
     if (res._rri && !res.changed_url) {
       bufp      = res._rri->requestBufp;
       url_m_loc = res._rri->requestUrl;
@@ -480,8 +481,8 @@ OperatorSetRedirect::initialize(Parser &p)
 {
   Operator::initialize(p);
 
-  _status.set_value(p.get_arg());
-  _location.set_value(p.get_value());
+  _status.set_value(p.get_arg(), this);
+  _location.set_value(p.get_value(), this);
   auto status = _status.get_int_value();
   if (status < 300 || status > 399 || status == TS_HTTP_STATUS_NOT_MODIFIED) {
     TSError("[%s] unsupported redirect status %d", PLUGIN_NAME, status);
@@ -590,7 +591,7 @@ OperatorSetRedirect::exec(const Resources &res) const
         Dbg(pi_dbg_ctl, "Could not set Location field value to: %s", value.c_str());
       }
       // Set the new status.
-      TSHttpTxnStatusSet(res.txnp, static_cast<TSHttpStatus>(_status.get_int_value()));
+      TSHttpTxnStatusSet(res.state.txnp, static_cast<TSHttpStatus>(_status.get_int_value()));
       const_cast<Resources &>(res).changed_url = true;
       res._rri->redirect                       = 1;
     } else {
@@ -598,7 +599,7 @@ OperatorSetRedirect::exec(const Resources &res) const
       // Set the new status code and reason.
       TSHttpStatus status = static_cast<TSHttpStatus>(_status.get_int_value());
       TSHttpHdrStatusSet(res.bufp, res.hdr_loc, status);
-      EditRedirectResponse(res.txnp, value, status, res.bufp, res.hdr_loc);
+      EditRedirectResponse(res.state.txnp, value, status, res.bufp, res.hdr_loc);
     }
     Dbg(pi_dbg_ctl, "OperatorSetRedirect::exec() invoked with destination=%s and status code=%d", value.c_str(),
         _status.get_int_value());
@@ -625,7 +626,7 @@ OperatorSetTimeoutOut::initialize(Parser &p)
     TSError("[%s] unsupported timeout qualifier: %s", PLUGIN_NAME, p.get_arg().c_str());
   }
 
-  _timeout.set_value(p.get_value());
+  _timeout.set_value(p.get_value(), this);
 }
 
 bool
@@ -634,22 +635,22 @@ OperatorSetTimeoutOut::exec(const Resources &res) const
   switch (_type) {
   case TO_OUT_ACTIVE:
     Dbg(pi_dbg_ctl, "OperatorSetTimeoutOut::exec(active, %d)", _timeout.get_int_value());
-    TSHttpTxnActiveTimeoutSet(res.txnp, _timeout.get_int_value());
+    TSHttpTxnActiveTimeoutSet(res.state.txnp, _timeout.get_int_value());
     break;
 
   case TO_OUT_INACTIVE:
     Dbg(pi_dbg_ctl, "OperatorSetTimeoutOut::exec(inactive, %d)", _timeout.get_int_value());
-    TSHttpTxnNoActivityTimeoutSet(res.txnp, _timeout.get_int_value());
+    TSHttpTxnNoActivityTimeoutSet(res.state.txnp, _timeout.get_int_value());
     break;
 
   case TO_OUT_CONNECT:
     Dbg(pi_dbg_ctl, "OperatorSetTimeoutOut::exec(connect, %d)", _timeout.get_int_value());
-    TSHttpTxnConnectTimeoutSet(res.txnp, _timeout.get_int_value());
+    TSHttpTxnConnectTimeoutSet(res.state.txnp, _timeout.get_int_value());
     break;
 
   case TO_OUT_DNS:
     Dbg(pi_dbg_ctl, "OperatorSetTimeoutOut::exec(dns, %d)", _timeout.get_int_value());
-    TSHttpTxnDNSTimeoutSet(res.txnp, _timeout.get_int_value());
+    TSHttpTxnDNSTimeoutSet(res.state.txnp, _timeout.get_int_value());
     break;
   default:
     TSError("[%s] unsupported timeout", PLUGIN_NAME);
@@ -674,7 +675,7 @@ bool
 OperatorSkipRemap::exec(const Resources &res) const
 {
   Dbg(pi_dbg_ctl, "OperatorSkipRemap::exec() skipping remap: %s", _skip_remap ? "True" : "False");
-  TSHttpTxnCntlSet(res.txnp, TS_HTTP_CNTL_SKIP_REMAPPING, _skip_remap);
+  TSHttpTxnCntlSet(res.state.txnp, TS_HTTP_CNTL_SKIP_REMAPPING, _skip_remap);
   return true;
 }
 
@@ -704,7 +705,7 @@ OperatorAddHeader::initialize(Parser &p)
 {
   OperatorHeaders::initialize(p);
 
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
 }
 
 bool
@@ -741,7 +742,7 @@ OperatorSetHeader::initialize(Parser &p)
 {
   OperatorHeaders::initialize(p);
 
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
 }
 
 bool
@@ -799,7 +800,7 @@ OperatorSetBody::initialize(Parser &p)
 {
   Operator::initialize(p);
   // we want the arg since body only takes one value
-  _value.set_value(p.get_arg());
+  _value.set_value(p.get_arg(), this);
 }
 
 void
@@ -815,8 +816,11 @@ OperatorSetBody::exec(const Resources &res) const
   std::string value;
 
   _value.append_value(value, res);
-  char *msg = TSstrdup(_value.get_value().c_str());
-  TSHttpTxnErrorBodySet(res.txnp, msg, _value.size(), nullptr);
+  char *msg = nullptr;
+  if (!value.empty()) {
+    msg = TSstrdup(value.c_str());
+  }
+  TSHttpTxnErrorBodySet(res.state.txnp, msg, value.size(), nullptr);
   return true;
 }
 
@@ -898,7 +902,7 @@ void
 OperatorAddCookie::initialize(Parser &p)
 {
   OperatorCookies::initialize(p);
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
 }
 
 bool
@@ -944,7 +948,7 @@ void
 OperatorSetCookie::initialize(Parser &p)
 {
   OperatorCookies::initialize(p);
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
 }
 
 bool
@@ -1082,7 +1086,7 @@ OperatorSetConnDSCP::initialize(Parser &p)
 {
   Operator::initialize(p);
 
-  _ds_value.set_value(p.get_arg());
+  _ds_value.set_value(p.get_arg(), this);
 }
 
 void
@@ -1096,8 +1100,8 @@ OperatorSetConnDSCP::initialize_hooks()
 bool
 OperatorSetConnDSCP::exec(const Resources &res) const
 {
-  if (res.txnp) {
-    TSHttpTxnClientPacketDscpSet(res.txnp, _ds_value.get_int_value());
+  if (res.state.txnp) {
+    TSHttpTxnClientPacketDscpSet(res.state.txnp, _ds_value.get_int_value());
     Dbg(pi_dbg_ctl, "   Setting DSCP to %d", _ds_value.get_int_value());
   }
   return true;
@@ -1109,7 +1113,7 @@ OperatorSetConnMark::initialize(Parser &p)
 {
   Operator::initialize(p);
 
-  _ds_value.set_value(p.get_arg());
+  _ds_value.set_value(p.get_arg(), this);
 }
 
 void
@@ -1123,8 +1127,8 @@ OperatorSetConnMark::initialize_hooks()
 bool
 OperatorSetConnMark::exec(const Resources &res) const
 {
-  if (res.txnp) {
-    TSHttpTxnClientPacketMarkSet(res.txnp, _ds_value.get_int_value());
+  if (res.state.txnp) {
+    TSHttpTxnClientPacketMarkSet(res.state.txnp, _ds_value.get_int_value());
     Dbg(pi_dbg_ctl, "   Setting MARK to %d", _ds_value.get_int_value());
   }
   return true;
@@ -1149,7 +1153,7 @@ OperatorSetDebug::initialize_hooks()
 bool
 OperatorSetDebug::exec(const Resources &res) const
 {
-  TSHttpTxnCntlSet(res.txnp, TS_HTTP_CNTL_TXN_DEBUG, true);
+  TSHttpTxnCntlSet(res.state.txnp, TS_HTTP_CNTL_TXN_DEBUG, true);
   return true;
 }
 
@@ -1186,10 +1190,10 @@ bool
 OperatorSetHttpCntl::exec(const Resources &res) const
 {
   if (_flag) {
-    TSHttpTxnCntlSet(res.txnp, _cntl_qual, true);
+    TSHttpTxnCntlSet(res.state.txnp, _cntl_qual, true);
     Dbg(pi_dbg_ctl, "   Turning ON %s for transaction", HttpCntls[static_cast<size_t>(_cntl_qual)]);
   } else {
-    TSHttpTxnCntlSet(res.txnp, _cntl_qual, false);
+    TSHttpTxnCntlSet(res.state.txnp, _cntl_qual, false);
     Dbg(pi_dbg_ctl, "   Turning OFF %s for transaction", HttpCntls[static_cast<size_t>(_cntl_qual)]);
   }
   return true;
@@ -1241,7 +1245,7 @@ bool
 OperatorSetPluginCntl::exec(const Resources &res) const
 {
   PrivateSlotData private_data;
-  private_data.raw = reinterpret_cast<uint64_t>(TSUserArgGet(res.txnp, _txn_private_slot));
+  private_data.raw = reinterpret_cast<uint64_t>(TSUserArgGet(res.state.txnp, _txn_private_slot));
 
   switch (_name) {
   case PluginCtrl::TIMEZONE:
@@ -1253,7 +1257,7 @@ OperatorSetPluginCntl::exec(const Resources &res) const
   }
 
   Dbg(pi_dbg_ctl, "   Setting plugin control %d to %d", static_cast<int>(_name), _value);
-  TSUserArgSet(res.txnp, _txn_private_slot, reinterpret_cast<void *>(private_data.raw));
+  TSUserArgSet(res.state.txnp, _txn_private_slot, reinterpret_cast<void *>(private_data.raw));
 
   return true;
 }
@@ -1323,8 +1327,8 @@ OperatorRunPlugin::exec(const Resources &res) const
 {
   TSReleaseAssert(_plugin != nullptr);
 
-  if (res._rri && res.txnp) {
-    _plugin->doRemap(res.txnp, res._rri);
+  if (res._rri && res.state.txnp) {
+    _plugin->doRemap(res.state.txnp, res._rri);
   }
   return true;
 }
@@ -1335,7 +1339,7 @@ OperatorSetBodyFrom::initialize(Parser &p)
 {
   Operator::initialize(p);
   // we want the arg since body only takes one value
-  _value.set_value(p.get_arg());
+  _value.set_value(p.get_arg(), this);
   require_resources(RSRC_SERVER_RESPONSE_HEADERS);
   require_resources(RSRC_RESPONSE_STATUS);
 }
@@ -1349,7 +1353,7 @@ OperatorSetBodyFrom::initialize_hooks()
 bool
 OperatorSetBodyFrom::exec(const Resources &res) const
 {
-  if (TSHttpTxnIsInternal(res.txnp)) {
+  if (TSHttpTxnIsInternal(res.state.txnp)) {
     // If this is triggered by an internal transaction, a infinte loop may occur
     // It should only be triggered by the original transaction sent by the client
     Dbg(pi_dbg_ctl, "OperatorSetBodyFrom triggered by an internal transaction");
@@ -1360,9 +1364,9 @@ OperatorSetBodyFrom::exec(const Resources &res) const
   int  req_buf_size = 0;
   if (createRequestString(_value.get_value(), req_buf, &req_buf_size) == TS_SUCCESS) {
     TSCont fetchCont = TSContCreate(handleFetchEvents, TSMutexCreate());
-    TSContDataSet(fetchCont, static_cast<void *>(res.txnp));
+    TSContDataSet(fetchCont, static_cast<void *>(res.state.txnp));
 
-    TSHttpTxnHookAdd(res.txnp, TS_HTTP_TXN_CLOSE_HOOK, fetchCont);
+    TSHttpTxnHookAdd(res.state.txnp, TS_HTTP_TXN_CLOSE_HOOK, fetchCont);
 
     TSFetchEvent event_ids;
     event_ids.success_event_id = TS_EVENT_FETCHSM_SUCCESS;
@@ -1379,7 +1383,7 @@ OperatorSetBodyFrom::exec(const Resources &res) const
     // Forces original status code in event TSHttpTxnErrorBodySet changed
     // the code or another condition was set conflicting with this one.
     // Set here because res is the only structure that contains the original status code.
-    TSHttpTxnStatusSet(res.txnp, res.resp_status);
+    TSHttpTxnStatusSet(res.state.txnp, res.resp_status);
   } else {
     TSError(PLUGIN_NAME, "OperatorSetBodyFrom:exec:: Could not create request");
     return true;
@@ -1429,16 +1433,16 @@ OperatorSetStateFlag::initialize_hooks()
 bool
 OperatorSetStateFlag::exec(const Resources &res) const
 {
-  if (!res.txnp) {
+  if (!res.state.txnp) {
     TSError("[%s] OperatorSetStateFlag() failed. Transaction is null", PLUGIN_NAME);
     return false;
   }
 
   Dbg(pi_dbg_ctl, "   Setting state flag %d to %d", _flag_ix, _flag);
 
-  auto data = reinterpret_cast<uint64_t>(TSUserArgGet(res.txnp, _txn_slot));
+  auto data = reinterpret_cast<uint64_t>(TSUserArgGet(res.state.txnp, _txn_slot));
 
-  TSUserArgSet(res.txnp, _txn_slot, reinterpret_cast<void *>(_flag ? data | _mask : data & _mask));
+  TSUserArgSet(res.state.txnp, _txn_slot, reinterpret_cast<void *>(_flag ? data | _mask : data & _mask));
 
   return true;
 }
@@ -1455,7 +1459,7 @@ OperatorSetStateInt8::initialize(Parser &p)
     return;
   }
 
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
   if (!_value.has_conds()) {
     int v = _value.get_int_value();
 
@@ -1483,12 +1487,12 @@ OperatorSetStateInt8::initialize_hooks()
 bool
 OperatorSetStateInt8::exec(const Resources &res) const
 {
-  if (!res.txnp) {
+  if (!res.state.txnp) {
     TSError("[%s] OperatorSetStateInt8() failed. Transaction is null", PLUGIN_NAME);
     return false;
   }
 
-  auto ptr = reinterpret_cast<uint64_t>(TSUserArgGet(res.txnp, _txn_slot));
+  auto ptr = reinterpret_cast<uint64_t>(TSUserArgGet(res.state.txnp, _txn_slot));
   int  val = 0;
 
   if (_value.has_conds()) { // If there are conditions, we need to evaluate them, which gives us a string
@@ -1508,7 +1512,7 @@ OperatorSetStateInt8::exec(const Resources &res) const
   Dbg(pi_dbg_ctl, "   Setting state int8 %d to %d", _byte_ix, val);
   ptr &= ~STATE_INT8_MASKS[_byte_ix]; // Clear any old value
   ptr |= (static_cast<uint64_t>(val) << (NUM_STATE_FLAGS + _byte_ix * 8));
-  TSUserArgSet(res.txnp, _txn_slot, reinterpret_cast<void *>(ptr));
+  TSUserArgSet(res.state.txnp, _txn_slot, reinterpret_cast<void *>(ptr));
 
   return true;
 }
@@ -1525,7 +1529,7 @@ OperatorSetStateInt16::initialize(Parser &p)
     return;
   }
 
-  _value.set_value(p.get_value());
+  _value.set_value(p.get_value(), this);
   if (!_value.has_conds()) {
     int v = _value.get_int_value();
 
@@ -1553,12 +1557,12 @@ OperatorSetStateInt16::initialize_hooks()
 bool
 OperatorSetStateInt16::exec(const Resources &res) const
 {
-  if (!res.txnp) {
+  if (!res.state.txnp) {
     TSError("[%s] OperatorSetStateInt16() failed. Transaction is null", PLUGIN_NAME);
     return false;
   }
 
-  auto ptr = reinterpret_cast<uint64_t>(TSUserArgGet(res.txnp, _txn_slot));
+  auto ptr = reinterpret_cast<uint64_t>(TSUserArgGet(res.state.txnp, _txn_slot));
   int  val = 0;
 
   if (_value.has_conds()) { // If there are conditions, we need to evaluate them, which gives us a string
@@ -1578,7 +1582,7 @@ OperatorSetStateInt16::exec(const Resources &res) const
   Dbg(pi_dbg_ctl, "   Setting state int16 to %d", val);
   ptr &= ~STATE_INT16_MASK; // Clear any old value
   ptr |= (static_cast<uint64_t>(val) << 48);
-  TSUserArgSet(res.txnp, _txn_slot, reinterpret_cast<void *>(ptr));
+  TSUserArgSet(res.state.txnp, _txn_slot, reinterpret_cast<void *>(ptr));
 
   return true;
 }
