@@ -65,6 +65,12 @@ public:
     return _cond;
   }
 
+  bool
+  is_else() const
+  {
+    return _else;
+  }
+
   const std::string &
   get_op() const
   {
@@ -83,13 +89,6 @@ public:
     return _val;
   }
 
-  // Return a copy of the string, this implies RVO as well
-  std::string
-  copy_value() const
-  {
-    return _val;
-  }
-
   bool
   mod_exist(const std::string &m) const
   {
@@ -110,6 +109,7 @@ private:
   bool preprocess(std::vector<std::string> tokens);
 
   bool                     _cond     = false;
+  bool                     _else     = false;
   bool                     _empty    = false;
   char                    *_from_url = nullptr;
   char                    *_to_url   = nullptr;
