@@ -22,6 +22,7 @@
 */
 #include "ts/ts.h"
 #include "ts/remap.h"
+#include "ts/remap_version.h"
 
 #include <sys/types.h>
 #include <cstdio>
@@ -58,18 +59,20 @@ static const int MAX_SUBS  = 32; // No more than 32 substitution variables in th
 
 // Substitutions other than regex matches
 enum ExtraSubstitutions {
-  SUB_HOST       = 11,
-  SUB_FROM_HOST  = 12,
-  SUB_TO_HOST    = 13,
-  SUB_PORT       = 14,
-  SUB_SCHEME     = 15,
-  SUB_PATH       = 16,
-  SUB_QUERY      = 17,
-  SUB_MATRIX     = 18,
+  SUB_HOST      = 11,
+  SUB_FROM_HOST = 12,
+  SUB_TO_HOST   = 13,
+  SUB_PORT      = 14,
+  SUB_SCHEME    = 15,
+  SUB_PATH      = 16,
+  SUB_QUERY     = 17,
+  // 18 is unused, used to be matrix parameters
   SUB_CLIENT_IP  = 19,
   SUB_LOWER_PATH = 20,
 };
 
+static DbgCtl dbg_ctl{PLUGIN_NAME};
+
 ///////////////////////////////////////////////////////////////////////////////
 // Class holding one request URL's component, to simplify the code and
 // length calculations (we need all of them).
@@ -84,24 +87,21 @@ struct UrlComponents {
     host   = TSUrlHostGet(bufp, url, &host_len);
     path   = TSUrlPathGet(bufp, url, &path_len);
     query  = TSUrlHttpQueryGet(bufp, url, &query_len);
-    matrix = TSUrlHttpParamsGet(bufp, url, &matrix_len);
     port   = TSUrlPortGet(bufp, url);
 
-    url_len = scheme_len + host_len + path_len + query_len + matrix_len + 32;
+    url_len = scheme_len + host_len + path_len + query_len + 32;
   }
 
   const char *scheme = nullptr;
   const char *host   = nullptr;
   const char *path   = nullptr;
   const char *query  = nullptr;
-  const char *matrix = nullptr;
-  int port           = 0;
+  int         port   = 0;
 
   int scheme_len = 0;
   int host_len   = 0;
   int path_len   = 0;
   int query_len  = 0;
-  int matrix_len = 0;
 
   int url_len = 0; // Full length, of all components
 };
@@ -114,7 +114,7 @@ class RemapRegex
 public:
   ~RemapRegex()
   {
-    TSDebug(PLUGIN_NAME, "Calling destructor");
+    Dbg(dbg_ctl, "Calling destructor");
     TSfree(_rex_string);
     TSfree(_subst);
 
@@ -230,10 +230,10 @@ public:
   // Hold an overridable configurations
   struct Override {
     TSOverridableConfigKey key;
-    TSRecordDataType type;
-    TSRecordData data;
-    int data_len; // Used when data is a string
-    Override *next;
+    TSRecordDataType       type;
+    TSRecordData           data;
+    int                    data_len; // Used when data is a string
+    Override              *next;
   };
 
   Override *
@@ -245,17 +245,17 @@ public:
 private:
   char *_rex_string = nullptr;
   char *_subst      = nullptr;
-  int _subst_len    = 0;
-  int _num_subs     = -1;
-  int _hits         = 0;
-  int _options      = 0;
-  int _order        = -1;
+  int   _subst_len  = 0;
+  int   _num_subs   = -1;
+  int   _hits       = 0;
+  int   _options    = 0;
+  int   _order      = -1;
 
   bool _lowercase_substitutions = false;
 
-  pcre *_rex           = nullptr;
-  pcre_extra *_extra   = nullptr;
-  RemapRegex *_next    = nullptr;
+  pcre        *_rex    = nullptr;
+  pcre_extra  *_extra  = nullptr;
+  RemapRegex  *_next   = nullptr;
   TSHttpStatus _status = static_cast<TSHttpStatus>(0);
 
   int _active_timeout      = -1;
@@ -264,8 +264,8 @@ private:
   int _dns_timeout         = -1;
 
   Override *_first_override = nullptr;
-  int _sub_pos[MAX_SUBS];
-  int _sub_ix[MAX_SUBS];
+  int       _sub_pos[MAX_SUBS];
+  int       _sub_ix[MAX_SUBS];
 };
 
 bool
@@ -286,7 +286,7 @@ RemapRegex::initialize(const std::string &reg, const std::string &sub, const std
   // Parse options
   std::string::size_type start = opt.find_first_of('@');
   std::string::size_type pos1, pos2;
-  Override *last_override = nullptr;
+  Override              *last_override = nullptr;
 
   while (start != std::string::npos) {
     std::string opt_val;
@@ -325,8 +325,8 @@ RemapRegex::initialize(const std::string &reg, const std::string &sub, const std
       _dns_timeout = strtol(opt_val.c_str(), nullptr, 10);
     } else {
       TSOverridableConfigKey key;
-      TSRecordDataType type;
-      std::string opt_name = opt.substr(start, pos1 - start - 1);
+      TSRecordDataType       type;
+      std::string            opt_name = opt.substr(start, pos1 - start - 1);
 
       if (TS_SUCCESS == TSHttpTxnConfigFind(opt_name.c_str(), opt_name.length(), &key, &type)) {
         std::unique_ptr<Override> cur(new Override);
@@ -347,7 +347,7 @@ RemapRegex::initialize(const std::string &reg, const std::string &sub, const std
           TSError("[%s] configuration variable '%s' is of an unsupported type", PLUGIN_NAME, opt_name.c_str());
           return false;
         }
-        TSDebug(PLUGIN_NAME, "Overridable config %s=%s", opt_name.c_str(), opt_val.c_str());
+        Dbg(dbg_ctl, "Overridable config %s=%s", opt_name.c_str(), opt_val.c_str());
         cur->key  = key;
         cur->type = type;
         cur->next = nullptr;
@@ -373,7 +373,7 @@ int
 RemapRegex::compile(const char *&error, int &erroffset)
 {
   char *str;
-  int ccount;
+  int   ccount;
 
   // Initialize these in case they are not set.
   error     = "unknown error";
@@ -395,8 +395,8 @@ RemapRegex::compile(const char *&error, int &erroffset)
   }
 
   // POOMA - also dependent on actual stack size. Crashes with previous value of 2047,
-  _extra->match_limit_recursion = 1750;
-  _extra->flags |= PCRE_EXTRA_MATCH_LIMIT_RECURSION;
+  _extra->match_limit_recursion  = 1750;
+  _extra->flags                 |= PCRE_EXTRA_MATCH_LIMIT_RECURSION;
 
   if (pcre_fullinfo(_rex, _extra, PCRE_INFO_CAPTURECOUNT, &ccount) != 0) {
     error = "call to pcre_fullinfo() failed";
@@ -439,9 +439,6 @@ RemapRegex::compile(const char *&error, int &erroffset)
         case 'q':
           ix = SUB_QUERY;
           break;
-        case 'm':
-          ix = SUB_MATRIX;
-          break;
         case 'i':
           ix = SUB_CLIENT_IP;
           break;
@@ -456,9 +453,9 @@ RemapRegex::compile(const char *&error, int &erroffset)
           return -1;
         }
 
-        _sub_ix[_num_subs]  = ix;
-        _sub_pos[_num_subs] = (str - _subst);
-        str += 2;
+        _sub_ix[_num_subs]   = ix;
+        _sub_pos[_num_subs]  = (str - _subst);
+        str                 += 2;
         ++_num_subs;
       } else { // Not a valid substitution character, so just ignore it
         ++str;
@@ -482,8 +479,8 @@ RemapRegex::get_lengths(const int ovector[], int lengths[], TSRemapRequestInfo *
     int ix = _sub_ix[i];
 
     if (ix < 10) {
-      lengths[ix] = ovector[2 * ix + 1] - ovector[2 * ix]; // -1 - -1 == 0
-      len += lengths[ix];
+      lengths[ix]  = ovector[2 * ix + 1] - ovector[2 * ix]; // -1 - -1 == 0
+      len         += lengths[ix];
     } else {
       int tmp_len;
 
@@ -512,9 +509,6 @@ RemapRegex::get_lengths(const int ovector[], int lengths[], TSRemapRequestInfo *
       case SUB_QUERY:
         len += req_url->query_len;
         break;
-      case SUB_MATRIX:
-        len += req_url->matrix_len;
-        break;
       case SUB_CLIENT_IP:
         len += INET6_ADDRSTRLEN;
         break;
@@ -535,13 +529,13 @@ RemapRegex::substitute(char dest[], const char *src, const int ovector[], const
                        TSRemapRequestInfo *rri, UrlComponents *req_url, bool lowercase_substitutions)
 {
   if (_num_subs > 0) {
-    char *p1 = dest;
-    char *p2 = _subst;
-    int prev = 0;
+    char *p1   = dest;
+    char *p2   = _subst;
+    int   prev = 0;
 
     for (int i = 0; i < _num_subs; i++) {
       char *start = p1;
-      int ix      = _sub_ix[i];
+      int   ix    = _sub_ix[i];
 
       memcpy(p1, p2, _sub_pos[i] - prev);
       p1 += (_sub_pos[i] - prev);
@@ -549,9 +543,9 @@ RemapRegex::substitute(char dest[], const char *src, const int ovector[], const
         memcpy(p1, src + ovector[2 * ix], lengths[ix]);
         p1 += lengths[ix];
       } else {
-        char buff[INET6_ADDRSTRLEN];
+        char        buff[INET6_ADDRSTRLEN];
         const char *str = nullptr;
-        int len         = 0;
+        int         len = 0;
 
         switch (ix) {
         case SUB_HOST:
@@ -580,10 +574,6 @@ RemapRegex::substitute(char dest[], const char *src, const int ovector[], const
           str = req_url->query;
           len = req_url->query_len;
           break;
-        case SUB_MATRIX:
-          str = req_url->matrix;
-          len = req_url->matrix_len;
-          break;
         case SUB_CLIENT_IP:
           str = ats_ip_ntop(TSHttpTxnClientAddrGet(txnp), buff, INET6_ADDRSTRLEN);
           len = strlen(str);
@@ -597,8 +587,8 @@ RemapRegex::substitute(char dest[], const char *src, const int ovector[], const
           p1 += len;
         }
       }
-      p2 += (_sub_pos[i] - prev + 2);
-      prev = _sub_pos[i] + 2;
+      p2   += (_sub_pos[i] - prev + 2);
+      prev  = _sub_pos[i] + 2;
 
       if (lowercase_substitutions == true || ix == SUB_LOWER_PATH) {
         while (start < p1) {
@@ -609,8 +599,8 @@ RemapRegex::substitute(char dest[], const char *src, const int ovector[], const
     }
 
     memcpy(p1, p2, _subst_len - (p2 - _subst));
-    p1 += _subst_len - (p2 - _subst);
-    *p1 = 0; // Make sure it's NULL terminated (for safety).
+    p1  += _subst_len - (p2 - _subst);
+    *p1  = 0; // Make sure it's NULL terminated (for safety).
     return p1 - dest;
   } else {
     memcpy(dest, _subst, _subst_len + 1); // No substitutions in the string, copy it all
@@ -624,17 +614,16 @@ RemapRegex::substitute(char dest[], const char *src, const int ovector[], const
 struct RemapInstance {
   RemapInstance() : filename("unknown") {}
 
-  RemapRegex *first  = nullptr;
-  RemapRegex *last   = nullptr;
-  bool pristine_url  = false;
-  bool profile       = false;
-  bool method        = false;
-  bool query_string  = true;
-  bool matrix_params = false;
-  bool host          = false;
-  int hits           = 0;
-  int misses         = 0;
-  int failures       = 0;
+  RemapRegex *first        = nullptr;
+  RemapRegex *last         = nullptr;
+  bool        pristine_url = false;
+  bool        profile      = false;
+  bool        method       = false;
+  bool        query_string = true;
+  bool        host         = false;
+  int         hits         = 0;
+  int         misses       = 0;
+  int         failures     = 0;
   std::string filename;
 };
 
@@ -644,18 +633,8 @@ struct RemapInstance {
 TSReturnCode
 TSRemapInit(TSRemapInterface *api_info, char *errbuf, int errbuf_size)
 {
-  if (!api_info) {
-    strncpy(errbuf, "[tsremap_init] - Invalid TSRemapInterface argument", errbuf_size - 1);
-    return TS_ERROR;
-  }
-
-  if (api_info->tsremap_version < TSREMAP_VERSION) {
-    snprintf(errbuf, errbuf_size, "[TSRemapInit] - Incorrect API version %ld.%ld", api_info->tsremap_version >> 16,
-             (api_info->tsremap_version & 0xffff));
-    return TS_ERROR;
-  }
-
-  TSDebug(PLUGIN_NAME, "Plugin is successfully initialized");
+  CHECK_REMAP_API_COMPATIBILITY(api_info, errbuf, errbuf_size);
+  Dbg(dbg_ctl, "Plugin is successfully initialized");
   return TS_SUCCESS;
 }
 
@@ -668,8 +647,8 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf ATS_UNUSE
   RemapInstance *ri = new RemapInstance();
 
   std::ifstream f;
-  int lineno = 0;
-  int count  = 0;
+  int           lineno = 0;
+  int           count  = 0;
 
   *ih = (void *)ri;
   if (ri == nullptr) {
@@ -696,10 +675,6 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf ATS_UNUSE
       ri->query_string = true;
     } else if (strncmp(argv[i], "no-query-string", 15) == 0) {
       ri->query_string = false;
-    } else if (strncmp(argv[i], "matrix-parameters", 17) == 0) {
-      ri->matrix_params = true;
-    } else if (strncmp(argv[i], "no-matrix-parameters", 20) == 0) {
-      ri->matrix_params = false;
     } else if (strncmp(argv[i], "host", 4) == 0) {
       ri->host = true;
     } else if (strncmp(argv[i], "no-host", 7) == 0) {
@@ -718,7 +693,7 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf ATS_UNUSE
     ri->filename = argv[2];
   } else {
     // Relative path. Make it relative to the configuration directory.
-    ri->filename = TSConfigDirGet();
+    ri->filename  = TSConfigDirGet();
     ri->filename += "/";
     ri->filename += argv[2];
   }
@@ -733,10 +708,10 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf ATS_UNUSE
     TSError("[%s] unable to open %s", PLUGIN_NAME, (ri->filename).c_str());
     return TS_ERROR;
   }
-  TSDebug(PLUGIN_NAME, "Loading regular expressions from %s", (ri->filename).c_str());
+  Dbg(dbg_ctl, "Loading regular expressions from %s", (ri->filename).c_str());
 
   while (!f.eof()) {
-    std::string line, regex, subst, options;
+    std::string            line, regex, subst, options;
     std::string::size_type pos1, pos2;
 
     getline(f, line);
@@ -793,7 +768,7 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf ATS_UNUSE
     }
 
     const char *error;
-    int erroffset;
+    int         erroffset;
     if (cur->compile(error, erroffset) < 0) {
       std::ostringstream oss;
       oss << '[' << PLUGIN_NAME << "] PCRE failed in " << (ri->filename).c_str() << " (line " << lineno << ')';
@@ -808,7 +783,7 @@ TSRemapNewInstance(int argc, char *argv[], void **ih, char * /* errbuf ATS_UNUSE
       }
       TSError("%s", oss.str().c_str());
     } else {
-      TSDebug(PLUGIN_NAME, "Added regex=%s with subs=%s and options `%s'", regex.c_str(), subst.c_str(), options.c_str());
+      Dbg(dbg_ctl, "Added regex=%s with subs=%s and options `%s'", regex.c_str(), subst.c_str(), options.c_str());
       cur->set_order(++count);
       auto tmp = cur.get();
       if (ri->first == nullptr) {
@@ -833,18 +808,17 @@ void
 TSRemapDeleteInstance(void *ih)
 {
   RemapInstance *ri = static_cast<RemapInstance *>(ih);
-  RemapRegex *re;
-  RemapRegex *tmp;
+  RemapRegex    *re;
+  RemapRegex    *tmp;
 
   if (ri->profile) {
-    char now[64];
+    char             now[64];
     const ink_time_t tim = time(nullptr);
 
     if (ink_ctime_r(&tim, now)) {
       now[strlen(now) - 1] = '\0';
     } else {
-      memcpy(now, "unknown time", 12);
-      *(now + 12) = '\0';
+      strncpy(now, "unknown time", sizeof(now));
     }
 
     fprintf(stderr, "[%s]: Profiling information for regex_remap file `%s':\n", now, (ri->filename).c_str());
@@ -892,15 +866,15 @@ TSRemapStatus
 TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
 {
   if (nullptr == ih) {
-    TSDebug(PLUGIN_NAME, "Falling back to default URL on regex remap without rules");
+    Dbg(dbg_ctl, "Falling back to default URL on regex remap without rules");
     return TSREMAP_NO_REMAP;
   }
   RemapInstance *ri = static_cast<RemapInstance *>(ih);
 
   struct SrcUrl {
     TSMBuffer bufp;
-    TSMLoc loc;
-    bool bad;
+    TSMLoc    loc;
+    bool      bad;
   };
 
   const SrcUrl src_url([=]() -> SrcUrl {
@@ -925,19 +899,19 @@ TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
   UrlComponents req_url;
   req_url.populate(src_url.bufp, src_url.loc);
 
-  int ovector[OVECCOUNT];
-  int lengths[OVECCOUNT / 2 + 1];
-  int dest_len;
-  TSRemapStatus retval = TSREMAP_DID_REMAP;
-  RemapRegex *re       = ri->first;
-  int match_len        = 0;
-  char *match_buf;
+  int           ovector[OVECCOUNT];
+  int           lengths[OVECCOUNT / 2 + 1];
+  int           dest_len;
+  TSRemapStatus retval    = TSREMAP_DID_REMAP;
+  RemapRegex   *re        = ri->first;
+  int           match_len = 0;
+  char         *match_buf;
 
   match_buf = static_cast<char *>(alloca(req_url.url_len + 32));
 
   if (ri->method) { // Prepend the URI path or URL with the HTTP method
-    TSMBuffer mBuf;
-    TSMLoc reqHttpHdrLoc;
+    TSMBuffer   mBuf;
+    TSMLoc      reqHttpHdrLoc;
     const char *method;
 
     // Note that Method can not be longer than 16 bytes, or we'll simply truncate it
@@ -965,19 +939,13 @@ TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
     match_len += (req_url.path_len);
   }
 
-  if (ri->matrix_params && req_url.matrix && req_url.matrix_len > 0) {
-    *(match_buf + match_len) = ';';
-    memcpy(match_buf + match_len + 1, req_url.matrix, req_url.matrix_len);
-    match_len += (req_url.matrix_len + 1);
-  }
-
   if (ri->query_string && req_url.query && req_url.query_len > 0) {
     *(match_buf + match_len) = '?';
     memcpy(match_buf + match_len + 1, req_url.query, req_url.query_len);
     match_len += (req_url.query_len + 1);
   }
   match_buf[match_len] = '\0'; // NULL terminate the match string
-  TSDebug(PLUGIN_NAME, "Target match string is `%s'", match_buf);
+  Dbg(dbg_ctl, "Target match string is `%s'", match_buf);
 
   // Apply the regular expressions, in order. First one wins.
   while (re) {
@@ -988,24 +956,24 @@ TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
 
       // Set timeouts
       if (re->active_timeout_option() > (-1)) {
-        TSDebug(PLUGIN_NAME, "Setting active timeout to %d", re->active_timeout_option());
+        Dbg(dbg_ctl, "Setting active timeout to %d", re->active_timeout_option());
         TSHttpTxnActiveTimeoutSet(txnp, re->active_timeout_option());
       }
       if (re->no_activity_timeout_option() > (-1)) {
-        TSDebug(PLUGIN_NAME, "Setting no activity timeout to %d", re->no_activity_timeout_option());
+        Dbg(dbg_ctl, "Setting no activity timeout to %d", re->no_activity_timeout_option());
         TSHttpTxnNoActivityTimeoutSet(txnp, re->no_activity_timeout_option());
       }
       if (re->connect_timeout_option() > (-1)) {
-        TSDebug(PLUGIN_NAME, "Setting connect timeout to %d", re->connect_timeout_option());
+        Dbg(dbg_ctl, "Setting connect timeout to %d", re->connect_timeout_option());
         TSHttpTxnConnectTimeoutSet(txnp, re->connect_timeout_option());
       }
       if (re->dns_timeout_option() > (-1)) {
-        TSDebug(PLUGIN_NAME, "Setting DNS timeout to %d", re->dns_timeout_option());
+        Dbg(dbg_ctl, "Setting DNS timeout to %d", re->dns_timeout_option());
         TSHttpTxnDNSTimeoutSet(txnp, re->dns_timeout_option());
       }
       bool lowercase_substitutions = false;
       if (re->lowercase_substitutions_option() == true) {
-        TSDebug(PLUGIN_NAME, "Setting lowercasing substitutions on");
+        Dbg(dbg_ctl, "Setting lowercasing substitutions on");
         lowercase_substitutions = true;
       }
 
@@ -1015,15 +983,15 @@ TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
         switch (override->type) {
         case TS_RECORDDATATYPE_INT:
           TSHttpTxnConfigIntSet(txnp, override->key, override->data.rec_int);
-          TSDebug(PLUGIN_NAME, "Setting config id %d to `%" PRId64 "'", override->key, override->data.rec_int);
+          Dbg(dbg_ctl, "Setting config id %d to `%" PRId64 "'", override->key, override->data.rec_int);
           break;
         case TS_RECORDDATATYPE_FLOAT:
           TSHttpTxnConfigFloatSet(txnp, override->key, override->data.rec_float);
-          TSDebug(PLUGIN_NAME, "Setting config id %d to `%f'", override->key, override->data.rec_float);
+          Dbg(dbg_ctl, "Setting config id %d to `%f'", override->key, override->data.rec_float);
           break;
         case TS_RECORDDATATYPE_STRING:
           TSHttpTxnConfigStringSet(txnp, override->key, override->data.rec_string, override->data_len);
-          TSDebug(PLUGIN_NAME, "Setting config id %d to `%s'", override->key, override->data.rec_string);
+          Dbg(dbg_ctl, "Setting config id %d to `%s'", override->key, override->data.rec_string);
           break;
         default:
           break; // Error ?
@@ -1043,9 +1011,9 @@ TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
         dest     = static_cast<char *>(alloca(new_len + 8));
         dest_len = re->substitute(dest, match_buf, ovector, lengths, txnp, rri, &req_url, lowercase_substitutions);
 
-        TSDebug(PLUGIN_NAME, "New URL is estimated to be %d bytes long, or less", new_len);
-        TSDebug(PLUGIN_NAME, "New URL is %s (length %d)", dest, dest_len);
-        TSDebug(PLUGIN_NAME, "    matched rule %d [%s]", re->order(), re->regex());
+        Dbg(dbg_ctl, "New URL is estimated to be %d bytes long, or less", new_len);
+        Dbg(dbg_ctl, "New URL is %s (length %d)", dest, dest_len);
+        Dbg(dbg_ctl, "    matched rule %d [%s]", re->order(), re->regex());
 
         // Check for a quick response, if the status option is set
         if (re->status_option() > 0) {
@@ -1057,7 +1025,7 @@ TSRemapDoRemap(void *ih, TSHttpTxn txnp, TSRemapRequestInfo *rri)
             break;
           }
 
-          TSDebug(PLUGIN_NAME, "Redirecting URL, status=%d", re->status_option());
+          Dbg(dbg_ctl, "Redirecting URL, status=%d", re->status_option());
           TSHttpTxnStatusSet(txnp, re->status_option());
           rri->redirect = 1;
         }
