@@ -21,13 +21,14 @@
   limitations under the License.
  */
 
+#include "tscore/ink_config.h"
+
 #include <cstdio>
 #include <cstdlib>
 #include <memory>
 #include <ts/ts.h>
 #include <unistd.h>
 #include <netinet/in.h>
-#include <netinet/tcp.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <getopt.h>
@@ -38,32 +39,35 @@
 #include <sys/time.h>
 #include <arpa/inet.h>
 
-#include "tscore/ink_defs.h"
 #include "tscore/ParseRules.h"
 
 #if defined(TCP_INFO) && defined(HAVE_STRUCT_TCP_INFO)
 #define TCPI_PLUGIN_SUPPORTED 1
 #endif
 
-#define TCPI_HOOK_SSN_START 0x01u
-#define TCPI_HOOK_TXN_START 0x02u
+#define TCPI_HOOK_SSN_START     0x01u
+#define TCPI_HOOK_TXN_START     0x02u
 #define TCPI_HOOK_SEND_RESPONSE 0x04u
-#define TCPI_HOOK_SSN_CLOSE 0x08u
-#define TCPI_HOOK_TXN_CLOSE 0x10u
+#define TCPI_HOOK_TXN_CLOSE     0x10u
 
 // Log format headers. These are emitted once at the start of a log file. Note that we
 // carefully order the fields so the field ordering is compatible. This lets you change
-// the verbosity without breaking a perser that is moderately robust.
-static const char *tcpi_headers[] = {
-  "timestamp event client server rtt",
-  "timestamp event client server rtt rttvar last_sent last_recv "
-  "snd_cwnd snd_ssthresh rcv_ssthresh unacked sacked lost retrans fackets all_retrans",
+// the verbosity without breaking a parser that is moderately robust.
+static const char *tcpi_headers[] = {"timestamp event client server rtt",
+                                     "timestamp event client server rtt rttvar last_sent last_recv snd_cwnd "
+                                     "snd_ssthresh rcv_ssthresh unacked sacked lost retrans fackets all_retrans"
+// Additional information from linux's linux/tcp.h appended here
+#if HAVE_STRUCT_TCP_INFO_TCPI_DATA_SEGS_OUT
+                                     " data_segs_in data_segs_out"
+#endif
 };
 
+static DbgCtl dbg_ctl{"tcpinfo"};
+
 struct Config {
-  int sample             = 1000;
-  unsigned int log_level = 1;
-  TSTextLogObject log    = nullptr;
+  int             sample    = 1000;
+  unsigned int    log_level = 1;
+  TSTextLogObject log       = nullptr;
 
   ~Config()
   {
@@ -74,8 +78,8 @@ struct Config {
 };
 
 union const_sockaddr_ptr {
-  const struct sockaddr *sa;
-  const struct sockaddr_in *in;
+  const struct sockaddr     *sa;
+  const struct sockaddr_in  *in;
   const struct sockaddr_in6 *in6;
 
   const void *
@@ -97,28 +101,28 @@ union const_sockaddr_ptr {
 static void
 log_tcp_info(Config *config, const char *event_name, TSHttpSsn ssnp)
 {
-  char client_str[INET6_ADDRSTRLEN];
-  char server_str[INET6_ADDRSTRLEN];
+  char               client_str[INET6_ADDRSTRLEN];
+  char               server_str[INET6_ADDRSTRLEN];
   const_sockaddr_ptr client_addr;
   const_sockaddr_ptr server_addr;
 
   struct tcp_info info;
-  socklen_t tcp_info_len = sizeof(info);
-  int fd;
+  socklen_t       tcp_info_len = sizeof(info);
+  int             fd;
 
   TSReleaseAssert(config->log != nullptr);
 
   if (ssnp != nullptr && (TSHttpSsnClientFdGet(ssnp, &fd) != TS_SUCCESS || fd <= 0)) {
-    TSDebug("tcpinfo", "error getting the client socket fd from ssn");
+    Dbg(dbg_ctl, "error getting the client socket fd from ssn");
     return;
   }
   if (ssnp == nullptr) {
-    TSDebug("tcpinfo", "ssn is not specified");
+    Dbg(dbg_ctl, "ssn is not specified");
     return;
   }
 
   if (getsockopt(fd, IPPROTO_TCP, TCP_INFO, &info, &tcp_info_len) != 0) {
-    TSDebug("tcpinfo", "getsockopt(%d, TCP_INFO) failed: %s", fd, strerror(errno));
+    Dbg(dbg_ctl, "getsockopt(%d, TCP_INFO) failed: %s", fd, strerror(errno));
     return;
   }
 
@@ -136,12 +140,21 @@ log_tcp_info(Config *config, const char *event_name, TSHttpSsn ssnp)
   TSReturnCode ret;
 
   if (config->log_level == 2) {
-#if !defined(freebsd) || defined(__GLIBC__)
+#if HAVE_STRUCT_TCP_INFO_TCPI_DATA_SEGS_OUT
+    // Linux 4.6+
+    ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u %u %u %u", event_name, client_str,
+                               server_str, info.tcpi_rtt, info.tcpi_rttvar, info.tcpi_last_data_sent, info.tcpi_last_data_recv,
+                               info.tcpi_snd_cwnd, info.tcpi_snd_ssthresh, info.tcpi_rcv_ssthresh, info.tcpi_unacked,
+                               info.tcpi_sacked, info.tcpi_lost, info.tcpi_retrans, info.tcpi_fackets, info.tcpi_total_retrans,
+                               info.tcpi_data_segs_in, info.tcpi_data_segs_out);
+#elif HAVE_STRUCT_TCP_INFO_TCPI_TOTAL_RETRANS
+    // Linux 2.6.12+
     ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u %u", event_name, client_str, server_str,
                                info.tcpi_rtt, info.tcpi_rttvar, info.tcpi_last_data_sent, info.tcpi_last_data_recv,
                                info.tcpi_snd_cwnd, info.tcpi_snd_ssthresh, info.tcpi_rcv_ssthresh, info.tcpi_unacked,
                                info.tcpi_sacked, info.tcpi_lost, info.tcpi_retrans, info.tcpi_fackets, info.tcpi_total_retrans);
-#else
+#elif HAVE_STRUCT_TCP_INFO___TCPI_RETRANS
+    // FreeBSD 6.0+
     ret = TSTextLogObjectWrite(config->log, "%s %s %s %u %u %u %u %u %u %u %u %u %u %u %u %u", event_name, client_str, server_str,
                                info.tcpi_rtt, info.tcpi_rttvar, info.__tcpi_last_data_sent, info.tcpi_last_data_recv,
                                info.tcpi_snd_cwnd, info.tcpi_snd_ssthresh, info.__tcpi_rcv_ssthresh, info.__tcpi_unacked,
@@ -171,41 +184,37 @@ log_tcp_info(Config * /* config */, const char * /* event_name */, TSHttpSsn /*
 static int
 tcp_info_hook(TSCont contp, TSEvent event, void *edata)
 {
-  TSHttpSsn ssnp = nullptr;
-  TSHttpTxn txnp = nullptr;
-  int random     = 0;
-  Config *config = (Config *)TSContDataGet(contp);
+  TSHttpSsn ssnp   = nullptr;
+  TSHttpTxn txnp   = nullptr;
+  int       random = 0;
+  Config   *config = static_cast<Config *>(TSContDataGet(contp));
 
   const char *event_name;
   switch (event) {
   case TS_EVENT_HTTP_SSN_START:
-    ssnp       = (TSHttpSsn)edata;
+    ssnp       = static_cast<TSHttpSsn>(edata);
     event_name = "ssn_start";
     break;
   case TS_EVENT_HTTP_TXN_START:
-    txnp       = (TSHttpTxn)edata;
+    txnp       = static_cast<TSHttpTxn>(edata);
     ssnp       = TSHttpTxnSsnGet(txnp);
     event_name = "txn_start";
     break;
   case TS_EVENT_HTTP_TXN_CLOSE:
-    txnp       = (TSHttpTxn)edata;
+    txnp       = static_cast<TSHttpTxn>(edata);
     ssnp       = TSHttpTxnSsnGet(txnp);
     event_name = "txn_close";
     break;
   case TS_EVENT_HTTP_SEND_RESPONSE_HDR:
-    txnp       = (TSHttpTxn)edata;
+    txnp       = static_cast<TSHttpTxn>(edata);
     ssnp       = TSHttpTxnSsnGet(txnp);
     event_name = "send_resp_hdr";
     break;
-  case TS_EVENT_HTTP_SSN_CLOSE:
-    ssnp       = (TSHttpSsn)edata;
-    event_name = "ssn_close";
-    break;
   default:
     return 0;
   }
 
-  TSDebug("tcpinfo", "logging hook called for %s (%s) with log object %p", TSHttpEventNameLookup(event), event_name, config->log);
+  Dbg(dbg_ctl, "logging hook called for %s (%s) with log object %p", TSHttpEventNameLookup(event), event_name, config->log);
 
   if (config->log == nullptr) {
     goto done;
@@ -220,11 +229,11 @@ tcp_info_hook(TSCont contp, TSEvent event, void *edata)
   if (config->sample < 1000) {
     // coverity[dont_call]
     random = rand() % 1000;
-    TSDebug("tcpinfo", "random: %d, config->sample: %d", random, config->sample);
+    Dbg(dbg_ctl, "random: %d, config->sample: %d", random, config->sample);
   }
 
   if (random < config->sample) {
-    TSDebug("tcpinfo", "sampling TCP metrics for %s event", event_name);
+    Dbg(dbg_ctl, "sampling TCP metrics for %s event", event_name);
     log_tcp_info(config, event_name, ssnp);
   }
 
@@ -254,7 +263,7 @@ parse_unsigned(const char *str, unsigned long &lval)
   }
 
   if (end && *end != '\0') {
-    // Not all charaters consumed.
+    // Not all characters consumed.
     return false;
   }
 
@@ -266,15 +275,20 @@ static unsigned
 parse_hook_list(const char *hook_list)
 {
   unsigned mask = 0;
-  char *tok;
-  char *str;
-  char *last;
+  char    *tok;
+  char    *str;
+  char    *last;
 
   const struct hookmask {
     const char *name;
-    unsigned mask;
-  } hooks[] = {{"ssn_start", TCPI_HOOK_SSN_START}, {"txn_start", TCPI_HOOK_TXN_START}, {"send_resp_hdr", TCPI_HOOK_SEND_RESPONSE},
-               {"ssn_close", TCPI_HOOK_SSN_CLOSE}, {"txn_close", TCPI_HOOK_TXN_CLOSE}, {nullptr, 0u}};
+    unsigned    mask;
+  } hooks[] = {
+    {"ssn_start",     TCPI_HOOK_SSN_START    },
+    {"txn_start",     TCPI_HOOK_TXN_START    },
+    {"send_resp_hdr", TCPI_HOOK_SEND_RESPONSE},
+    {"txn_close",     TCPI_HOOK_TXN_CLOSE    },
+    {nullptr,         0u                     }
+  };
 
   str = TSstrdup(hook_list);
 
@@ -283,8 +297,8 @@ parse_hook_list(const char *hook_list)
 
     for (const struct hookmask *m = hooks; m->name != nullptr; ++m) {
       if (strcmp(m->name, tok) == 0) {
-        mask |= m->mask;
-        match = true;
+        mask  |= m->mask;
+        match  = true;
         break;
       }
     }
@@ -301,32 +315,32 @@ parse_hook_list(const char *hook_list)
 void
 TSPluginInit(int argc, const char *argv[])
 {
-  static const char usage[] = "tcpinfo.so [--log-file=PATH] [--log-level=LEVEL] [--hooks=LIST] [--sample-rate=COUNT] "
-                              "[--rolling-enabled=VALUE] [--rolling-offset-hr=HOUR] [--rolling-interval-sec=SECONDS] "
-                              "[--rolling-size=MB]";
+  static const char          usage[]    = "tcpinfo.so [--log-file=PATH] [--log-level=LEVEL] [--hooks=LIST] [--sample-rate=COUNT] "
+                                          "[--rolling-enabled=VALUE] [--rolling-offset-hr=HOUR] [--rolling-interval-sec=SECONDS] "
+                                          "[--rolling-size=MB]";
   static const struct option longopts[] = {
-    {const_cast<char *>("sample-rate"), required_argument, nullptr, 'r'},
-    {const_cast<char *>("log-file"), required_argument, nullptr, 'f'},
-    {const_cast<char *>("log-level"), required_argument, nullptr, 'l'},
-    {const_cast<char *>("hooks"), required_argument, nullptr, 'h'},
-    {const_cast<char *>("rolling-enabled"), required_argument, nullptr, 'e'},
-    {const_cast<char *>("rolling-offset-hr"), required_argument, nullptr, 'H'},
+    {const_cast<char *>("sample-rate"),          required_argument, nullptr, 'r'},
+    {const_cast<char *>("log-file"),             required_argument, nullptr, 'f'},
+    {const_cast<char *>("log-level"),            required_argument, nullptr, 'l'},
+    {const_cast<char *>("hooks"),                required_argument, nullptr, 'h'},
+    {const_cast<char *>("rolling-enabled"),      required_argument, nullptr, 'e'},
+    {const_cast<char *>("rolling-offset-hr"),    required_argument, nullptr, 'H'},
     {const_cast<char *>("rolling-interval-sec"), required_argument, nullptr, 'S'},
-    {const_cast<char *>("rolling-size"), required_argument, nullptr, 'M'},
-    {nullptr, 0, nullptr, 0},
+    {const_cast<char *>("rolling-size"),         required_argument, nullptr, 'M'},
+    {nullptr,                                    0,                 nullptr, 0  },
   };
 
   TSPluginRegistrationInfo info;
-  auto config          = std::make_unique<Config>();
-  const char *filename = "tcpinfo";
-  TSCont cont;
-  unsigned int hooks                = 0;
-  unsigned int rolling_enabled      = 1;
-  unsigned int rolling_interval_sec = 86400;
-  unsigned int rolling_offset_hr    = 0;
-  unsigned int rolling_size         = 1024;
-  unsigned int i                    = 0;
-  char *endptr;
+  auto                     config   = std::make_unique<Config>();
+  const char              *filename = "tcpinfo";
+  TSCont                   cont;
+  unsigned int             hooks                = 0;
+  int                      rolling_enabled      = -1;
+  unsigned int             rolling_interval_sec = 86400;
+  unsigned int             rolling_offset_hr    = 0;
+  unsigned int             rolling_size         = 1024;
+  unsigned int             i                    = 0;
+  char                    *endptr;
 
   info.plugin_name   = (char *)"tcpinfo";
   info.vendor_name   = (char *)"Apache Software Foundation";
@@ -339,7 +353,7 @@ TSPluginInit(int argc, const char *argv[])
   for (;;) {
     unsigned long lval;
 
-    switch (getopt_long(argc, (char *const *)argv, "r:f:l:h:e:H:S:M:", longopts, nullptr)) {
+    switch (getopt_long(argc, const_cast<char *const *>(argv), "r:f:l:h:e:H:S:M:", longopts, nullptr)) {
     case 'r':
       if (parse_unsigned(optarg, lval)) {
         config->sample = atoi(optarg);
@@ -363,7 +377,8 @@ TSPluginInit(int argc, const char *argv[])
     case 'e':
       i = strtoul(optarg, &endptr, 10);
       if (*endptr != '\0' || i > 3) {
-        TSError("[tcpinfo] invalid rolling-enabled argument, '%s', using default of %d", optarg, rolling_enabled);
+        TSError("[tcpinfo] invalid rolling-enabled argument, '%s', using the system's proxy.config.log.rolling_enabled value",
+                optarg);
       } else {
         rolling_enabled = i;
       }
@@ -405,23 +420,29 @@ init:
   TSError("[tcpinfo] TCP metrics are not supported on this platform");
 #endif
 
-  TSDebug("tcpinfo", "sample: %d", config->sample);
-  TSDebug("tcpinfo", "log filename: %s", filename);
-  TSDebug("tcpinfo", "log_level: %u", config->log_level);
-  TSDebug("tcpinfo", "hook mask: 0x%x", hooks);
+  Dbg(dbg_ctl, "sample: %d", config->sample);
+  Dbg(dbg_ctl, "log filename: %s", filename);
+  Dbg(dbg_ctl, "log_level: %u", config->log_level);
+  Dbg(dbg_ctl, "rolling_enabled: %d", rolling_enabled);
+  Dbg(dbg_ctl, "hook mask: 0x%x", hooks);
 
   if (TSTextLogObjectCreate(filename, TS_LOG_MODE_ADD_TIMESTAMP, &config->log) != TS_SUCCESS) {
     TSError("[tcpinfo] failed to create log file '%s'", filename);
     return;
   }
-  if (TSTextLogObjectRollingEnabledSet(config->log, rolling_enabled) != TS_SUCCESS) {
-    TSError("[tcpinfo] failed to enable log file rolling to: '%d'", rolling_enabled);
-    return;
+  if (rolling_enabled == -1) {
+    // The user either did not provide a value or the value they provided was
+    // invalid.
+    Dbg(dbg_ctl, "Using system default value of proxy.config.log.rolling_enabled ");
   } else {
-    TSTextLogObjectRollingIntervalSecSet(config->log, rolling_interval_sec);
-    TSTextLogObjectRollingOffsetHrSet(config->log, rolling_offset_hr);
-    TSTextLogObjectRollingSizeMbSet(config->log, rolling_size);
+    if (TSTextLogObjectRollingEnabledSet(config->log, rolling_enabled) != TS_SUCCESS) {
+      TSError("[tcpinfo] failed to enable log file rolling to: '%d'", rolling_enabled);
+      return;
+    }
   }
+  TSTextLogObjectRollingIntervalSecSet(config->log, rolling_interval_sec);
+  TSTextLogObjectRollingOffsetHrSet(config->log, rolling_offset_hr);
+  TSTextLogObjectRollingSizeMbSet(config->log, rolling_size);
 
   TSTextLogObjectHeaderSet(config->log, tcpi_headers[config->log_level - 1]);
 
@@ -430,26 +451,21 @@ init:
 
   if (hooks & TCPI_HOOK_SSN_START) {
     TSHttpHookAdd(TS_HTTP_SSN_START_HOOK, cont);
-    TSDebug("tcpinfo", "added hook to the start of the TCP connection");
+    Dbg(dbg_ctl, "added hook to the start of the TCP connection");
   }
 
   if (hooks & TCPI_HOOK_TXN_START) {
     TSHttpHookAdd(TS_HTTP_TXN_START_HOOK, cont);
-    TSDebug("tcpinfo", "added hook to the start of the transaction");
+    Dbg(dbg_ctl, "added hook to the start of the transaction");
   }
 
   if (hooks & TCPI_HOOK_SEND_RESPONSE) {
     TSHttpHookAdd(TS_HTTP_SEND_RESPONSE_HDR_HOOK, cont);
-    TSDebug("tcpinfo", "added hook to the sending of the headers");
-  }
-
-  if (hooks & TCPI_HOOK_SSN_CLOSE) {
-    TSHttpHookAdd(TS_HTTP_SSN_CLOSE_HOOK, cont);
-    TSDebug("tcpinfo", "added hook to the close of the TCP connection");
+    Dbg(dbg_ctl, "added hook to the sending of the headers");
   }
 
   if (hooks & TCPI_HOOK_TXN_CLOSE) {
     TSHttpHookAdd(TS_HTTP_TXN_CLOSE_HOOK, cont);
-    TSDebug("tcpinfo", "added hook to the close of the transaction");
+    Dbg(dbg_ctl, "added hook to the close of the transaction");
   }
 }
