@@ -58,7 +58,7 @@ DbgCtl dbg_ctl_dir_lookaside{"dir_lookaside"};
 
 // Globals
 
-ClassAllocator<OpenDirEntry> openDirEntryAllocator("openDirEntry");
+ClassAllocator<OpenDirEntry, false> openDirEntryAllocator("openDirEntry");
 
 // OpenDir
 
@@ -987,7 +987,7 @@ Lrestart:
       goto Ldone;
     }
 
-    int    headerlen = ROUND_TO_STORE_BLOCK(sizeof(StripteHeaderFooter));
+    int    headerlen = ROUND_TO_STORE_BLOCK(sizeof(StripeHeaderFooter));
     size_t dirlen    = stripe->dirlen();
     if (!writepos) {
       // start
