@@ -90,11 +90,11 @@ is_addr_query(int qtype)
 }
 } // namespace
 
-DNSProcessor             dnsProcessor;
-ClassAllocator<DNSEntry> dnsEntryAllocator("dnsEntryAllocator");
+DNSProcessor                    dnsProcessor;
+ClassAllocator<DNSEntry, false> dnsEntryAllocator("dnsEntryAllocator");
 // Users are expected to free these entries in short order!
 // We could page align this buffer to enable page flipping for recv...
-ClassAllocator<HostEnt> dnsBufAllocator("dnsBufAllocator", 2);
+ClassAllocator<HostEnt, false> dnsBufAllocator("dnsBufAllocator", 2);
 
 //
 // Function Prototypes
