@@ -39,7 +39,7 @@
 
 using namespace swoc::literals;
 
-ClassAllocator<SocksEntry> socksAllocator("socksAllocator");
+ClassAllocator<SocksEntry, false> socksAllocator("socksAllocator");
 
 namespace
 {
