@@ -20,7 +20,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
  */
-#include <fstream>
+#include "iocore/eventsystem/EventProcessor.h"
 #include "tsutil/ts_bw_format.h"
 #include "proxy/HostStatus.h"
 #include "iocore/eventsystem/Tasks.h"
@@ -28,6 +28,9 @@
 #include "mgmt/rpc/jsonrpc/JsonRPC.h"
 #include "shared/rpc/RPCRequests.h"
 
+#include <fstream>
+#include <utility>
+
 namespace
 {
 const std::string STATUS_LIST_KEY{"statusList"};
@@ -170,7 +173,7 @@ HostStatus::loadFromPersistentStore()
         const YAML::Node &host     = *it;
         std::string       hostName = host[HOST_NAME_KEY].as<std::string>();
         std::string       status   = host[STATUS_KEY].as<std::string>();
-        HostStatRec       h(status);
+        HostStatRec       h(std::move(status));
         loadRecord(hostName, h);
       }
     } catch (std::exception const &ex) {
@@ -211,7 +214,7 @@ HostStatus::setHostStatus(const std::string_view name, TSHostStatus status, cons
       host_stat = it->second;
     } else {
       host_stat = static_cast<HostStatRec *>(ats_malloc(sizeof(HostStatRec)));
-      bzero(host_stat, sizeof(HostStatRec));
+      bzero(static_cast<void *>(host_stat), sizeof(HostStatRec));
       hosts_statuses.emplace(name, host_stat);
     }
     if (reason & Reason::ACTIVE) {
