@@ -38,6 +38,7 @@
 #include "proxy/PoolableSession.h"
 
 #include "iocore/utils/Machine.h"
+#include "tsutil/DbgCtl.h"
 
 using namespace std::literals;
 
@@ -420,6 +421,8 @@ HttpTransactHeaders::downgrade_request(bool *origin_server_keep_alive, HTTPHdr *
 void
 HttpTransactHeaders::generate_and_set_squid_codes(HTTPHdr *header, char *via_string, HttpTransact::SquidLogInfo *squid_codes)
 {
+  Dbg(dbg_ctl_http_transact_headers, "via_string=%s", via_string);
+
   SquidLogCode       log_code      = SQUID_LOG_EMPTY;
   SquidHierarchyCode hier_code     = SQUID_HIER_EMPTY;
   SquidHitMissCode   hit_miss_code = SQUID_HIT_RESERVED;
@@ -477,6 +480,8 @@ HttpTransactHeaders::generate_and_set_squid_codes(HTTPHdr *header, char *via_str
       } else {
         if (via_string[VIA_CACHE_RESULT] == VIA_IN_CACHE_STALE && via_string[VIA_SERVER_RESULT] == VIA_SERVER_NOT_MODIFIED) {
           log_code = SQUID_LOG_TCP_REFRESH_HIT;
+        } else if (via_string[VIA_CACHE_RESULT] == VIA_IN_CACHE_STALE && via_string[VIA_SERVER_RESULT] == VIA_SERVER_ERROR) {
+          log_code = SQUID_LOG_TCP_REF_FAIL_HIT;
         } else {
           log_code = SQUID_LOG_TCP_IMS_MISS;
         }
