@@ -30,6 +30,7 @@
 
 ****************************************************************************/
 
+#include "iocore/cache/Cache.h"
 #include "proxy/http/HttpConfig.h"
 #include "proxy/http/HttpTunnel.h"
 #include "proxy/http/HttpSM.h"
@@ -37,7 +38,6 @@
 
 // inkcache
 #include "../../iocore/cache/P_CacheInternal.h"
-#include "iocore/cache/CacheVC.h"
 
 #include "tscore/ParseRules.h"
 #include "tscore/ink_memory.h"
@@ -183,9 +183,10 @@ ChunkedHandler::read_size()
           }
         } else {
           // We are done parsing size
-          if ((num_digits == 0 || running_sum < 0) ||       /* Bogus chunk size */
-              (!ParseRules::is_wslfcr(*tmp) && *tmp != ';') /* Unexpected character */
-          ) {
+          const auto is_bogus_chunk_size   = (num_digits == 0 || running_sum < 0);
+          const auto is_rfc_compliant_char = (ParseRules::is_ws(*tmp) || ParseRules::is_cr(*tmp) || *tmp == ';');
+          const auto is_acceptable_lf      = (ParseRules::is_lf(*tmp) && !strict_chunk_parsing);
+          if (is_bogus_chunk_size || (!is_rfc_compliant_char && !is_acceptable_lf)) {
             state = CHUNK_READ_ERROR;
             done  = true;
             break;
@@ -1142,7 +1143,7 @@ HttpTunnel::producer_run(HttpTunnelProducer *p)
       producer_handler(HTTP_TUNNEL_EVENT_PRECOMPLETE, p);
     } else {
       if (read_start_pos > 0) {
-        p->read_vio = ((CacheVC *)p->vc)->do_io_pread(this, producer_n, p->read_buffer, read_start_pos);
+        p->read_vio = static_cast<CacheVConnection *>(p->vc)->do_io_pread(this, producer_n, p->read_buffer, read_start_pos);
       } else {
         Dbg(dbg_ctl_http_tunnel, "Start read vio %" PRId64 " bytes", producer_n);
         p->read_vio = p->vc->do_io_read(this, producer_n, p->read_buffer);
