@@ -40,8 +40,8 @@
 #define PreWarmSMDbg(fmt, ...)  Dbg(dbg_ctl_prewarm_sm, "[%p] " fmt, this, ##__VA_ARGS__);
 #define PreWarmSMVDbg(fmt, ...) Dbg(dbg_ctl_v_prewarm_sm, "[%p] " fmt, this, ##__VA_ARGS__);
 
-ClassAllocator<PreWarmSM> preWarmSMAllocator("preWarmSMAllocator");
-PreWarmManager            prewarmManager;
+ClassAllocator<PreWarmSM, false> preWarmSMAllocator("preWarmSMAllocator");
+PreWarmManager                   prewarmManager;
 
 namespace
 {
