@@ -49,7 +49,7 @@ DbgCtl dbg_ctl_http2_stream{"http2_stream"};
 #define Http2StreamDebug(fmt, ...) \
   SsnDbg(_proxy_ssn, dbg_ctl_http2_stream, "[%" PRId64 "] [%u] " fmt, _proxy_ssn->connection_id(), this->get_id(), ##__VA_ARGS__);
 
-ClassAllocator<Http2Stream, true> http2StreamAllocator("http2StreamAllocator");
+ClassAllocator<Http2Stream> http2StreamAllocator("http2StreamAllocator");
 
 Http2Stream::Http2Stream(ProxySession *session, Http2StreamId sid, ssize_t initial_peer_rwnd, ssize_t initial_local_rwnd,
                          bool registered_stream)
