@@ -37,8 +37,12 @@ TEST_CASE("AtomicBit Atomic test")
   // test the atomicity and isolation of operations
   uint32_t bit_storage = 0;
 
-  auto job_set   = [&bit_storage](int idx) { AtomicBit{(uint8_t *)&bit_storage + (idx / 8), (uint8_t)(1 << (idx % 8))} = 1; };
-  auto job_clear = [&bit_storage](int idx) { AtomicBit{(uint8_t *)&bit_storage + (idx / 8), (uint8_t)(1 << (idx % 8))} = 0; };
+  auto job_set = [&bit_storage](int idx) {
+    AtomicBit{reinterpret_cast<uint8_t *>(&bit_storage) + (idx / 8), static_cast<uint8_t>(1 << (idx % 8))} = true;
+  };
+  auto job_clear = [&bit_storage](int idx) {
+    AtomicBit{reinterpret_cast<uint8_t *>(&bit_storage) + (idx / 8), static_cast<uint8_t>(1 << (idx % 8))} = false;
+  };
 
   std::thread jobs[32];
 
@@ -46,8 +50,8 @@ TEST_CASE("AtomicBit Atomic test")
   for (int i = 0; i < 32; i++) {
     jobs[i] = std::thread(job_set, i);
   }
-  for (int i = 0; i < 32; i++) {
-    jobs[i].join();
+  for (auto &job : jobs) {
+    job.join();
   }
   REQUIRE(bit_storage == 0xffffffff);
 
@@ -55,8 +59,8 @@ TEST_CASE("AtomicBit Atomic test")
   for (int i = 0; i < 32; i++) {
     jobs[i] = std::thread(job_clear, i);
   }
-  for (int i = 0; i < 32; i++) {
-    jobs[i].join();
+  for (auto &job : jobs) {
+    job.join();
   }
   REQUIRE(bit_storage == 0);
 }
@@ -117,9 +121,6 @@ TEST_CASE("Create A", "")
   ext::details::areFieldsFinalized() = true;
   a_ptr                              = ext::create<A>();
   CHECK(Extendible<A>::schema.no_instances() == false);
-}
-TEST_CASE("Delete A", "")
-{
   delete a_ptr;
   CHECK(Extendible<A>::schema.no_instances());
 }
@@ -127,9 +128,6 @@ TEST_CASE("Create B", "")
 {
   a_ptr = ext::create<B>();
   CHECK(Extendible<A>::schema.no_instances() == false);
-}
-TEST_CASE("Delete B", "")
-{
   delete a_ptr;
   CHECK(Extendible<A>::schema.no_instances());
 }
@@ -167,7 +165,7 @@ TEST_CASE("Extendible Memory Allocations", "")
   //    0   1   2   3   4   5   6
   //[ EA*,  a,  b,EC*,  c, EA, EC]
   //
-  uint16_t *mem = (uint16_t *)&x;
+  uint16_t *mem = reinterpret_cast<uint16_t *>(&x);
   CHECK(memDelta(&x, &x.a) == w * 1);
   CHECK(memDelta(&x, &x.b) == w * 2);
   CHECK(memDelta(&x, &x.c) == w * 4);
@@ -217,7 +215,7 @@ TEST_CASE("Extendible Pointer Math", "")
   CHECK(ext::viewFormat(x) == format);
 
   ext::FieldId<A, bool> a_bit;
-  ext::FieldId<A, int> a_int;
+  ext::FieldId<A, int>  a_int;
   static_assert(std::is_same<decltype(ext::get(x, a_bit)), bool>::value);
   static_assert(std::is_same<decltype(ext::get(x, a_int)), int const &>::value);
   delete &x;
@@ -246,7 +244,7 @@ struct Derived : Extendible<Derived> {
   static const string
   testFormat()
   {
-    const size_t intenal_size = sizeof(Derived) - sizeof(ext::Extendible<Derived>::short_ptr_t);
+    const size_t      intenal_size = sizeof(Derived) - sizeof(ext::Extendible<Derived>::short_ptr_t);
     std::stringstream format;
     format << "\n                      7Derived | EXT  |     1b |##" << string(intenal_size, '_') << "#"
            << "\n                      7Derived | BASE | " << setw(5) << intenal_size << "b |__" << string(intenal_size, '#')
@@ -266,7 +264,7 @@ DerivedExtalloc()
 void
 DerivedExtFree(void *ptr)
 {
-  delete (Derived *)ptr;
+  delete static_cast<Derived *>(ptr);
 }
 
 ExtFieldContext
@@ -289,12 +287,12 @@ DerivedExtfieldFind(char const *field_name)
 // something to store more complex than an int
 struct testField {
   std::array<uint8_t, 5> arr;
-  static int alive;
+  static int             alive;
   testField()
   {
     uint8_t x = 1;
     for (uint8_t &a : arr) {
-      a = x;
+      a  = x;
       x *= 2;
     }
     alive++;
@@ -324,9 +322,9 @@ TEST_CASE("Extendible", "")
   printf("\nsizeof(string) = %lu", sizeof(std::string));
   printf("\nsizeof(Derived) = %lu", sizeof(Derived));
 
-  ext::FieldId<Derived, bool> bit_a, bit_b, bit_c;
+  ext::FieldId<Derived, bool>             bit_a, bit_b, bit_c;
   ext::FieldId<Derived, std::atomic<int>> int_a, int_b, int_c;
-  Derived *ptr;
+  Derived                                *ptr;
 
   // test cases:
   //[constructor] [operator] [type] [access] [capacity] [modifier] [operation] [compare] [find]
@@ -388,12 +386,12 @@ TEST_CASE("Extendible", "")
   INFO("test bit field");
   {
     shared_ptr<Derived> sptr{ext::create<Derived>()};
-    Derived &ref = *sptr;
+    Derived            &ref = *sptr;
 
     CHECK(ext::viewFormat(ref) == Derived::testFormat());
 
     AtomicBit bitref = ext::set(ref, bit_a);
-    bitref           = 1;
+    bitref           = true;
     CHECK(bitref == true);
     bitref = true;
     CHECK(bitref == true);
@@ -404,7 +402,7 @@ TEST_CASE("Extendible", "")
   INFO("test bit packing")
   {
     struct size_test {
-      string s;
+      string   s;
       uint16_t i;
     };
 
@@ -425,16 +423,16 @@ TEST_CASE("Extendible", "")
     ext::details::areFieldsFinalized() = true;
 
     shared_ptr<Derived> sptr(ext::create<Derived>());
-    Derived &ref = *sptr;
+    Derived            &ref = *sptr;
     CHECK(ext::viewFormat(ref) == Derived::testFormat());
     using Catch::Matchers::Contains;
     REQUIRE_THAT(ext::toString(ref), Contains("bit_a: 0"));
     REQUIRE_THAT(ext::toString(ref), Contains("bit_b: 0"));
     REQUIRE_THAT(ext::toString(ref), Contains("bit_c: 0"));
 
-    ext::set(ref, bit_a) = 1;
-    ext::set(ref, bit_b) = 0;
-    ext::set(ref, bit_c) = 1;
+    ext::set(ref, bit_a) = true;
+    ext::set(ref, bit_b) = false;
+    ext::set(ref, bit_c) = true;
     CHECK(ext::get(ref, bit_a) == true);
     CHECK(ext::get(ref, bit_b) == false);
     CHECK(ext::get(ref, bit_c) == true);
@@ -454,7 +452,7 @@ TEST_CASE("Extendible", "")
     CHECK(ext::sizeOf<Derived>() == expected_size);
 
     shared_ptr<Derived> sptr(ext::create<Derived>());
-    Derived &ref = *sptr;
+    Derived            &ref = *sptr;
     CHECK(ext::get(ref, int_a) == 0);
     CHECK(ext::get(ref, int_b) == 0);
     ++ext::set(ref, int_a);
@@ -502,15 +500,15 @@ TEST_CASE("Extendible C API")
     void *d = DerivedExtalloc();
     REQUIRE(d != nullptr);
 
-    ExtFieldContext cf_a = DerivedExtfieldFind("cf_a");
-    uint8_t *data8       = (uint8_t *)ExtFieldPtr(d, cf_a);
+    ExtFieldContext cf_a  = DerivedExtfieldFind("cf_a");
+    uint8_t        *data8 = static_cast<uint8_t *>(ExtFieldPtr(d, cf_a));
 
     CHECK(data8[0] == 0);
     ink_atomic_increment(&data8[0], 1);
     data8[1] = 5;
     data8[2] = 7;
 
-    uint32_t *data32 = (uint32_t *)ExtFieldPtr(d, cf_a);
+    uint32_t *data32 = static_cast<uint32_t *>(ExtFieldPtr(d, cf_a));
     CHECK(*data32 == 0x00070501);
     DerivedExtFree(d);
   }
