@@ -126,15 +126,10 @@ struct RegexMatches::_MatchData {
 //----------------------------------------------------------------------------
 RegexMatches::RegexMatches(uint32_t size)
 {
-  pcre2_general_context *ctx =
-    pcre2_general_context_create(&RegexMatches::malloc, [](void *, void *) -> void {}, static_cast<void *>(this));
+  pcre2_general_context *ctx = pcre2_general_context_create(&RegexMatches::malloc, &RegexMatches::free, static_cast<void *>(this));
 
   pcre2_match_data *match_data = pcre2_match_data_create(size, ctx);
-  if (match_data == nullptr) {
-    // buffer was too small, allocate from heap
-    debug_assert_message(false, "RegexMatches data buffer too small, increase the buffer size in Regex.h");
-    match_data = pcre2_match_data_create(size, RegexContext::get_instance()->get_general_context());
-  }
+  debug_assert_message(match_data, "Failed to allocate pcre2 match data from custom context");
 
   _MatchData::set(_match_data, match_data);
 }
@@ -152,8 +147,23 @@ RegexMatches::malloc(size_t size, void *caller)
     return ptr;
   }
 
-  // return nullptr if buffer is too small
-  return nullptr;
+  return ::malloc(size);
+}
+
+void
+RegexMatches::free(void *p, void *caller)
+{
+  auto *matches = static_cast<RegexMatches *>(caller);
+
+  // Call free for any p outside _buffer
+  // If the pcre2 context requests more data than fits in our builtin buffer, we will call malloc
+  // to fulfil that request.
+  // !his checks for any pointers outside of our buffer in order to free that memory up.
+  //
+  // nullptr is outside of our buffer, but its ok to call ::free with nullptr.
+  if (!(p >= matches->_buffer && p < matches->_buffer + sizeof(matches->_buffer))) {
+    ::free(p);
+  }
 }
 
 //----------------------------------------------------------------------------
