@@ -25,6 +25,6 @@ t = Test.AddTestRun("Test traffic server started properly")
 t.StillRunningAfter = Test.Processes.ts
 
 p = t.Processes.Default
-t.MakeCurlCommand("http://127.0.0.1:{0}".format(ts.Variables.port))
+t.MakeCurlCommand("http://127.0.0.1:{0}".format(ts.Variables.port), ts=ts)
 p.ReturnCode = 0
 p.StartBefore(Test.Processes.ts)
