@@ -54,7 +54,8 @@ class BackgroundFillTest:
 
             self.ts[name].Disk.records_config.update(
                 {
-                    "proxy.config.http.server_ports": f"{self.ts[name].Variables.port} {self.ts[name].Variables.ssl_port}:ssl",
+                    "proxy.config.http.server_ports":
+                        f"{self.ts[name].Variables.port} {self.ts[name].Variables.ssl_port}:ssl {self.ts[name].Variables.uds_path}",
                     "proxy.config.http.background_fill_active_timeout": "0",
                     "proxy.config.http.background_fill_completed_threshold": "0.0",
                     "proxy.config.http.cache.required_headers": 0,  # Force cache
@@ -71,6 +72,8 @@ class BackgroundFillTest:
                     "proxy.config.diags.debug.tags": "http",
                 })
 
+            self.ts[name].Disk.plugin_config.AddLine('xdebug.so --enable=x-cache')
+
             if name == 'for_httpbin' or name == 'default':
                 self.ts[name].Disk.remap_config.AddLines([
                     f"map / http://127.0.0.1:{self.httpbin.Variables.Port}",
@@ -109,13 +112,13 @@ class BackgroundFillTest:
         tr.MakeCurlCommandMulti(
             f"""
 {{curl}} -X PURGE --http1.1 -vs http://127.0.0.1:{self.ts['for_httpbin'].Variables.port}/drip?duration=4;
-timeout 2 {{curl}} --http1.1 -vs http://127.0.0.1:{self.ts['for_httpbin'].Variables.port}/drip?duration=4;
-sleep 4;
-{{curl}} --http1.1 -vs http://127.0.0.1:{self.ts['for_httpbin'].Variables.port}/drip?duration=4
-""")
+timeout 1 {{curl}} --http1.1 -vs http://127.0.0.1:{self.ts['for_httpbin'].Variables.port}/drip?duration=4;
+sleep 5;
+{{curl}} --http1.1 -vs http://127.0.0.1:{self.ts['for_httpbin'].Variables.port}/drip?duration=4 -H "x-debug: x-cache"
+""",
+            ts=self.ts['for_httpbin'])
         tr.Processes.Default.ReturnCode = 0
-        tr.Processes.Default.Streams.stderr = Testers.Any(
-            "gold/background_fill_0_stderr_H.gold", "gold/background_fill_0_stderr_W.gold")
+        tr.Processes.Default.Streams.stderr = "gold/background_fill_0_stderr_H.gold"
         self.__checkProcessAfter(tr)
 
     def __testCase1(self):
@@ -127,13 +130,13 @@ sleep 4;
         tr.MakeCurlCommandMulti(
             f"""
 {{curl}} -X PURGE --http1.1 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4;
-timeout 3 {{curl}} --http1.1 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4;
+timeout 1 {{curl}} --http1.1 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4;
 sleep 5;
-{{curl}} --http1.1 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4
-""")
+{{curl}} --http1.1 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4 -H "x-debug: x-cache"
+""",
+            ts=self.ts['for_httpbin'])
         tr.Processes.Default.ReturnCode = 0
-        tr.Processes.Default.Streams.stderr = Testers.Any(
-            "gold/background_fill_1_stderr_H.gold", "gold/background_fill_1_stderr_W.gold")
+        tr.Processes.Default.Streams.stderr = "gold/background_fill_1_stderr_H.gold"
         self.__checkProcessAfter(tr)
 
     def __testCase2(self):
@@ -145,13 +148,13 @@ sleep 5;
         tr.MakeCurlCommandMulti(
             f"""
 {{curl}} -X PURGE --http2 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4;
-timeout 3 {{curl}} --http2 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4;
+timeout 1 {{curl}} --http2 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4;
 sleep 5;
-{{curl}} --http2 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4
-""")
+{{curl}} --http2 -vsk https://127.0.0.1:{self.ts['for_httpbin'].Variables.ssl_port}/drip?duration=4 -H "x-debug: x-cache"
+""",
+            ts=self.ts['for_httpbin'])
         tr.Processes.Default.ReturnCode = 0
-        tr.Processes.Default.Streams.stderr = Testers.Any(
-            "gold/background_fill_2_stderr_H.gold", "gold/background_fill_2_stderr_W.gold")
+        tr.Processes.Default.Streams.stderr = "gold/background_fill_2_stderr_H.gold"
         self.__checkProcessAfter(tr)
 
     def __testCase3(self):
@@ -164,17 +167,17 @@ sleep 5;
             "pv_client",
             "replay/bg_fill.yaml",
             http_ports=[self.ts['for_pv'].Variables.port],
-            https_ports=[self.ts['for_pv'].Variables.ssl_port],
-            other_args='--thread-limit 1')
+            https_ports=[self.ts['for_pv'].Variables.ssl_port])
         tr.Processes.Default.ReturnCode = 0
         tr.Processes.Default.Streams.stdout = "gold/background_fill_3_stdout.gold"
         self.__checkProcessAfter(tr)
 
     def run(self):
         self.__testCase0()
-        self.__testCase1()
-        self.__testCase2()
-        self.__testCase3()
+        if not Condition.CurlUsingUnixDomainSocket():
+            self.__testCase1()
+            self.__testCase2()
+            self.__testCase3()
 
 
 BackgroundFillTest().run()
