@@ -50,7 +50,8 @@ objectid = uuid.uuid4()
 tr = Test.AddTestRun()
 tr.MakeCurlCommand(
     '"http://127.0.0.1:{0}/default/cache/10/{1}" -H "x-debug: x-cache,x-cache-key,via,x-cache-generation" --verbose'.format(
-        ts.Variables.port, objectid))
+        ts.Variables.port, objectid),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.StartBefore(Test.Processes.ts)
 tr.Processes.Default.Streams.All = "gold/miss_default-1.gold"
@@ -59,7 +60,8 @@ tr.Processes.Default.Streams.All = "gold/miss_default-1.gold"
 tr = Test.AddTestRun()
 tr.MakeCurlCommand(
     '"http://127.0.0.1:{0}/default/cache/10/{1}" -H "x-debug: x-cache,x-cache-key,via,x-cache-generation" --verbose'.format(
-        ts.Variables.port, objectid))
+        ts.Variables.port, objectid),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = "gold/hit_default-1.gold"
 
@@ -76,7 +78,8 @@ tr.DelayStart = 15  # delay start of test run to allow previous command to take
 # create a new traffic_ctrl call and the environment
 tr.MakeCurlCommand(
     '"http://127.0.0.1:{0}/default/cache/10/{1}" -H "x-debug: x-cache,x-cache-key,via,x-cache-generation" --verbose'.format(
-        ts.Variables.port, objectid))
+        ts.Variables.port, objectid),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = "gold/miss_default77.gold"
 
@@ -84,7 +87,8 @@ tr.Processes.Default.Streams.All = "gold/miss_default77.gold"
 tr = Test.AddTestRun()
 tr.MakeCurlCommand(
     '"http://127.0.0.1:{0}/default/cache/10/{1}" -H "x-debug: x-cache,x-cache-key,via,x-cache-generation" --verbose'.format(
-        ts.Variables.port, objectid))
+        ts.Variables.port, objectid),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = "gold/hit_default77.gold"
 
@@ -92,6 +96,7 @@ tr.Processes.Default.Streams.All = "gold/hit_default77.gold"
 tr = Test.AddTestRun()
 tr.MakeCurlCommand(
     '"http://127.0.0.1:{0}/default/cache/10/{1}" -H "x-debug: x-cache,x-cache-key,via,x-cache-generation" --verbose'.format(
-        ts.Variables.port, objectid))
+        ts.Variables.port, objectid),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = "gold/hit_default77.gold"
