@@ -20,6 +20,7 @@ from typing import Union
 
 Test.Summary = 'Verify ATS can function as a forward proxy'
 Test.ContinueOnFail = True
+Test.SkipIf(Condition.CurlUsingUnixDomainSocket())
 
 
 class ForwardProxyTest:
@@ -84,7 +85,8 @@ class ForwardProxyTest:
         tr.MakeCurlCommand(
             f'--proxy-insecure -v -H "uuid: 1" '
             f'--proxy "https://127.0.0.1:{self.ts.Variables.ssl_port}/" '
-            f'http://example.com/')
+            f'http://example.com/',
+            ts=self.ts)
         tr.Processes.Default.ReturnCode = 0
         tr.StillRunningAfter = self.server
         tr.StillRunningAfter = self.ts
