@@ -58,7 +58,7 @@ ts.Disk.sni_yaml.AddLines([
 ])
 
 tr = Test.AddTestRun("Do-not-Negotiate-h2")
-tr.MakeCurlCommand("-v -k --resolve 'foo.com:{0}:127.0.0.1' https://foo.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v -k --resolve 'foo.com:{0}:127.0.0.1' https://foo.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.Processes.Default.StartBefore(server, ready=When.PortOpen(server.Variables.Port))
 tr.Processes.Default.StartBefore(Test.Processes.ts)
@@ -70,7 +70,7 @@ tr.Processes.Default.Streams.All += Testers.ExcludesExpression("[Uu]sing HTTP/?2
 tr.TimeOut = 5
 
 tr2 = Test.AddTestRun("Do negotiate h2")
-tr2.MakeCurlCommand("-v -k --resolve 'bar.com:{0}:127.0.0.1' https://bar.com:{0}".format(ts.Variables.ssl_port))
+tr2.MakeCurlCommand("-v -k --resolve 'bar.com:{0}:127.0.0.1' https://bar.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr2.ReturnCode = 0
 tr2.StillRunningAfter = server
 tr2.Processes.Default.TimeOut = 5
@@ -80,7 +80,7 @@ tr2.Processes.Default.Streams.All += Testers.ContainsExpression("[Uu]sing HTTP/?
 tr2.TimeOut = 5
 
 tr2 = Test.AddTestRun("Do negotiate h2")
-tr2.MakeCurlCommand("-v -k --resolve 'bob.foo.com:{0}:127.0.0.1' https://bob.foo.com:{0}".format(ts.Variables.ssl_port))
+tr2.MakeCurlCommand("-v -k --resolve 'bob.foo.com:{0}:127.0.0.1' https://bob.foo.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr2.ReturnCode = 0
 tr2.StillRunningAfter = server
 tr2.Processes.Default.TimeOut = 5
