@@ -132,13 +132,18 @@ ts.Disk.remap_config.AddLines(
 
 ts.Disk.MakeConfigFile(regex_remap_conf_file).AddLine(f'//.*/ http://127.0.0.1:{server.Variables.Port} @status=304')
 
+ipv4flag = ""
+if not Condition.CurlUsingUnixDomainSocket():
+    ipv4flag = "--ipv4"
+
 # Test 0 - Fill a 3 byte object with Last-Modified time into cache.
 tr = Test.AddTestRun()
 tr.Processes.Default.StartBefore(server)
 tr.Processes.Default.StartBefore(ts)
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: Fill" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: Fill" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_body-miss.gold"
 tr.StillRunningAfter = ts
@@ -150,8 +155,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 2
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: IMS" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: IMS" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_body-hit-stale.gold"
 tr.StillRunningAfter = ts
@@ -163,8 +169,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 2
 tr.MakeCurlCommand(
-    '--range 0-1 -s -D - -v --ipv4 --http1.1 -H"UID: IMS" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/'
-    .format(ts.Variables.port))
+    '--range 0-1 -s -D - -v {0} --http1.1 -H"UID: IMS" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_body-hit-stale-206.gold"
 tr.StillRunningAfter = ts
@@ -172,30 +179,32 @@ tr.StillRunningAfter = server
 
 # Test 3 - Test 304 response served from a regex-remap rule with HTTP.
 tr = Test.AddTestRun()
-tr.MakeCurlCommand(f'-vs http://127.0.0.1:{ts.Variables.port}/ -H "Host: {default_304_host}"')
+tr.MakeCurlCommand(f'-vs http://127.0.0.1:{ts.Variables.port}/ -H "Host: {default_304_host}"', ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = Testers.GoldFile("gold/http1_304.gold", case_insensitive=True)
 tr.StillRunningAfter = server
 
-# Test 4 - Test 304 response served from a regex-remap rule with HTTPS.
-tr = Test.AddTestRun()
-tr.MakeCurlCommand(f'-vs -k https://127.0.0.1:{ts.Variables.ssl_port}/ -H "Host: {default_304_host}"')
-tr.Processes.Default.ReturnCode = 0
-tr.Processes.Default.Streams.All = Testers.GoldFile("gold/http1_304.gold", case_insensitive=True)
-tr.StillRunningAfter = server
+if not Condition.CurlUsingUnixDomainSocket():
+    # Test 4 - Test 304 response served from a regex-remap rule with HTTPS.
+    tr = Test.AddTestRun()
+    tr.MakeCurlCommand(f'-vs -k https://127.0.0.1:{ts.Variables.ssl_port}/ -H "Host: {default_304_host}"', ts=ts)
+    tr.Processes.Default.ReturnCode = 0
+    tr.Processes.Default.Streams.All = Testers.GoldFile("gold/http1_304.gold", case_insensitive=True)
+    tr.StillRunningAfter = server
 
-# Test 5 - Test 304 response served from a regex-remap rule with HTTP/2.
-tr = Test.AddTestRun()
-tr.MakeCurlCommand(f'-vs -k --http2 https://127.0.0.1:{ts.Variables.ssl_port}/ -H "Host: {default_304_host}"')
-tr.Processes.Default.ReturnCode = 0
-tr.Processes.Default.Streams.All = Testers.GoldFile("gold/http2_304.gold", case_insensitive=True)
-tr.StillRunningAfter = server
+    # Test 5 - Test 304 response served from a regex-remap rule with HTTP/2.
+    tr = Test.AddTestRun()
+    tr.MakeCurlCommand(f'-vs -k --http2 https://127.0.0.1:{ts.Variables.ssl_port}/ -H "Host: {default_304_host}"', ts=ts)
+    tr.Processes.Default.ReturnCode = 0
+    tr.Processes.Default.Streams.All = Testers.GoldFile("gold/http2_304.gold", case_insensitive=True)
+    tr.StillRunningAfter = server
 
 # Test 6 - Fill a new object with an Etag. Not checking the output here.
 tr = Test.AddTestRun()
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: EtagFill" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/etag'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: EtagFill" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/etag'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
@@ -206,8 +215,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 2
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: INM" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/etag'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: INM" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/etag'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_body-hit-stale-INM.gold"
 tr.StillRunningAfter = ts
@@ -219,8 +229,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 2
 tr.MakeCurlCommand(
-    '--range 0-1 -s -D - -v --ipv4 --http1.1 -H"UID: INM" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/etag'
-    .format(ts.Variables.port))
+    '--range 0-1 -s -D - -v {0} --http1.1 -H"UID: INM" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/etag'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_body-hit-stale-206-etag.gold"
 tr.StillRunningAfter = ts
@@ -230,8 +241,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 3
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: noBody" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: noBody" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_nobody-hit-stale.gold"
 tr.StillRunningAfter = ts
@@ -241,8 +253,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 3
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: noBody" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: noBody" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_req_nobody-hit-stale.gold"
 tr.StillRunningAfter = ts
@@ -252,8 +265,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 2
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: EtagError" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/etag'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: EtagError" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/etag'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_error_nobody.gold"
 tr.StillRunningAfter = ts
@@ -263,8 +277,9 @@ tr.StillRunningAfter = server
 tr = Test.AddTestRun()
 tr.DelayStart = 2
 tr.MakeCurlCommand(
-    '-s -D - -v --ipv4 --http1.1 -H"UID: EtagError" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{0}/etag'
-    .format(ts.Variables.port))
+    '-s -D - -v {0} --http1.1 -H"UID: EtagError" -H "x-debug: x-cache,x-cache-key,via" -H "Host: www.example.com" http://localhost:{1}/etag'
+    .format(ipv4flag, ts.Variables.port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = "cache_and_error_nobody.gold"
 tr.StillRunningAfter = ts
