@@ -76,6 +76,10 @@ normalize_ae_log_id.Content = "normalize_ae.gold"
 
 # Try various Accept-Encoding header fields for a particular traffic server and host.
 
+ipv4flag = ""
+if not Condition.CurlUsingUnixDomainSocket():
+    ipv4flag = "--ipv4"
+
 
 def allAEHdrs(shouldWaitForUServer, shouldWaitForTs, ts, host):
 
@@ -90,34 +94,34 @@ def allAEHdrs(shouldWaitForUServer, shouldWaitForTs, ts, host):
         # delay on readiness of port
         tr.Processes.Default.StartBefore(ts)
 
-    baseCurl = '--verbose --ipv4 --http1.1 --proxy localhost:{} '.format(ts.Variables.port)
+    baseCurl = '--verbose {0} --http1.1 --proxy localhost:{1} '.format(ipv4flag, ts.Variables.port)
 
     # No Accept-Encoding header.
     #
-    tr.MakeCurlCommand(baseCurl + '--header "X-Au-Test: {0}" http://{0}'.format(host))
+    tr.MakeCurlCommand(baseCurl + '--header "X-Au-Test: {0}" http://{0}'.format(host), ts=ts)
     tr.Processes.Default.ReturnCode = 0
 
     def curlTail(hdrValue):
         return '--header "Accept-Encoding: {}" http://'.format(hdrValue) + host
 
     tr = test.AddTestRun()
-    tr.MakeCurlCommand(baseCurl + curlTail('gzip'))
+    tr.MakeCurlCommand(baseCurl + curlTail('gzip'), ts=ts)
     tr.Processes.Default.ReturnCode = 0
 
     tr = test.AddTestRun()
-    tr.MakeCurlCommand(baseCurl + curlTail('x-gzip'))
+    tr.MakeCurlCommand(baseCurl + curlTail('x-gzip'), ts=ts)
     tr.Processes.Default.ReturnCode = 0
 
     tr = test.AddTestRun()
-    tr.MakeCurlCommand(baseCurl + curlTail('br'))
+    tr.MakeCurlCommand(baseCurl + curlTail('br'), ts=ts)
     tr.Processes.Default.ReturnCode = 0
 
     tr = test.AddTestRun()
-    tr.MakeCurlCommand(baseCurl + curlTail('gzip, br'))
+    tr.MakeCurlCommand(baseCurl + curlTail('gzip, br'), ts=ts)
     tr.Processes.Default.ReturnCode = 0
 
     tr = test.AddTestRun()
-    tr.MakeCurlCommand(baseCurl + curlTail('gzip;q=0.3, whatever;q=0.666, br;q=0.7'))
+    tr.MakeCurlCommand(baseCurl + curlTail('gzip;q=0.3, whatever;q=0.666, br;q=0.7'), ts=ts)
     tr.Processes.Default.ReturnCode = 0
 
 
