@@ -128,7 +128,7 @@ tr.Processes.Default.ReturnCode = 0
 
 for i in range(num_objects):
     tr = Test.AddTestRun()
-    tr.MakeCurlCommand(f'--verbose --proxy 127.0.0.1:{ts.Variables.port} http://dummy.com/obj{i}')
+    tr.MakeCurlCommand(f'--verbose --proxy 127.0.0.1:{ts.Variables.port} http://dummy.com/obj{i}', ts=ts)
     tr.Processes.Default.Streams.stdout = "body.gold"
     tr.Processes.Default.ReturnCode = 0
 
