@@ -143,8 +143,8 @@ tr.Processes.Default.ReturnCode = 0
 for i in range(num_object):
     tr = Test.AddTestRun()
     tr.MakeCurlCommand(
-        f'--verbose --proxy 127.0.0.1:{ts_peer[i % num_peer].Variables.port} http://ts_upstream0:{ts_upstream[0].Variables.port}/obj{i}'
-    )
+        f'--verbose --proxy 127.0.0.1:{ts_peer[i % num_peer].Variables.port} http://ts_upstream0:{ts_upstream[0].Variables.port}/obj{i}',
+        ts=ts_peer[i % num_peer])
     tr.Processes.Default.Streams.stdout = "body.gold"
     tr.Processes.Default.ReturnCode = 0
 
@@ -152,8 +152,8 @@ for i in range(num_object):
     tr = Test.AddTestRun()
     # num_peer must not be a multiple of 3
     tr.MakeCurlCommand(
-        f'--verbose --proxy 127.0.0.1:{ts_peer[(i * 3) % num_peer].Variables.port} http://ts_upstream0:{ts_upstream[0].Variables.port}/obj{i}'
-    )
+        f'--verbose --proxy 127.0.0.1:{ts_peer[(i * 3) % num_peer].Variables.port} http://ts_upstream0:{ts_upstream[0].Variables.port}/obj{i}',
+        ts=ts_peer[(i * 3) % num_peer])
     tr.Processes.Default.Streams.stdout = "body.gold"
     tr.Processes.Default.ReturnCode = 0
 
