@@ -95,7 +95,7 @@ tr = Test.AddTestRun("0- range cache load")
 ps = tr.Processes.Default
 ps.StartBefore(server, ready=When.PortOpen(server.Variables.Port))
 ps.StartBefore(Test.Processes.ts)
-tr.MakeCurlCommand(curl_and_args + ' http://ims/path -r 0-')
+tr.MakeCurlCommand(curl_and_args + ' http://ims/path -r 0-', ts=ts)
 ps.ReturnCode = 0
 ps.Streams.stdout.Content = Testers.ContainsExpression("X-Cache: miss", "expected cache miss for load")
 tr.StillRunningAfter = ts
@@ -104,7 +104,7 @@ tr.StillRunningAfter = ts
 # 1 Test - Fetch range into cache
 tr = Test.AddTestRun("0- cache hit check")
 ps = tr.Processes.Default
-tr.MakeCurlCommand(curl_and_args + ' http://ims/path -r 0-')
+tr.MakeCurlCommand(curl_and_args + ' http://ims/path -r 0-', ts=ts)
 ps.ReturnCode = 0
 ps.Streams.stdout.Content = Testers.ContainsExpression("X-Cache: hit", "expected cache hit")
 tr.StillRunningAfter = ts
@@ -116,7 +116,7 @@ futurestr = time.strftime("%a, %d %b %Y %H:%M:%S GMT", time.gmtime(futuretime))
 # 2 Test - Ensure X-CRR-IMS header results in hit-stale
 tr = Test.AddTestRun("0- range X-CRR-IMS check")
 ps = tr.Processes.Default
-tr.MakeCurlCommand(curl_and_args + ' http://ims/path -r 0- -H "X-CRR-IMS: {}"'.format(futurestr))
+tr.MakeCurlCommand(curl_and_args + ' http://ims/path -r 0- -H "X-CRR-IMS: {}"'.format(futurestr), ts=ts)
 ps.ReturnCode = 0
 ps.Streams.stdout.Content = Testers.ContainsExpression("X-Cache: hit-stale", "expected cache hit-stale")
 tr.StillRunningAfter = ts
@@ -127,7 +127,7 @@ futurestr = time.strftime("%a, %d %b %Y %H:%M:%S GMT", time.gmtime(futuretime))
 # 3 Test - Ensure CrrIms header results in hit-stale
 tr = Test.AddTestRun("0- range CrrIms check, override header")
 ps = tr.Processes.Default
-tr.MakeCurlCommand(curl_and_args + ' http://imsheader/path -r 0- -H "CrrIms: {}"'.format(futurestr))
+tr.MakeCurlCommand(curl_and_args + ' http://imsheader/path -r 0- -H "CrrIms: {}"'.format(futurestr), ts=ts)
 ps.ReturnCode = 0
 ps.Streams.stdout.Content = Testers.ContainsExpression("X-Cache: hit-stale", "expected cache hit-stale")
 tr.StillRunningAfter = ts
