@@ -67,12 +67,13 @@ tr.Processes.Default.Command = 'echo start TS, HTTP server and DNS.'
 tr.Processes.Default.ReturnCode = 0
 
 tr = Test.AddTestRun()
-tr.MakeCurlCommand(f'--verbose --proxy 127.0.0.1:{ts.Variables.port} http://domain.in/texts/demo-3842948374928374982374982374.txt')
+tr.MakeCurlCommand(
+    f'--verbose --proxy 127.0.0.1:{ts.Variables.port} http://domain.in/texts/demo-3842948374928374982374982374.txt', ts=ts)
 tr.Processes.Default.ReturnCode = 0
 
 Test.AddAwaitFileContainsTestRun('Await transactions to finish logging.', ts.Disk.traffic_out.Name, '3842948374928374982374982377')
 
 tr = Test.AddTestRun()
-tr.Processes.Default.Command = (f"grep 'GET http://domain.in' {ts.Disk.traffic_out.Name}")
+tr.Processes.Default.Command = (f"grep 'GET http://' {ts.Disk.traffic_out.Name} | grep -v '127.0.0.1' ")
 tr.Streams.stdout = "prefetch_bignum.gold"
 tr.Processes.Default.ReturnCode = 0
