@@ -28,7 +28,7 @@ Test.testName = 'Emergency Shutdown Test'
 
 ts.Disk.records_config.update(
     {
-        'proxy.config.exec_thread.autoconfig': 0,
+        'proxy.config.exec_thread.autoconfig.enabled': 0,
         'proxy.config.exec_thread.autoconfig.scale': 1.5,
         'proxy.config.exec_thread.limit': 16,
         'proxy.config.accept_threads': 1,
@@ -47,7 +47,7 @@ tr = Test.AddTestRun()
 # before it detects the log message. So we add a separate process that waits
 # upon the log message.
 watcher = Test.Processes.Process("watcher")
-watcher.Command = "sleep 1"
+watcher.Command = "sleep 10"
 watcher.Ready = When.FileContains(ts.Disk.diags_log.Name, "testing emergency shutdown")
 watcher.StartBefore(ts)
 
