@@ -69,7 +69,8 @@ tr.Processes.Default.StartBefore(Test.Processes.ts)
 
 tr.MakeCurlCommand(
     '-o /dev/null -k --verbose -H "uuid: get" --ipv4 --http1.1 --resolve www.example.com:{}:127.0.0.1 https://www.example.com:{}/'
-    .format(ts.Variables.ssl_port, ts.Variables.ssl_port))
+    .format(ts.Variables.ssl_port, ts.Variables.ssl_port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = ts
@@ -79,7 +80,8 @@ tr.Processes.Default.Streams.all = Testers.ContainsExpression("TLS", "Should neg
 tr2 = Test.AddTestRun()
 tr2.MakeCurlCommand(
     '--verbose --ipv4 --http1.1 -H "uuid: get" --resolve www.example.com:{}:127.0.0.1 http://www.example.com:{}'.format(
-        ts.Variables.ssl_port, ts.Variables.ssl_port))
+        ts.Variables.ssl_port, ts.Variables.ssl_port),
+    ts=ts)
 tr2.Processes.Default.ReturnCode = 0
 tr2.StillRunningAfter = server
 tr2.StillRunningAfter = ts
@@ -90,7 +92,8 @@ tr2.Processes.Default.Streams.all = Testers.ExcludesExpression("TLS", "Should no
 tr3 = Test.AddTestRun()
 tr3.MakeCurlCommand(
     '--verbose -d @big_post_body -H "uuid: post" --ipv4 --http1.1 --resolve www.example.com:{}:127.0.0.1 http://www.example.com:{}/post http://www.example.com:{}/post'
-    .format(ts.Variables.ssl_port, ts.Variables.ssl_port, ts.Variables.ssl_port))
+    .format(ts.Variables.ssl_port, ts.Variables.ssl_port, ts.Variables.ssl_port),
+    ts=ts)
 tr3.Processes.Default.ReturnCode = 0
 tr3.StillRunningAfter = server
 tr3.StillRunningAfter = ts
