@@ -121,7 +121,7 @@ tr.Processes.Default.StartBefore(server2)
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
-tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -130,7 +130,7 @@ trfail = Test.AddTestRun("Connect with first client cert to second server")
 trfail.StillRunningAfter = ts
 trfail.StillRunningAfter = server
 trfail.StillRunningAfter = server2
-trfail.MakeCurlCommand('-H host:example.com  http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+trfail.MakeCurlCommand('-H host:example.com  http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 trfail.Processes.Default.ReturnCode = 0
 trfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -139,7 +139,7 @@ trbar = Test.AddTestRun("Connect with signed2 bar to second server")
 trbar.StillRunningAfter = ts
 trbar.StillRunningAfter = server
 trbar.StillRunningAfter = server2
-trbar.MakeCurlCommand("-H host:bar.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port))
+trbar.MakeCurlCommand("-H host:bar.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port), ts=ts)
 trbar.Processes.Default.ReturnCode = 0
 trbar.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -148,7 +148,7 @@ trbarfail = Test.AddTestRun("Connect with signed2 bar cert to first server")
 trbarfail.StillRunningAfter = ts
 trbarfail.StillRunningAfter = server
 trbarfail.StillRunningAfter = server2
-trbarfail.MakeCurlCommand('-H host:bar.com  http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+trbarfail.MakeCurlCommand('-H host:bar.com  http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 trbarfail.Processes.Default.ReturnCode = 0
 trbarfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -198,7 +198,7 @@ tr3bar.Processes.Default.StartBefore(server3, ready=When.FileContains(ts.Disk.di
 tr3bar.StillRunningAfter = ts
 tr3bar.StillRunningAfter = server
 tr3bar.StillRunningAfter = server2
-tr3bar.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+tr3bar.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 tr3bar.Processes.Default.ReturnCode = 0
 tr3bar.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -207,7 +207,7 @@ tr3barfail = Test.AddTestRun("Make request with other bar cert to second server"
 tr3barfail.StillRunningAfter = ts
 tr3barfail.StillRunningAfter = server
 tr3barfail.StillRunningAfter = server2
-tr3barfail.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+tr3barfail.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 tr3barfail.Processes.Default.ReturnCode = 0
 tr3barfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -217,7 +217,7 @@ tr3 = Test.AddTestRun("Make request with other cert to second server")
 tr3.StillRunningAfter = ts
 tr3.StillRunningAfter = server
 tr3.StillRunningAfter = server2
-tr3.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+tr3.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 tr3.Processes.Default.ReturnCode = 0
 tr3.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -226,7 +226,7 @@ tr3fail = Test.AddTestRun("Make request with other cert to first server")
 tr3fail.StillRunningAfter = ts
 tr3fail.StillRunningAfter = server
 tr3fail.StillRunningAfter = server2
-tr3fail.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+tr3fail.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 tr3fail.Processes.Default.ReturnCode = 0
 tr3fail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -260,7 +260,7 @@ tr4bar.DelayStart = 10
 tr4bar.StillRunningAfter = ts
 tr4bar.StillRunningAfter = server
 tr4bar.StillRunningAfter = server2
-tr4bar.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+tr4bar.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 tr4bar.Processes.Default.ReturnCode = 0
 tr4bar.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -269,7 +269,7 @@ tr4barfail = Test.AddTestRun("Make request with renamed bar cert to first server
 tr4barfail.StillRunningAfter = ts
 tr4barfail.StillRunningAfter = server
 tr4barfail.StillRunningAfter = server2
-tr4barfail.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+tr4barfail.MakeCurlCommand(' -H host:bar.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 tr4barfail.Processes.Default.ReturnCode = 0
 tr4barfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -278,7 +278,7 @@ tr4 = Test.AddTestRun("Make request with renamed foo cert to first server")
 tr4.StillRunningAfter = ts
 tr4.StillRunningAfter = server
 tr4.StillRunningAfter = server2
-tr4.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+tr4.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 tr4.Processes.Default.ReturnCode = 0
 tr4.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -287,7 +287,7 @@ tr4fail = Test.AddTestRun("Make request with renamed foo cert to second server")
 tr4fail.StillRunningAfter = ts
 tr4fail.StillRunningAfter = server
 tr4fail.StillRunningAfter = server2
-tr4fail.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+tr4fail.MakeCurlCommand(' -H host:example.com http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 tr4fail.Processes.Default.ReturnCode = 0
 tr4fail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
