@@ -127,7 +127,7 @@ tr.Processes.Default.StartBefore(server2)
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
-tr.MakeCurlCommand("-H host:bob.bar.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:bob.bar.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -136,7 +136,7 @@ trfail = Test.AddTestRun("bob.bar.com to server 2")
 trfail.StillRunningAfter = ts
 trfail.StillRunningAfter = server
 trfail.StillRunningAfter = server2
-trfail.MakeCurlCommand('-H host:bob.bar.com  http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+trfail.MakeCurlCommand('-H host:bob.bar.com  http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 trfail.Processes.Default.ReturnCode = 0
 trfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -145,7 +145,7 @@ tr = Test.AddTestRun("bob.foo.com to server 1")
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
-tr.MakeCurlCommand("-H host:bob.foo.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:bob.foo.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -154,7 +154,7 @@ trfail = Test.AddTestRun("bob.foo.com to server 2")
 trfail.StillRunningAfter = ts
 trfail.StillRunningAfter = server
 trfail.StillRunningAfter = server2
-trfail.MakeCurlCommand('-H host:bob.foo.com  http://127.0.0.1:{0}/case2'.format(ts.Variables.port))
+trfail.MakeCurlCommand('-H host:bob.foo.com  http://127.0.0.1:{0}/case2'.format(ts.Variables.port), ts=ts)
 trfail.Processes.Default.ReturnCode = 0
 trfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -163,7 +163,7 @@ tr = Test.AddTestRun("random.bar.com to server 2")
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
-tr.MakeCurlCommand("-H host:random.bar.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:random.bar.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -172,7 +172,7 @@ trfail = Test.AddTestRun("random.bar.com to server 1")
 trfail.StillRunningAfter = ts
 trfail.StillRunningAfter = server
 trfail.StillRunningAfter = server2
-trfail.MakeCurlCommand('-H host:random.bar.com  http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+trfail.MakeCurlCommand('-H host:random.bar.com  http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 trfail.Processes.Default.ReturnCode = 0
 trfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -181,7 +181,7 @@ tr = Test.AddTestRun("random.foo.com to server 2")
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
-tr.MakeCurlCommand("-H host:random.foo.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:random.foo.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -190,7 +190,7 @@ trfail = Test.AddTestRun("random.foo.com to server 1")
 trfail.StillRunningAfter = ts
 trfail.StillRunningAfter = server
 trfail.StillRunningAfter = server2
-trfail.MakeCurlCommand('-H host:random.foo.com  http://127.0.0.1:{0}/case1'.format(ts.Variables.port))
+trfail.MakeCurlCommand('-H host:random.foo.com  http://127.0.0.1:{0}/case1'.format(ts.Variables.port), ts=ts)
 trfail.Processes.Default.ReturnCode = 0
 trfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
