@@ -130,7 +130,7 @@ tr.Processes.Default.StartBefore(server2)
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
-tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -139,7 +139,7 @@ trfail = Test.AddTestRun("Connect with bad client cert to first server")
 trfail.StillRunningAfter = ts
 trfail.StillRunningAfter = server
 trfail.StillRunningAfter = server2
-trfail.MakeCurlCommand('-H host:example.com  http://127.0.0.1:{0}/badcase1'.format(ts.Variables.port))
+trfail.MakeCurlCommand('-H host:example.com  http://127.0.0.1:{0}/badcase1'.format(ts.Variables.port), ts=ts)
 trfail.Processes.Default.ReturnCode = 0
 trfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -148,7 +148,7 @@ trbar = Test.AddTestRun("Connect with correct client cert to second server")
 trbar.StillRunningAfter = ts
 trbar.StillRunningAfter = server
 trbar.StillRunningAfter = server2
-trbar.MakeCurlCommand("-H host:bar.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port))
+trbar.MakeCurlCommand("-H host:bar.com  http://127.0.0.1:{0}/case2".format(ts.Variables.port), ts=ts)
 trbar.Processes.Default.ReturnCode = 0
 trbar.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -157,7 +157,7 @@ trbarfail = Test.AddTestRun("Connect with bad client cert to second server")
 trbarfail.StillRunningAfter = ts
 trbarfail.StillRunningAfter = server
 trbarfail.StillRunningAfter = server2
-trbarfail.MakeCurlCommand('-H host:bar.com  http://127.0.0.1:{0}/badcase2'.format(ts.Variables.port))
+trbarfail.MakeCurlCommand('-H host:bar.com  http://127.0.0.1:{0}/badcase2'.format(ts.Variables.port), ts=ts)
 trbarfail.Processes.Default.ReturnCode = 0
 trbarfail.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -189,7 +189,7 @@ tr3bar.Processes.Default.StartBefore(server3, ready=When.FileContains(ts.Disk.di
 tr3bar.StillRunningAfter = ts
 tr3bar.StillRunningAfter = server
 tr3bar.StillRunningAfter = server2
-tr3bar.MakeCurlCommand(' -H host:foo.com http://127.0.0.1:{0}/badcase1'.format(ts.Variables.port))
+tr3bar.MakeCurlCommand(' -H host:foo.com http://127.0.0.1:{0}/badcase1'.format(ts.Variables.port), ts=ts)
 tr3bar.Processes.Default.ReturnCode = 0
 tr3bar.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
 
@@ -213,7 +213,7 @@ tr.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
 tr.StillRunningAfter = ts
-tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/case1".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could Not Connect", "Check response")
 
@@ -222,6 +222,6 @@ tr.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = server2
 tr.StillRunningAfter = ts
-tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/badcase1".format(ts.Variables.port))
+tr.MakeCurlCommand("-H host:example.com  http://127.0.0.1:{0}/badcase1".format(ts.Variables.port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.stdout = Testers.ExcludesExpression("Could Not Connect", "Check response")
