@@ -80,7 +80,8 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
     ("-v -k --tls-max 1.2  --cert {1}.pem --key {1}.key --resolve 'aaa.com:{0}:127.0.0.1'" + " https://aaa.com:{0}/xyz").format(
-        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/aaa-signed"))
+        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/aaa-signed"),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = Testers.ExcludesExpression("error", "Check response")
 
@@ -89,7 +90,8 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
     ("-v -k --tls-max 1.2  --cert {1}.pem --key {1}.key --resolve 'bbb-signed:{0}:127.0.0.1'" +
-     " https://bbb-signed:{0}/xyz").format(ts.Variables.ssl_port, Test.TestDirectory + "/ssl/bbb-signed"))
+     " https://bbb-signed:{0}/xyz").format(ts.Variables.ssl_port, Test.TestDirectory + "/ssl/bbb-signed"),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = Testers.ExcludesExpression("error", "Check response")
 
@@ -98,7 +100,8 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
     ("-v -k --tls-max 1.2  --cert {1}.pem --key {1}.key --resolve 'ccc.com:{0}:127.0.0.1'" + " https://ccc.com:{0}/xyz").format(
-        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/ccc-signed"))
+        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/ccc-signed"),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.Streams.All = Testers.ExcludesExpression("error", "Check response")
 
@@ -109,7 +112,8 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
     ("-v -k --tls-max 1.2  --cert {1}.pem --key {1}.key --resolve 'aaa.com:{0}:127.0.0.1'" + " https://aaa.com:{0}/xyz").format(
-        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/bbb-signed"))
+        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/bbb-signed"),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 35
 
 tr = Test.AddTestRun()
@@ -117,7 +121,8 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
     ("-v -k --tls-max 1.2  --cert {1}.pem --key {1}.key --resolve 'bbb.com:{0}:127.0.0.1'" + " https://bbb.com:{0}/xyz").format(
-        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/ccc-signed"))
+        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/ccc-signed"),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 35
 
 tr = Test.AddTestRun()
@@ -125,5 +130,6 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
     (" -v -k --tls-max 1.2  --cert {1}.pem --key {1}.key --resolve 'ccc.com:{0}:127.0.0.1'" + " https://ccc.com:{0}/xyz").format(
-        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/aaa-signed"))
+        ts.Variables.ssl_port, Test.TestDirectory + "/ssl/aaa-signed"),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 35
