@@ -69,7 +69,7 @@ tr.Processes.Default.StartBefore(Test.Processes.ts)
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommand(
-    '-k -v --http1.1  -H \'host:example.com:{0}\' https://127.0.0.1:{0} https://127.0.0.1:{0}'.format(ts.Variables.ssl_port))
+    '-k -v --http1.1  -H \'host:example.com:{0}\' https://127.0.0.1:{0} https://127.0.0.1:{0}'.format(ts.Variables.ssl_port), ts=ts)
 tr.Processes.Default.ReturnCode = 0
 
 tr = Test.AddTestRun("Test two HTTP/1.1 requests over two TLS connections")
@@ -77,14 +77,16 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommandMulti(
     '{{curl}} -k -v --http1.1  -H \'host:example.com:{0}\' https://127.0.0.1:{0}; {{curl}} -k -v --http1.1 -H \'host:example.com:{0}\'  https://127.0.0.1:{0}'
-    .format(ts.Variables.ssl_port))
+    .format(ts.Variables.ssl_port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 
 tr = Test.AddTestRun("Test two HTTP/2 requests over one TLS connection")
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommandMulti(
-    '{{curl}} -k -v --http2  -H \'host:example.com:{0}\' https://127.0.0.1:{0} https://127.0.0.1:{0}'.format(ts.Variables.ssl_port))
+    '{{curl}} -k -v --http2  -H \'host:example.com:{0}\' https://127.0.0.1:{0} https://127.0.0.1:{0}'.format(ts.Variables.ssl_port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 
 tr = Test.AddTestRun("Test two HTTP/2 requests over two TLS connections")
@@ -92,7 +94,8 @@ tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
 tr.MakeCurlCommandMulti(
     '{{curl}} -k -v --http2  -H \'host:example.com:{0}\' https://127.0.0.1:{0}; {{curl}} -k -v --http1.1 -H \'host:example.com:{0}\'  https://127.0.0.1:{0}'
-    .format(ts.Variables.ssl_port))
+    .format(ts.Variables.ssl_port),
+    ts=ts)
 tr.Processes.Default.ReturnCode = 0
 
 # Just a check to flush out the traffic log until we have a clean shutdown for traffic_server
