@@ -67,5 +67,6 @@ tr.StillRunningAfter = server
 tr.StillRunningAfter = ts
 tr.MakeCurlCommand(
     "-v --cacert {0} --cert-status -H \")host:example.com\" https://127.0.0.1:{1}".format(
-        os.path.join(ts.Variables.SSLDir, "ca.ocsp.pem"), ts.Variables.ssl_port))
+        os.path.join(ts.Variables.SSLDir, "ca.ocsp.pem"), ts.Variables.ssl_port),
+    ts=ts)
 tr.ReturnCode = 0
