@@ -126,7 +126,7 @@ ts.Disk.sni_yaml.AddLines(
 
 tr = Test.AddTestRun("foo.com Tunnel-test")
 tr.TimeOut = 5
-tr.MakeCurlCommand("-v --resolve 'foo.com:{0}:127.0.0.1' -k  https://foo.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v --resolve 'foo.com:{0}:127.0.0.1' -k  https://foo.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.Processes.Default.StartBefore(server_foo)
 tr.Processes.Default.StartBefore(server_bar)
@@ -146,7 +146,7 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("foo ok", "Should
 
 tr = Test.AddTestRun("bob.bar.com Tunnel-test")
 tr.TimeOut = 5
-tr.MakeCurlCommand("-v --resolve 'bob.bar.com:{0}:127.0.0.1' -k  https://bob.bar.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v --resolve 'bob.bar.com:{0}:127.0.0.1' -k  https://bob.bar.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
@@ -159,7 +159,7 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("foo ok", "Should
 
 tr = Test.AddTestRun("bar.com no Tunnel-test")
 tr.TimeOut = 5
-tr.MakeCurlCommand("-v --resolve 'bar.com:{0}:127.0.0.1' -k  https://bar.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v --resolve 'bar.com:{0}:127.0.0.1' -k  https://bar.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
@@ -168,7 +168,7 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("ATS", "Terminate
 
 tr = Test.AddTestRun("no SNI Tunnel-test")
 tr.TimeOut = 5
-tr.MakeCurlCommand("-v -k  https://127.0.0.1:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v -k  https://127.0.0.1:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
@@ -180,7 +180,8 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("bar ok", "Should
 
 tr = Test.AddTestRun("one.match.com Tunnel-test")
 tr.TimeOut = 5
-tr.MakeCurlCommand("-vvv --resolve 'one.match.com:{0}:127.0.0.1' -k  https://one.match.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand(
+    "-vvv --resolve 'one.match.com:{0}:127.0.0.1' -k  https://one.match.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
@@ -193,7 +194,8 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("foo ok", "Should
 
 tr = Test.AddTestRun("one.ok.two.com Tunnel-test")
 tr.TimeOut = 5
-tr.MakeCurlCommand("-vvv --resolve 'one.ok.two.com:{0}:127.0.0.1' -k  https://one.ok.two.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand(
+    "-vvv --resolve 'one.ok.two.com:{0}:127.0.0.1' -k  https://one.ok.two.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
@@ -207,7 +209,7 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("foo ok", "Should
 tr = Test.AddTestRun("test {inbound_local_port}")
 tr.TimeOut = 5
 tr.MakeCurlCommand(
-    "-vvv --resolve 'incoming.port.com:{0}:127.0.0.1' -k  https://incoming.port.com:{0}".format(ts.Variables.ssl_port))
+    "-vvv --resolve 'incoming.port.com:{0}:127.0.0.1' -k  https://incoming.port.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 # The tunnel connecting to the outgoing port which is the same as the incoming
 # port (per the `inbound_local_port` configuration) will result in ATS
 # connecting back to itself. This will result in a connection close and a
@@ -255,7 +257,8 @@ tr = Test.AddTestRun("test wildcard with inbound_local_port")
 tr.TimeOut = 5
 tr.MakeCurlCommand(
     "-vvv --resolve 'wildcard.with.incoming.port.com:{0}:127.0.0.1' -k  https://wildcard.with.incoming.port.com:{0}".format(
-        ts.Variables.ssl_port))
+        ts.Variables.ssl_port),
+    ts=ts)
 
 # See the inbound_local_port test above for the explanation of the return code.
 tr.ReturnCode = 35
@@ -345,14 +348,14 @@ tr.TimeOut = 30
 tr.StillRunningAfter = ts
 # Wait for the reload to complete by running the sni_reload_done test
 tr.Processes.Default.StartBefore(server2, ready=When.FileContains(ts.Disk.diags_log.Name, 'sni.yaml finished loading', 2))
-tr.MakeCurlCommand("-v --resolve 'foo.com:{0}:127.0.0.1' -k  https://foo.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v --resolve 'foo.com:{0}:127.0.0.1' -k  https://foo.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.Processes.Default.Streams.All += Testers.ContainsExpression("Not Found on Accelerato", "Terminates on on Traffic Server")
 tr.Processes.Default.Streams.All += Testers.ContainsExpression("ATS", "Terminate on Traffic Server")
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
 
 # Should tunnel to server_bar
 tr = Test.AddTestRun("bar.com  Tunnel-test")
-tr.MakeCurlCommand("-v --resolve 'bar.com:{0}:127.0.0.1' -k  https://bar.com:{0}".format(ts.Variables.ssl_port))
+tr.MakeCurlCommand("-v --resolve 'bar.com:{0}:127.0.0.1' -k  https://bar.com:{0}".format(ts.Variables.ssl_port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.Processes.Default.Streams.All += Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
