@@ -133,7 +133,7 @@ tr.Setup.Copy("ssl/signed-foo.key")
 tr.Setup.Copy("ssl/signed-foo.pem")
 tr.Setup.Copy("ssl/signed-bar.key")
 tr.Setup.Copy("ssl/signed-bar.pem")
-tr.MakeCurlCommand('-v -k -H \"host: foo.com\"  http://127.0.0.1:{0}/basic'.format(ts.Variables.port))
+tr.MakeCurlCommand('-v -k -H \"host: foo.com\"  http://127.0.0.1:{0}/basic'.format(ts.Variables.port), ts=ts)
 tr.ReturnCode = 0
 tr.Processes.Default.StartBefore(dns)
 tr.Processes.Default.StartBefore(server_foo)
@@ -147,7 +147,7 @@ tr.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connect
 tr.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
 
 tr2 = Test.AddTestRun("default-permissive-fail")
-tr2.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/basic".format(ts.Variables.port))
+tr2.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/basic".format(ts.Variables.port), ts=ts)
 tr2.ReturnCode = 0
 tr2.StillRunningAfter = server
 tr2.StillRunningAfter = ts
@@ -156,7 +156,7 @@ tr2.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connec
 tr2.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
 
 tr2 = Test.AddTestRun("default-permissive-fail2")
-tr2.MakeCurlCommand("-v -k -H \"host: random.com\"  http://127.0.0.1:{0}/basic".format(ts.Variables.port))
+tr2.MakeCurlCommand("-v -k -H \"host: random.com\"  http://127.0.0.1:{0}/basic".format(ts.Variables.port), ts=ts)
 tr2.ReturnCode = 0
 tr2.StillRunningAfter = server
 tr2.StillRunningAfter = ts
@@ -165,7 +165,7 @@ tr2.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connec
 tr2.Processes.Default.Streams.All += Testers.ContainsExpression("404 Not Found", "Curl attempt should have succeeded")
 
 tr3 = Test.AddTestRun("default-foo-to-bar")
-tr3.MakeCurlCommand("-k -v -H \"host: foo.com\"  http://127.0.0.1:{0}/basictobar".format(ts.Variables.port))
+tr3.MakeCurlCommand("-k -v -H \"host: foo.com\"  http://127.0.0.1:{0}/basictobar".format(ts.Variables.port), ts=ts)
 tr3.ReturnCode = 0
 tr3.StillRunningAfter = server
 tr3.StillRunningAfter = ts
@@ -174,7 +174,7 @@ tr3.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connec
 tr3.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
 
 tr3 = Test.AddTestRun("override-foo")
-tr3.MakeCurlCommand("-k -v -H \"host: foo.com\"  http://127.0.0.1:{0}/override".format(ts.Variables.port))
+tr3.MakeCurlCommand("-k -v -H \"host: foo.com\"  http://127.0.0.1:{0}/override".format(ts.Variables.port), ts=ts)
 tr3.ReturnCode = 0
 tr3.StillRunningAfter = server
 tr3.StillRunningAfter = ts
@@ -183,7 +183,7 @@ tr3.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connec
 tr3.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
 
 tr4 = Test.AddTestRun("override-bar-disabled")
-tr4.MakeCurlCommand("-k -v -H \"host: bad_bar.com\"  http://127.0.0.1:{0}/overridedisabled".format(ts.Variables.port))
+tr4.MakeCurlCommand("-k -v -H \"host: bad_bar.com\"  http://127.0.0.1:{0}/overridedisabled".format(ts.Variables.port), ts=ts)
 tr4.ReturnCode = 0
 tr4.StillRunningAfter = server
 tr4.StillRunningAfter = ts
@@ -192,7 +192,7 @@ tr4.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connec
 tr4.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
 
 tr5 = Test.AddTestRun("override-bar-signature-enforced")
-tr5.MakeCurlCommand("-k -v -H \"host: bar.com\"  http://127.0.0.1:{0}/overridesignature".format(ts.Variables.port))
+tr5.MakeCurlCommand("-k -v -H \"host: bar.com\"  http://127.0.0.1:{0}/overridesignature".format(ts.Variables.port), ts=ts)
 tr5.ReturnCode = 0
 tr5.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
 tr5.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
@@ -200,7 +200,7 @@ tr5.StillRunningAfter = server
 tr5.StillRunningAfter = ts
 
 tr5a = Test.AddTestRun("override-bar-none-permissive")
-tr5a.MakeCurlCommand("-k -v -H \"host: bar.com\"  http://127.0.0.1:{0}/overridenone".format(ts.Variables.port))
+tr5a.MakeCurlCommand("-k -v -H \"host: bar.com\"  http://127.0.0.1:{0}/overridenone".format(ts.Variables.port), ts=ts)
 tr5a.ReturnCode = 0
 tr5a.Processes.Default.Streams.All = Testers.ExcludesExpression("Could Not Connect", "Curl attempt should have succeeded")
 tr5a.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl attempt should have succeeded")
@@ -208,7 +208,7 @@ tr5a.StillRunningAfter = server
 tr5a.StillRunningAfter = ts
 
 tr6 = Test.AddTestRun("override-bar-enforced")
-tr6.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/overrideenforced".format(ts.Variables.port))
+tr6.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/overrideenforced".format(ts.Variables.port), ts=ts)
 tr6.ReturnCode = 0
 # Should fail
 tr6.Processes.Default.Streams.All = Testers.ContainsExpression("Could Not Connect", "Curl attempt should have failed")
@@ -217,7 +217,7 @@ tr6.StillRunningAfter = ts
 
 # Should succeed
 tr = Test.AddTestRun("foo-to-bar-sni-policy-remap")
-tr.MakeCurlCommand("-v -k -H \"host: foo.com\"  http://127.0.0.1:{0}/snipolicybarremap".format(ts.Variables.port))
+tr.MakeCurlCommand("-v -k -H \"host: foo.com\"  http://127.0.0.1:{0}/snipolicybarremap".format(ts.Variables.port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = ts
@@ -226,7 +226,7 @@ tr.Processes.Default.Streams.All += Testers.ContainsExpression("200 OK", "Curl a
 
 # Should fail
 tr = Test.AddTestRun("foo-to-bar-sni-policy-host")
-tr.MakeCurlCommand("-v -k -H \"host: foo.com\"  http://127.0.0.1:{0}/snipolicybarhost".format(ts.Variables.port))
+tr.MakeCurlCommand("-v -k -H \"host: foo.com\"  http://127.0.0.1:{0}/snipolicybarhost".format(ts.Variables.port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = ts
@@ -234,7 +234,7 @@ tr.Processes.Default.Streams.All = Testers.ContainsExpression("Could not connect
 
 # Should fail
 tr = Test.AddTestRun("bar-to-foo-sni-policy-remap")
-tr.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/snipolicyfooremap".format(ts.Variables.port))
+tr.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/snipolicyfooremap".format(ts.Variables.port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = ts
@@ -242,7 +242,7 @@ tr.Processes.Default.Streams.stdout = Testers.ContainsExpression("Could not conn
 
 # Should succeed
 tr = Test.AddTestRun("bar-to-foo-sni-policy-host")
-tr.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/snipolicyfoohost".format(ts.Variables.port))
+tr.MakeCurlCommand("-v -k -H \"host: bar.com\"  http://127.0.0.1:{0}/snipolicyfoohost".format(ts.Variables.port), ts=ts)
 tr.ReturnCode = 0
 tr.StillRunningAfter = server
 tr.StillRunningAfter = ts
