@@ -23,6 +23,7 @@ Test.Summary = '''
 Test the reported type of HTTP transactions and tunnels
 '''
 
+Test.SkipIf(Condition.CurlUsingUnixDomainSocket())
 # Define default ATS. Disable the cache to simplify the test.
 ts = Test.MakeATSProcess("ts", enable_cache=False, enable_tls=True)
 ts.addSSLfile("../tls/ssl/server.pem")
@@ -84,7 +85,7 @@ cmd_connect = '-k --http1.1 -H "Connection: close" -vs --resolve "connect-proxy:
 # Send the http request
 tr = Test.AddTestRun("send http request")
 tr.Processes.Default.Env = ts.Env
-tr.MakeCurlCommand(cmd_http)
+tr.MakeCurlCommand(cmd_http, ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.Processes.Default.StartBefore(server, ready=When.PortOpen(server.Variables.SSL_Port))
 tr.Processes.Default.StartBefore(Test.Processes.ts)
@@ -94,7 +95,7 @@ tr.StillRunningAfter = server
 # Send the tunnel request
 tr = Test.AddTestRun("send tunnel request")
 tr.Processes.Default.Env = ts.Env
-tr.MakeCurlCommand(cmd_tunnel)
+tr.MakeCurlCommand(cmd_tunnel, ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
@@ -105,7 +106,7 @@ tr.StillRunningAfter = server
 # method to determine whether a connect tunnel will be set up
 tr = Test.AddTestRun("send connect request")
 tr.Processes.Default.Env = ts.Env
-tr.MakeCurlCommand(cmd_connect)
+tr.MakeCurlCommand(cmd_connect, ts=ts)
 tr.Processes.Default.ReturnCode = 0
 tr.StillRunningAfter = ts
 tr.StillRunningAfter = server
