@@ -21,10 +21,11 @@
 #include <ts/ts.h> // for debug
 
 // debug messages viewable by setting 'proxy.config.diags.debug.tags'
-// in 'records.config'
+// in 'records.yaml'
 
 // debug messages during one-time initialization
 static const char DEBUG_TAG[] = "TSEmergency_test";
+static DbgCtl     dbg_ctl{DEBUG_TAG};
 
 // plugin registration info
 static char plugin_name[]   = "TSEmergency_test";
@@ -32,14 +33,14 @@ static char vendor_name[]   = "apache";
 static char support_email[] = "duke8253@apache.org";
 
 static int
-test_handler(TSCont contp, TSEvent event, void *edata)
+test_handler(TSCont /* contp ATS_UNUSED */, TSEvent /* event ATS_UNUSED */, void * /* edata ATS_UNUSED */)
 {
-  TSDebug(DEBUG_TAG, "failed to shutdown");
+  Dbg(dbg_ctl, "failed to shutdown");
   return 0;
 }
 
 static int
-LifecycleHookTracer(TSCont contp, TSEvent event, void *edata)
+LifecycleHookTracer(TSCont /* contp ATS_UNUSED */, TSEvent event, void * /* edata ATS_UNUSED */)
 {
   if (event == TS_EVENT_LIFECYCLE_TASK_THREADS_READY) {
     TSCont contp = TSContCreate(test_handler, TSMutexCreate());
@@ -50,7 +51,7 @@ LifecycleHookTracer(TSCont contp, TSEvent event, void *edata)
 }
 
 void
-TSPluginInit(int argc, const char *argv[])
+TSPluginInit(int /* argc ATS_UNUSED */, const char ** /* argv ATS_UNUSED */)
 {
   TSPluginRegistrationInfo info;
 
